@@ -29,15 +29,16 @@ import ghidra.app.events.*;
 import ghidra.app.plugin.PluginCategoryNames;
 import ghidra.app.plugin.core.codebrowser.AbstractCodeBrowserPlugin;
 import ghidra.app.plugin.core.codebrowser.CodeViewerProvider;
-import ghidra.app.plugin.core.debug.DebuggerCoordinates;
 import ghidra.app.plugin.core.debug.DebuggerPluginPackage;
 import ghidra.app.plugin.core.debug.event.*;
 import ghidra.app.plugin.core.debug.gui.DebuggerResources.AbstractNewListingAction;
-import ghidra.app.plugin.core.debug.gui.action.LocationTrackingSpec;
-import ghidra.app.plugin.core.debug.gui.action.NoneLocationTrackingSpec;
+import ghidra.app.plugin.core.debug.gui.action.*;
 import ghidra.app.services.*;
 import ghidra.app.util.viewer.format.FormatManager;
 import ghidra.app.util.viewer.listingpanel.ListingPanel;
+import ghidra.debug.api.action.LocationTrackingSpec;
+import ghidra.debug.api.listing.MultiBlendedListingBackgroundColorModel;
+import ghidra.debug.api.tracemgr.DebuggerCoordinates;
 import ghidra.framework.options.SaveState;
 import ghidra.framework.plugintool.*;
 import ghidra.framework.plugintool.annotation.AutoServiceConsumed;
@@ -76,11 +77,9 @@ import utilities.util.SuppressableCallback.Suppression;
 		TraceSelectionPluginEvent.class
 	},
 	servicesRequired = {
-		DebuggerModelService.class, // For memory capture
 		DebuggerStaticMappingService.class, // For static listing sync. TODO: Optional?
 		DebuggerEmulationService.class, // TODO: Optional?
 		ProgramManager.class, // For static listing sync
-		//GoToService.class, // For static listing sync
 		ClipboardService.class,
 		MarkerService.class // TODO: Make optional?
 	},
@@ -119,8 +118,6 @@ public class DebuggerListingPlugin extends AbstractCodeBrowserPlugin<DebuggerLis
 
 	protected NewListingAction actionNewListing;
 
-	//@AutoServiceConsumed
-	//private GoToService goToService;
 	@AutoServiceConsumed
 	private ProgramManager programManager;
 	// NOTE: This plugin doesn't extend AbstractDebuggerPlugin
@@ -138,6 +135,16 @@ public class DebuggerListingPlugin extends AbstractCodeBrowserPlugin<DebuggerLis
 		autoServiceWiring = AutoService.wireServicesProvidedAndConsumed(this);
 
 		createActions();
+
+		tool.registerDefaultContextProvider(DebuggerProgramLocationActionContext.class,
+			connectedProvider);
+	}
+
+	@Override
+	protected void dispose() {
+		tool.unregisterDefaultContextProvider(DebuggerProgramLocationActionContext.class,
+			connectedProvider);
+		super.dispose();
 	}
 
 	@Override
