@@ -33,7 +33,6 @@ import docking.menu.MultiStateDockingAction;
 import docking.widgets.fieldpanel.support.ViewerPosition;
 import generic.theme.GThemeDefaults.Colors;
 import ghidra.app.plugin.core.byteviewer.*;
-import ghidra.app.plugin.core.debug.DebuggerCoordinates;
 import ghidra.app.plugin.core.debug.gui.DebuggerLocationLabel;
 import ghidra.app.plugin.core.debug.gui.DebuggerResources;
 import ghidra.app.plugin.core.debug.gui.DebuggerResources.FollowsCurrentThreadAction;
@@ -41,6 +40,9 @@ import ghidra.app.plugin.core.debug.gui.action.*;
 import ghidra.app.plugin.core.debug.gui.action.AutoReadMemorySpec.AutoReadMemorySpecConfigFieldCodec;
 import ghidra.app.plugin.core.format.ByteBlock;
 import ghidra.app.services.DebuggerTraceManagerService;
+import ghidra.debug.api.action.GoToInput;
+import ghidra.debug.api.action.LocationTrackingSpec;
+import ghidra.debug.api.tracemgr.DebuggerCoordinates;
 import ghidra.framework.options.SaveState;
 import ghidra.framework.plugintool.*;
 import ghidra.framework.plugintool.annotation.AutoConfigStateField;
@@ -69,7 +71,7 @@ public class DebuggerMemoryBytesProvider extends ProgramByteViewerComponentProvi
 		if (!Objects.equals(a.getView(), b.getView())) {
 			return false; // Subsumes trace
 		}
-		if (!Objects.equals(a.getRecorder(), b.getRecorder())) {
+		if (!Objects.equals(a.getTarget(), b.getTarget())) {
 			return false; // For capture memory action
 		}
 		if (!Objects.equals(a.getTime(), b.getTime())) {
@@ -103,13 +105,18 @@ public class DebuggerMemoryBytesProvider extends ProgramByteViewerComponentProvi
 				DebuggerMemoryBytesProvider.this);
 		}
 
+		@Override
+		protected GoToInput getDefaultInput() {
+			return trackingTrait.getDefaultGoToInput(currentLocation);
+		}
+
 		@Override
 		protected boolean goToAddress(Address address) {
 			TraceProgramView view = current.getView();
 			if (view == null) {
 				return false;
 			}
-			return goTo(view, new ProgramLocation(view, address));
+			return DebuggerMemoryBytesProvider.this.goTo(view, new ProgramLocation(view, address));
 		}
 	}
 
@@ -128,6 +135,7 @@ public class DebuggerMemoryBytesProvider extends ProgramByteViewerComponentProvi
 		protected void specChanged(LocationTrackingSpec spec) {
 			updateTitle();
 			trackingLabel.setText("");
+			trackingLabel.setToolTipText("");
 			trackingLabel.setForeground(Colors.FOREGROUND);
 		}
 	}
@@ -202,7 +210,7 @@ public class DebuggerMemoryBytesProvider extends ProgramByteViewerComponentProvi
 		addDisplayListener(readsMemTrait.getDisplayListener());
 
 		JPanel northPanel = new JPanel(new BorderLayout());
-		northPanel.add(locationLabel, BorderLayout.WEST);
+		northPanel.add(locationLabel);
 		northPanel.add(trackingLabel, BorderLayout.EAST);
 		decorationComponent.add(northPanel, BorderLayout.NORTH);
 
@@ -330,6 +338,11 @@ public class DebuggerMemoryBytesProvider extends ProgramByteViewerComponentProvi
 		setSubTitle(computeSubTitle());
 	}
 
+	@Override
+	protected ByteViewerActionContext newByteViewerActionContext() {
+		return new DebuggerMemoryBytesActionContext(this);
+	}
+
 	protected void createActions() {
 		initTraits();
 
@@ -372,7 +385,7 @@ public class DebuggerMemoryBytesProvider extends ProgramByteViewerComponentProvi
 		if (location == null) {
 			return false;
 		}
-		if (blockSet.getByteBlockInfo(location.getAddress()) == null) {
+		if (blockSet == null || blockSet.getByteBlockInfo(location.getAddress()) == null) {
 			return false;
 		}
 		if (!super.goTo(gotoProgram, location)) {
@@ -469,7 +482,9 @@ public class DebuggerMemoryBytesProvider extends ProgramByteViewerComponentProvi
 	}
 
 	protected void goToAndUpdateTrackingLabel(TraceProgramView curView, ProgramLocation loc) {
-		trackingLabel.setText(trackingTrait.computeLabelText());
+		String labelText = trackingTrait.computeLabelText();
+		trackingLabel.setText(labelText);
+		trackingLabel.setToolTipText(labelText);
 		if (goTo(curView, loc)) {
 			trackingLabel.setForeground(Colors.FOREGROUND);
 		}
@@ -488,6 +503,10 @@ public class DebuggerMemoryBytesProvider extends ProgramByteViewerComponentProvi
 		}
 		TraceProgramView curView = current.getView();
 		Swing.runIfSwingOrRunLater(() -> {
+			if (curView != current.getView()) {
+				// Trace changed before Swing scheduled us
+				return;
+			}
 			goToAndUpdateTrackingLabel(curView, loc);
 		});
 	}
