@@ -24,20 +24,25 @@ import javax.swing.*;
 
 import org.apache.commons.lang3.ArrayUtils;
 
+import db.Transaction;
 import docking.ActionContext;
 import docking.WindowPosition;
 import docking.action.*;
 import docking.action.builder.ActionBuilder;
-import ghidra.app.plugin.core.debug.DebuggerCoordinates;
+import docking.action.builder.ToggleActionBuilder;
 import ghidra.app.plugin.core.debug.DebuggerPluginPackage;
 import ghidra.app.plugin.core.debug.gui.DebuggerBlockChooserDialog;
 import ghidra.app.plugin.core.debug.gui.DebuggerResources;
-import ghidra.app.plugin.core.debug.gui.DebuggerResources.*;
+import ghidra.app.plugin.core.debug.gui.DebuggerResources.AbstractSelectAddressesAction;
+import ghidra.app.plugin.core.debug.gui.DebuggerResources.SelectRowsAction;
 import ghidra.app.plugin.core.debug.gui.model.DebuggerObjectActionContext;
 import ghidra.app.plugin.core.debug.gui.modules.DebuggerModulesProvider;
 import ghidra.app.plugin.core.debug.service.modules.MapRegionsBackgroundCommand;
 import ghidra.app.services.*;
-import ghidra.app.services.RegionMapProposal.RegionMapEntry;
+import ghidra.debug.api.modules.MapProposal;
+import ghidra.debug.api.modules.RegionMapProposal;
+import ghidra.debug.api.modules.RegionMapProposal.RegionMapEntry;
+import ghidra.debug.api.tracemgr.DebuggerCoordinates;
 import ghidra.framework.plugintool.*;
 import ghidra.framework.plugintool.annotation.AutoServiceConsumed;
 import ghidra.program.model.address.AddressRange;
@@ -76,7 +81,8 @@ public class DebuggerRegionsProvider extends ComponentProviderAdapter {
 
 		static ActionBuilder builder(Plugin owner) {
 			String ownerName = owner.getName();
-			return new ActionBuilder(NAME, ownerName).description(DESCRIPTION)
+			return new ActionBuilder(NAME, ownerName)
+					.description(DESCRIPTION)
 					.popupMenuPath(NAME)
 					.popupMenuGroup(GROUP)
 					.helpLocation(new HelpLocation(ownerName, HELP_ANCHOR));
@@ -91,7 +97,8 @@ public class DebuggerRegionsProvider extends ComponentProviderAdapter {
 
 		static ActionBuilder builder(Plugin owner) {
 			String ownerName = owner.getName();
-			return new ActionBuilder(NAME_PREFIX, ownerName).description(DESCRIPTION)
+			return new ActionBuilder(NAME_PREFIX, ownerName)
+					.description(DESCRIPTION)
 					.popupMenuPath(NAME_PREFIX + "...")
 					.popupMenuGroup(GROUP)
 					.helpLocation(new HelpLocation(ownerName, HELP_ANCHOR));
@@ -107,13 +114,62 @@ public class DebuggerRegionsProvider extends ComponentProviderAdapter {
 
 		static ActionBuilder builder(Plugin owner) {
 			String ownerName = owner.getName();
-			return new ActionBuilder(NAME_PREFIX, ownerName).description(DESCRIPTION)
+			return new ActionBuilder(NAME_PREFIX, ownerName)
+					.description(DESCRIPTION)
 					.popupMenuPath(NAME_PREFIX + "...")
 					.popupMenuGroup(GROUP)
 					.helpLocation(new HelpLocation(ownerName, HELP_ANCHOR));
 		}
 	}
 
+	interface AddRegionAction {
+		String NAME = "Add Region";
+		String DESCRIPTION = "Manually add a region to the memory map";
+		String GROUP = DebuggerResources.GROUP_MAINTENANCE;
+		String HELP_ANCHOR = "add_region";
+
+		static ActionBuilder builder(Plugin owner) {
+			String ownerName = owner.getName();
+			return new ActionBuilder(NAME, ownerName)
+					.description(DESCRIPTION)
+					.menuGroup(GROUP)
+					.menuPath(NAME)
+					.helpLocation(new HelpLocation(ownerName, HELP_ANCHOR));
+		}
+	}
+
+	interface DeleteRegionsAction {
+		String NAME = "Delete Regions";
+		String DESCRIPTION = "Delete one or more regions from the memory map";
+		String GROUP = DebuggerResources.GROUP_MAINTENANCE;
+		String HELP_ANCHOR = "delete_regions";
+
+		static ActionBuilder builder(Plugin owner) {
+			String ownerName = owner.getName();
+			return new ActionBuilder(NAME, ownerName)
+					.description(DESCRIPTION)
+					.popupMenuGroup(GROUP)
+					.popupMenuPath(NAME, "Yes, really. Delete them!")
+					.helpLocation(new HelpLocation(ownerName, HELP_ANCHOR));
+		}
+	}
+
+	interface ForceFullViewAction {
+		String NAME = "Force Full View";
+		String DESCRIPTION = "Ignore regions and fiew full address spaces";
+		String GROUP = DebuggerResources.GROUP_GENERAL;
+		String HELP_ANCHOR = "force_full_view";
+
+		static ToggleActionBuilder builder(Plugin owner) {
+			String ownerName = owner.getName();
+			return new ToggleActionBuilder(NAME, ownerName)
+					.description(DESCRIPTION)
+					.menuGroup(GROUP)
+					.menuPath(NAME)
+					.helpLocation(new HelpLocation(ownerName, HELP_ANCHOR));
+		}
+	}
+
 	protected class SelectAddressesAction extends AbstractSelectAddressesAction {
 		public static final String GROUP = DebuggerResources.GROUP_GENERAL;
 
@@ -175,12 +231,16 @@ public class DebuggerRegionsProvider extends ComponentProviderAdapter {
 	// TODO: Lazy construction of these dialogs?
 	private final DebuggerBlockChooserDialog blockChooserDialog;
 	private final DebuggerRegionMapProposalDialog regionProposalDialog;
+	private final DebuggerAddRegionDialog addRegionDialog;
+
 	DockingAction actionMapRegions;
 	DockingAction actionMapRegionTo;
 	DockingAction actionMapRegionsTo;
 
 	SelectAddressesAction actionSelectAddresses;
 	DockingAction actionSelectRows;
+	DockingAction actionAddRegion;
+	DockingAction actionDeleteRegions;
 	ToggleDockingAction actionForceFullView;
 
 	public DebuggerRegionsProvider(DebuggerRegionsPlugin plugin) {
@@ -198,6 +258,7 @@ public class DebuggerRegionsProvider extends ComponentProviderAdapter {
 
 		blockChooserDialog = new DebuggerBlockChooserDialog(tool);
 		regionProposalDialog = new DebuggerRegionMapProposalDialog(this);
+		addRegionDialog = new DebuggerAddRegionDialog();
 
 		setDefaultWindowPosition(WindowPosition.BOTTOM);
 		setVisible(true);
@@ -237,6 +298,14 @@ public class DebuggerRegionsProvider extends ComponentProviderAdapter {
 				.enabledWhen(ctx -> current.getTrace() != null)
 				.onAction(this::activatedSelectCurrent)
 				.buildAndInstallLocal(this);
+		actionAddRegion = AddRegionAction.builder(plugin)
+				.enabledWhen(ctx -> current.getTrace() != null)
+				.onAction(this::activatedAddRegion)
+				.buildAndInstallLocal(this);
+		actionDeleteRegions = DeleteRegionsAction.builder(plugin)
+				.enabledWhen(this::isContextNonEmpty)
+				.onAction(this::activatedDeleteRegions)
+				.buildAndInstallLocal(this);
 		actionForceFullView = ForceFullViewAction.builder(plugin)
 				.enabledWhen(ctx -> current.getTrace() != null)
 				.onAction(this::activatedForceFullView)
@@ -385,6 +454,25 @@ public class DebuggerRegionsProvider extends ComponentProviderAdapter {
 		}
 	}
 
+	private void activatedAddRegion(ActionContext ignored) {
+		if (current.getTrace() == null) {
+			return;
+		}
+		addRegionDialog.show(tool, current.getTrace(), current.getSnap());
+	}
+
+	private void activatedDeleteRegions(ActionContext ctx) {
+		Set<TraceMemoryRegion> sel = getSelectedRegions(ctx);
+		if (sel.isEmpty()) {
+			return;
+		}
+		try (Transaction tx = current.getTrace().openTransaction("Delete regions")) {
+			for (TraceMemoryRegion region : sel) {
+				region.delete();
+			}
+		}
+	}
+
 	private void activatedForceFullView(ActionContext ignored) {
 		if (current.getTrace() == null) {
 			return;
