@@ -31,7 +31,6 @@ import docking.action.ToggleDockingAction;
 import docking.widgets.table.RangeCursorTableHeaderRenderer.SeekListener;
 import docking.widgets.tree.support.GTreeSelectionEvent.EventOrigin;
 import generic.theme.GColor;
-import ghidra.app.plugin.core.debug.DebuggerCoordinates;
 import ghidra.app.plugin.core.debug.DebuggerPluginPackage;
 import ghidra.app.plugin.core.debug.gui.DebuggerResources;
 import ghidra.app.plugin.core.debug.gui.DebuggerResources.*;
@@ -42,6 +41,7 @@ import ghidra.app.plugin.core.debug.gui.model.ObjectTableModel.ValueRow;
 import ghidra.app.plugin.core.debug.gui.model.ObjectTreeModel.AbstractNode;
 import ghidra.app.plugin.core.debug.gui.model.PathTableModel.PathRow;
 import ghidra.app.services.DebuggerTraceManagerService;
+import ghidra.debug.api.tracemgr.DebuggerCoordinates;
 import ghidra.framework.options.SaveState;
 import ghidra.framework.plugintool.AutoConfigState;
 import ghidra.framework.plugintool.AutoService;
@@ -567,6 +567,9 @@ public class DebuggerModelProvider extends ComponentProvider implements Saveable
 	}
 
 	protected void checkPath() {
+		if (Trace.isLegacy(current.getTrace())) {
+			return;
+		}
 		if (objectsTreePanel.getNode(path) == null) {
 			plugin.getTool().setStatusInfo("No such object at path " + path, true);
 		}
