@@ -34,8 +34,7 @@ import javax.swing.tree.TreePath;
 import org.apache.commons.collections4.map.LinkedMap;
 import org.apache.commons.lang3.StringUtils;
 
-import docking.ActionContext;
-import docking.WindowPosition;
+import docking.*;
 import docking.action.*;
 import docking.action.builder.ActionBuilder;
 import docking.action.builder.ToggleActionBuilder;
@@ -44,26 +43,29 @@ import docking.widgets.table.DefaultEnumeratedColumnTableModel;
 import docking.widgets.tree.GTree;
 import generic.jar.ResourceFile;
 import generic.theme.GColor;
-import ghidra.app.plugin.core.debug.DebuggerCoordinates;
 import ghidra.app.plugin.core.debug.DebuggerPluginPackage;
 import ghidra.app.plugin.core.debug.gui.DebuggerResources;
 import ghidra.app.plugin.core.debug.gui.DebuggerResources.*;
 import ghidra.app.plugin.core.debug.gui.objects.actions.*;
 import ghidra.app.plugin.core.debug.gui.objects.components.*;
-import ghidra.app.plugin.core.debug.mapping.DebuggerMemoryMapper;
 import ghidra.app.script.*;
 import ghidra.app.services.*;
 import ghidra.app.services.DebuggerTraceManagerService.ActivationCause;
 import ghidra.async.*;
 import ghidra.dbg.*;
+import ghidra.dbg.DebuggerObjectModel.RefreshBehavior;
 import ghidra.dbg.error.DebuggerMemoryAccessException;
 import ghidra.dbg.target.*;
 import ghidra.dbg.target.TargetConsole.Channel;
 import ghidra.dbg.target.TargetExecutionStateful.TargetExecutionState;
 import ghidra.dbg.target.TargetMethod.ParameterDescription;
+import ghidra.dbg.target.TargetMethod.TargetParameterMap;
 import ghidra.dbg.target.TargetSteppable.TargetStepKind;
 import ghidra.dbg.util.DebuggerCallbackReorderer;
 import ghidra.dbg.util.PathUtils;
+import ghidra.debug.api.model.DebuggerMemoryMapper;
+import ghidra.debug.api.model.TraceRecorder;
+import ghidra.debug.api.tracemgr.DebuggerCoordinates;
 import ghidra.framework.model.Project;
 import ghidra.framework.options.AutoOptions;
 import ghidra.framework.options.SaveState;
@@ -132,7 +134,9 @@ public class DebuggerObjectsProvider extends ComponentProviderAdapter
 	@SuppressWarnings("unused")
 	private final AutoService.Wiring autoServiceWiring;
 
-	@AutoOptionDefined(name = "Default Extended Step", description = "The default string for the extended step command")
+	@AutoOptionDefined(
+		name = "Default Extended Step",
+		description = "The default string for the extended step command")
 	String extendedStep = "";
 
 	@SuppressWarnings("unused")
@@ -490,7 +494,7 @@ public class DebuggerObjectsProvider extends ComponentProviderAdapter
 	public void addTable(ObjectContainer container) {
 		AtomicReference<ObjectContainer> update = new AtomicReference<>();
 		AsyncUtils.sequence(TypeSpec.cls(ObjectContainer.class)).then(seq -> {
-			container.getOffspring().handle(seq::next);
+			container.getOffspring(RefreshBehavior.REFRESH_WHEN_ABSENT).handle(seq::next);
 		}, update).then(seq -> {
 			try {
 				ObjectContainer oc = update.get();
@@ -546,7 +550,7 @@ public class DebuggerObjectsProvider extends ComponentProviderAdapter
 		for (Object obj : map.values()) {
 			if (obj instanceof TargetObject) {
 				TargetObject ref = (TargetObject) obj;
-				ref.fetchAttributes(true).thenAccept(attrs -> {
+				ref.fetchAttributes(RefreshBehavior.REFRESH_ALWAYS).thenAccept(attrs -> {
 					table.setColumns();
 					// TODO: What with attrs?
 				}).exceptionally(ex -> {
@@ -703,7 +707,7 @@ public class DebuggerObjectsProvider extends ComponentProviderAdapter
 		plugin.fireObjectUpdated(object);
 	}
 
-	class ObjectActionContext extends ActionContext {
+	class ObjectActionContext extends DefaultActionContext {
 
 		private DebuggerObjectsProvider provider;
 
@@ -1241,9 +1245,14 @@ public class DebuggerObjectsProvider extends ComponentProviderAdapter
 	public void performRefresh(ActionContext context) {
 		TargetObject current = getObjectFromContext(context);
 		if (current != null) {
+			current.resync(RefreshBehavior.REFRESH_ALWAYS, RefreshBehavior.REFRESH_ALWAYS);
 			refresh(current.getName());
 		}
 		else {
+			TargetObject modelRoot = getModel().getModelRoot();
+			if (modelRoot != null) {
+				modelRoot.resync(RefreshBehavior.REFRESH_ALWAYS, RefreshBehavior.REFRESH_ALWAYS);
+			}
 			refresh();
 		}
 	}
@@ -1383,7 +1392,7 @@ public class DebuggerObjectsProvider extends ComponentProviderAdapter
 			}
 			attachDialog.fetchAndDisplayAttachable();
 			tool.showDialog(attachDialog);
-			return AsyncUtils.NIL;
+			return AsyncUtils.nil();
 		}, "Couldn't attach");
 	}
 
@@ -1411,7 +1420,15 @@ public class DebuggerObjectsProvider extends ComponentProviderAdapter
 			list.toArray(new String[] {}), lastMethod, OptionDialog.QUESTION_MESSAGE);
 		if (choice != null) {
 			TargetMethod method = (TargetMethod) attributes.get(choice);
-			Map<String, ?> args = methodDialog.promptArguments(method.getParameters());
+			TargetParameterMap parameters = method.getParameters();
+			if (parameters.isEmpty()) {
+				method.invoke(new HashMap<String, Object>());
+				if (!choice.equals("unload")) {
+					lastMethod = choice;
+				}
+				return;
+			}
+			Map<String, ?> args = methodDialog.promptArguments(parameters);
 			if (args != null) {
 				String script = (String) args.get("Script");
 				if (script != null && !script.isEmpty()) {
@@ -1531,7 +1548,7 @@ public class DebuggerObjectsProvider extends ComponentProviderAdapter
 			if (valid != null) {
 				startRecording(valid, true);
 			}
-			return AsyncUtils.NIL;
+			return AsyncUtils.nil();
 		}, "Couldn't record");
 	}
 
@@ -1574,7 +1591,7 @@ public class DebuggerObjectsProvider extends ComponentProviderAdapter
 		performAction(context, false, TargetBreakpointSpecContainer.class, container -> {
 			breakpointDialog.setContainer(container);
 			tool.showDialog(breakpointDialog);
-			return AsyncUtils.NIL;
+			return AsyncUtils.nil();
 		}, "Couldn't set breakpoint");
 	}
 
@@ -1604,12 +1621,12 @@ public class DebuggerObjectsProvider extends ComponentProviderAdapter
 			Map<String, ParameterDescription<?>> configParameters =
 				configurable.getConfigurableOptions();
 			if (configParameters.isEmpty()) {
-				return AsyncUtils.NIL;
+				return AsyncUtils.nil();
 			}
 			Map<String, ?> args = configDialog.promptArguments(configParameters);
 			if (args == null) {
 				// User cancelled
-				return AsyncUtils.NIL;
+				return AsyncUtils.nil();
 			}
 			AsyncFence fence = new AsyncFence();
 			for (Entry<String, ?> entry : args.entrySet()) {
@@ -1625,14 +1642,14 @@ public class DebuggerObjectsProvider extends ComponentProviderAdapter
 			if (t != null) {
 				navigateToSelectedObject(t, null);
 			}
-			return AsyncUtils.NIL;
+			return AsyncUtils.nil();
 		}, "Couldn't navigate");
 	}
 
 	public void initiateConsole(ActionContext context) {
 		performAction(context, false, TargetInterpreter.class, interpreter -> {
 			getPlugin().showConsole(interpreter);
-			return AsyncUtils.NIL;
+			return AsyncUtils.nil();
 		}, "Couldn't show interpreter");
 	}
 
