@@ -23,7 +23,6 @@ import java.util.List;
 import java.util.Map.Entry;
 import java.util.concurrent.CompletableFuture;
 import java.util.function.*;
-import java.util.stream.Collectors;
 
 import javax.swing.*;
 import javax.swing.table.TableColumn;
@@ -31,6 +30,7 @@ import javax.swing.table.TableColumnModel;
 
 import org.apache.commons.lang3.exception.ExceptionUtils;
 
+import db.Transaction;
 import docking.*;
 import docking.action.*;
 import docking.action.builder.ActionBuilder;
@@ -40,19 +40,17 @@ import docking.widgets.table.ColumnSortState.SortDirection;
 import docking.widgets.table.DefaultEnumeratedColumnTableModel.EnumeratedTableColumn;
 import generic.theme.GColor;
 import ghidra.app.plugin.core.data.DataSettingsDialog;
-import ghidra.app.plugin.core.debug.DebuggerCoordinates;
 import ghidra.app.plugin.core.debug.DebuggerPluginPackage;
 import ghidra.app.plugin.core.debug.gui.DebuggerProvider;
 import ghidra.app.plugin.core.debug.gui.DebuggerResources;
-import ghidra.app.plugin.core.debug.mapping.DebuggerRegisterMapper;
 import ghidra.app.services.*;
 import ghidra.app.services.DebuggerControlService.StateEditor;
 import ghidra.async.AsyncLazyValue;
 import ghidra.async.AsyncUtils;
 import ghidra.base.widgets.table.DataTypeTableCellEditor;
 import ghidra.dbg.error.DebuggerModelAccessException;
-import ghidra.dbg.target.TargetRegisterBank;
-import ghidra.dbg.target.TargetThread;
+import ghidra.debug.api.target.Target;
+import ghidra.debug.api.tracemgr.DebuggerCoordinates;
 import ghidra.docking.settings.Settings;
 import ghidra.framework.model.DomainObject;
 import ghidra.framework.model.DomainObjectChangeRecord;
@@ -75,10 +73,10 @@ import ghidra.trace.model.target.TraceObject;
 import ghidra.trace.model.thread.TraceThread;
 import ghidra.trace.util.TraceAddressSpace;
 import ghidra.trace.util.TraceRegisterUtils;
-import ghidra.util.*;
+import ghidra.util.HelpLocation;
+import ghidra.util.Msg;
 import ghidra.util.classfinder.ClassSearcher;
 import ghidra.util.data.DataTypeParser.AllowedDataTypes;
-import ghidra.util.database.UndoableTransaction;
 import ghidra.util.exception.CancelledException;
 import ghidra.util.table.GhidraTable;
 import ghidra.util.table.GhidraTableFilterPanel;
@@ -236,7 +234,7 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 		if (!Objects.equals(a.getPlatform(), b.getPlatform())) {
 			return false; // subsumes trace
 		}
-		if (!Objects.equals(a.getRecorder(), b.getRecorder())) {
+		if (!Objects.equals(a.getTarget(), b.getTarget())) {
 			return false; // For live read/writes
 		}
 		if (!Objects.equals(a.getThread(), b.getThread())) {
@@ -309,9 +307,9 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 		}
 
 		private void refreshRange(AddressRange range) {
-			TraceMemorySpace space = getRegisterMemorySpace(false);
+			TraceMemorySpace mem = getRegisterMemorySpace(range.getAddressSpace(), false);
 			// ...   If I got an event for it, it ought to exist.
-			assert space != null;
+			assert mem != null;
 
 			// TODO: Just certain rows?
 			regsTableModel.fireTableDataChanged();
@@ -389,18 +387,6 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 		}
 	}
 
-	class RegAccessListener implements TraceRecorderListener {
-		@Override
-		public void registerBankMapped(TraceRecorder recorder) {
-			Swing.runIfSwingOrRunLater(() -> loadValues());
-		}
-
-		@Override
-		public void registerAccessibilityChanged(TraceRecorder recorder) {
-			Swing.runIfSwingOrRunLater(() -> loadValues());
-		}
-	}
-
 	class RegisterValueCellRenderer extends HexBigIntegerTableCellRenderer {
 		@Override
 		public final Component getTableCellRendererComponent(GTableCellRenderingData data) {
@@ -450,8 +436,7 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 			if (dataType == null) {
 				return null;
 			}
-			try (UndoableTransaction tid =
-				UndoableTransaction.start(currentTrace, "Resolve DataType")) {
+			try (Transaction tx = currentTrace.openTransaction("Resolve DataType")) {
 				return currentTrace.getDataTypeManager().resolve(dataType, null);
 			}
 		}
@@ -467,10 +452,7 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 	private AsyncLazyValue<Void> readTheseCoords =
 		new AsyncLazyValue<>(this::readRegistersIfLiveAndAccessible); /* "read" past tense */
 	private Trace currentTrace; // Copy for transition
-	private TraceRecorder currentRecorder; // Copy for transition
 
-	@AutoServiceConsumed
-	private DebuggerModelService modelService;
 	@AutoServiceConsumed
 	private DebuggerTraceManagerService traceManager;
 	@AutoServiceConsumed
@@ -486,7 +468,6 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 	private final AutoOptions.Wiring autoOptionsWiring;
 
 	private final TraceChangeListener traceChangeListener = new TraceChangeListener();
-	private final RegAccessListener regAccessListener = new RegAccessListener();
 
 	private JPanel mainPanel = new JPanel(new BorderLayout());
 
@@ -634,8 +615,8 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 			catch (AddressOutOfBoundsException e) {
 				continue;
 			}
-			if (currentTrace.getMemoryManager()
-					.getRegionContaining(current.getSnap(), address) == null) {
+			// Use program view, not memory manager, so that "Force Full View" is respected.
+			if (!currentTrace.getProgramView().getMemory().contains(address)) {
 				continue;
 			}
 			String name = "Goto " + address.toString(true);
@@ -790,29 +771,6 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 		addNewTraceListener();
 	}
 
-	private void removeOldRecorderListener() {
-		if (currentRecorder == null) {
-			return;
-		}
-		currentRecorder.removeListener(regAccessListener);
-	}
-
-	private void addNewRecorderListener() {
-		if (currentRecorder == null) {
-			return;
-		}
-		currentRecorder.addListener(regAccessListener);
-	}
-
-	private void doSetRecorder(TraceRecorder recorder) {
-		if (currentRecorder == recorder) {
-			return;
-		}
-		removeOldRecorderListener();
-		this.currentRecorder = recorder;
-		addNewRecorderListener();
-	}
-
 	public void coordinatesActivated(DebuggerCoordinates coordinates) {
 		if (sameCoordinates(current, coordinates)) {
 			current = coordinates;
@@ -822,16 +780,14 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 		previous = current;
 		current = coordinates;
 
-		readTheseCoords = new AsyncLazyValue<>(this::readRegistersIfLiveAndAccessible);
+		readTheseCoords.forget();
 		doSetTrace(current.getTrace());
-		doSetRecorder(current.getRecorder());
 		updateSubTitle();
 
 		prepareRegisterSpace();
 		recomputeViewKnown();
 		loadRegistersAndValues();
 		contextChanged();
-		//checkEditsEnabled();
 	}
 
 	protected void traceClosed(Trace trace) {
@@ -855,7 +811,7 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 	}
 
 	BigInteger getRegisterValue(Register register) {
-		TraceMemorySpace regs = getRegisterMemorySpace(false);
+		TraceMemorySpace regs = getRegisterMemorySpace(register.getAddressSpace(), false);
 		if (regs == null) {
 			return BigInteger.ZERO;
 		}
@@ -902,8 +858,7 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 	 * register and modify it.... Well, that works until you consider changes in time....
 	 */
 	void writeRegisterDataType(Register register, DataType dataType) {
-		try (UndoableTransaction tid =
-			UndoableTransaction.start(current.getTrace(), "Edit Register Type")) {
+		try (Transaction tx = current.getTrace().openTransaction("Edit Register Type")) {
 			if (dataType instanceof Pointer ptrType && register.getAddress().isRegisterAddress()) {
 				// Because we're about to use the size, resolve it first
 				ptrType = (Pointer) current.getTrace()
@@ -925,13 +880,14 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 				dataType = new PointerTypedef(null, ptrType.getDataType(), ptrType.getLength(),
 					ptrType.getDataTypeManager(), space);
 			}
-			TraceCodeSpace space = getRegisterMemorySpace(true).getCodeSpace(true);
+			TraceCodeSpace code =
+				getRegisterMemorySpace(register.getAddressSpace(), true).getCodeSpace(true);
 			long snap = current.getViewSnap();
 			TracePlatform platform = current.getPlatform();
-			space.definedUnits()
+			code.definedUnits()
 					.clear(platform, Lifespan.at(snap), register, TaskMonitor.DUMMY);
 			if (dataType != null) {
-				space.definedData().create(platform, Lifespan.nowOn(snap), register, dataType);
+				code.definedData().create(platform, Lifespan.nowOn(snap), register, dataType);
 			}
 		}
 		catch (CodeUnitInsertionException | CancelledException e) {
@@ -940,7 +896,7 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 	}
 
 	TraceData getRegisterData(Register register) {
-		TraceCodeSpace space = getRegisterCodeSpace(false);
+		TraceCodeSpace space = getRegisterCodeSpace(register.getAddressSpace(), false);
 		if (space == null) {
 			return null;
 		}
@@ -1002,11 +958,13 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 	 * values are populated.
 	 */
 	void prepareRegisterSpace() {
-		if (current.getThread() != null &&
-			current.getTrace().getObjectManager().getRootSchema() != null) {
-			try (UndoableTransaction tid =
-				UndoableTransaction.start(current.getTrace(), "Create/initialize register space")) {
-				getRegisterMemorySpace(true);
+		Trace trace = current.getTrace();
+		if (current.getThread() != null && trace.getObjectManager().getRootSchema() != null) {
+			AddressSpace regSpace = current.getPlatform().getAddressFactory().getRegisterSpace();
+			if (regSpace != null) {
+				try (Transaction tx = trace.openTransaction("Create/initialize register space")) {
+					getRegisterMemorySpace(regSpace, true);
+				}
 			}
 		}
 	}
@@ -1023,17 +981,21 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 			return;
 		}
 		TraceMemoryManager mem = current.getTrace().getMemoryManager();
+		AddressSetView guestRegs = platform.getLanguage().getRegisterAddresses();
+		AddressSetView hostRegs = platform.mapGuestToHost(guestRegs);
 		AddressSetView viewKnownMem = view.getViewport()
-				.unionedAddresses(snap -> mem.getAddressesWithState(snap,
-					platform.mapGuestToHost(platform.getLanguage().getRegisterAddresses()),
+				.unionedAddresses(snap -> mem.getAddressesWithState(snap, hostRegs,
 					state -> state == TraceMemoryState.KNOWN));
-		TraceMemorySpace regs = getRegisterMemorySpace(false);
+		AddressSpace regSpace = platform.getAddressFactory().getRegisterSpace();
+		if (regSpace == null) {
+			viewKnown = new AddressSet(viewKnownMem);
+			return;
+		}
+		TraceMemorySpace regs = getRegisterMemorySpace(current, regSpace, false);
 		if (regs == null) {
 			viewKnown = new AddressSet(viewKnownMem);
 			return;
 		}
-		AddressSetView hostRegs =
-			platform.mapGuestToHost(platform.getLanguage().getRegisterAddresses());
 		AddressSetView overlayRegs =
 			TraceRegisterUtils.getOverlaySet(regs.getAddressSpace(), hostRegs);
 		AddressSetView viewKnownRegs = view.getViewport()
@@ -1046,7 +1008,7 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 		if (viewKnown == null) {
 			return false;
 		}
-		TraceMemorySpace regs = getRegisterMemorySpace(false);
+		TraceMemorySpace regs = getRegisterMemorySpace(current, register.getAddressSpace(), false);
 		if (regs == null && register.getAddressSpace().isRegisterSpace()) {
 			return false;
 		}
@@ -1065,8 +1027,10 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 		if (!isRegisterKnown(register)) {
 			return false;
 		}
-		TraceMemorySpace curSpace = getRegisterMemorySpace(current, false);
-		TraceMemorySpace prevSpace = getRegisterMemorySpace(previous, false);
+		TraceMemorySpace curSpace =
+			getRegisterMemorySpace(current, register.getAddressSpace(), false);
+		TraceMemorySpace prevSpace =
+			getRegisterMemorySpace(previous, register.getAddressSpace(), false);
 		if (prevSpace == null) {
 			return false;
 		}
@@ -1128,7 +1092,12 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 	}
 
 	protected static TraceMemorySpace getRegisterMemorySpace(DebuggerCoordinates coords,
-			boolean createIfAbsent) {
+			AddressSpace space, boolean createIfAbsent) {
+		if (!space.isRegisterSpace()) {
+			return coords.getTrace()
+					.getMemoryManager()
+					.getMemorySpace(space, createIfAbsent);
+		}
 		TraceThread thread = coords.getThread();
 		if (thread == null) {
 			return null;
@@ -1138,18 +1107,29 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 				.getMemoryRegisterSpace(thread, coords.getFrame(), createIfAbsent);
 	}
 
-	protected TraceMemorySpace getRegisterMemorySpace(boolean createIfAbsent) {
-		return getRegisterMemorySpace(current, createIfAbsent);
+	protected TraceMemorySpace getRegisterMemorySpace(AddressSpace space,
+			boolean createIfAbsent) {
+		return getRegisterMemorySpace(current, space, createIfAbsent);
 	}
 
-	protected TraceCodeSpace getRegisterCodeSpace(boolean createIfAbsent) {
-		TraceThread curThread = current.getThread();
-		if (curThread == null) {
+	protected static TraceCodeSpace getRegisterCodeSpace(DebuggerCoordinates coords,
+			AddressSpace space, boolean createIfAbsent) {
+		if (!space.isRegisterSpace()) {
+			return coords.getTrace()
+					.getCodeManager()
+					.getCodeSpace(space, createIfAbsent);
+		}
+		TraceThread thread = coords.getThread();
+		if (thread == null) {
 			return null;
 		}
-		return current.getTrace()
+		return coords.getTrace()
 				.getCodeManager()
-				.getCodeRegisterSpace(curThread, current.getFrame(), createIfAbsent);
+				.getCodeRegisterSpace(thread, coords.getFrame(), createIfAbsent);
+	}
+
+	protected TraceCodeSpace getRegisterCodeSpace(AddressSpace space, boolean createIfAbsent) {
+		return getRegisterCodeSpace(current, space, createIfAbsent);
 	}
 
 	protected Set<Register> collectBaseRegistersWithKnownValues(TraceThread thread) {
@@ -1268,7 +1248,7 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 		if (current.getThread() == null) {
 			regsTableModel.clear();
 			regMap.clear();
-			return AsyncUtils.NIL;
+			return AsyncUtils.nil();
 		}
 		Set<Register> selected = getSelectionFor(current.getPlatform());
 		displaySelectedRegisters(selected);
@@ -1278,70 +1258,21 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 	protected CompletableFuture<Void> loadValues() {
 		TraceThread curThread = current.getThread();
 		if (curThread == null) {
-			return AsyncUtils.NIL;
+			return AsyncUtils.nil();
 		}
 		regsTableModel.fireTableDataChanged();
-		//return AsyncUtils.NIL;
-		// In case we need to read a non-zero frame
 		return readTheseCoords.request();
 	}
 
-	private Set<Register> baseRegisters(Set<Register> regs) {
-		return regs.stream().filter(Register::isBaseRegister).collect(Collectors.toSet());
-	}
-
-	protected CompletableFuture<?> readRegistersLegacy(TraceRecorder recorder,
-			TraceThread traceThread, Set<Register> toRead) {
-		DebuggerRegisterMapper regMapper = recorder.getRegisterMapper(traceThread);
-		if (regMapper == null) {
-			Msg.error(this, "Target is live, but we haven't got a register mapper, yet");
-			return AsyncUtils.NIL;
-		}
-		toRead.retainAll(regMapper.getRegistersOnTarget());
-		Set<TargetRegisterBank> banks =
-			recorder.getTargetRegisterBanks(traceThread, current.getFrame());
-		if (banks == null || banks.isEmpty()) {
-			Msg.error(this, "Current frame's bank does not exist");
-			return AsyncUtils.NIL;
-		}
-		// TODO: Should probably always be the host platform. I suspect it's ignored anyway.
-		return recorder.captureThreadRegisters(current.getPlatform(), traceThread,
-			current.getFrame(), toRead);
-	}
-
-	protected CompletableFuture<?> readRegistersObjectMode(TraceRecorder recorder,
-			TraceThread traceThread, Set<Register> toRead) {
-		return recorder.captureThreadRegisters(current.getPlatform(), traceThread,
-			current.getFrame(), toRead);
-	}
-
 	protected CompletableFuture<Void> readRegistersIfLiveAndAccessible() {
-		TraceRecorder recorder = current.getRecorder();
-		if (recorder == null) {
-			return AsyncUtils.NIL;
-		}
-		if (recorder.getSnap() != current.getSnap()) {
-			return AsyncUtils.NIL;
-		}
-//		if (current.getFrame() == 0) {
-//			// Should have been pushed by model. non-zero frames are poll-only
-//			return AsyncUtils.NIL;
-//		}
-		TraceThread traceThread = current.getThread();
-		TargetThread targetThread = recorder.getTargetThread(traceThread);
-		if (targetThread == null) {
-			return AsyncUtils.NIL;
+		Target target = current.getTarget();
+		if (!current.isAliveAndReadsPresent()) {
+			return AsyncUtils.nil();
 		}
 
-		Set<Register> toRead = new HashSet<>(baseRegisters(getSelectionFor(current.getPlatform())));
-
-		CompletableFuture<?> future;
-		if (current.getTrace().getObjectManager().getRootSchema() == null) {
-			future = readRegistersLegacy(recorder, traceThread, toRead);
-		}
-		else {
-			future = readRegistersObjectMode(recorder, traceThread, toRead);
-		}
+		Set<Register> registers = getSelectionFor(current.getPlatform());
+		CompletableFuture<Void> future = target.readRegistersAsync(current.getPlatform(),
+			current.getThread(), current.getFrame(), registers);
 		return future.exceptionally(ex -> {
 			ex = AsyncUtils.unwrapThrowable(ex);
 			String msg = "Could not read target registers for selected thread: " + ex.getMessage();
@@ -1351,50 +1282,6 @@ public class DebuggerRegistersProvider extends ComponentProviderAdapter
 		}).thenApply(__ -> null);
 	}
 
-	protected String formatAddressInfo(Address address) {
-		return address.toString(); // TODO;
-		// TODO: Examine static mapped programs, too
-		/*Memory mem = program.getMemoryManager();
-		MemoryBlock addrBlock = mem.getBlock(address);
-		if (addrBlock == null) {
-			return "<INVALID>";
-		}
-		Function function = program.getFunctionManager().getFunctionContaining(address);
-		if (function != null) {
-			Address entry = function.getEntryPoint();
-			long diff = address.subtract(entry);
-			if (diff < 0) {
-				return function.getName() + "-" + (-diff);
-			}
-			if (diff > 0) {
-				return function.getName() + "+" + diff;
-			}
-			return function.getName();
-		}
-		Data defData = program.getListing().getDefinedDataContaining(address);
-		if (defData != null) {
-			// Use existing mechanism
-			return SymbolUtilities.getDynamicName(program, address);
-		}
-		// It is either undefined or an instruction outside a function
-		SymbolTable table = program.getSymbolTable();
-		Symbol primary = table.getPrimarySymbol(address);
-		if (primary != null) {
-			return primary.getName();
-		}
-		Symbol before = table.getSymbolIterator(address, false).next();
-		if (before != null) {
-			MemoryBlock symBlock = mem.getBlock(before.getAddress());
-			if (addrBlock == symBlock) {
-				long diff = address.subtract(before.getAddress());
-				return before.getName() + "+" + diff;
-			}
-		}
-		// TODO: Making an assumption about block name here. Generally true, but user can fuddle.
-		String moduleName = addrBlock.getName().split(":")[0];
-		return address.toString(moduleName + ":");*/
-	}
-
 	public void writeDataState(SaveState saveState) {
 		if (isClone) {
 			current.writeDataState(tool, saveState, KEY_DEBUGGER_COORDINATES);
