@@ -24,15 +24,17 @@ import java.util.concurrent.CancellationException;
 import java.util.concurrent.CompletableFuture;
 import java.util.stream.Collectors;
 
+import javax.swing.Icon;
 import javax.swing.JOptionPane;
 
 import org.jdom.Element;
 import org.jdom.JDOMException;
 
+import db.Transaction;
+import ghidra.app.plugin.core.debug.gui.DebuggerResources;
 import ghidra.app.plugin.core.debug.gui.objects.components.DebuggerMethodInvocationDialog;
 import ghidra.app.services.*;
 import ghidra.app.services.DebuggerTraceManagerService.ActivationCause;
-import ghidra.app.services.ModuleMapProposal.ModuleMapEntry;
 import ghidra.async.*;
 import ghidra.dbg.*;
 import ghidra.dbg.target.*;
@@ -41,6 +43,10 @@ import ghidra.dbg.target.TargetMethod.ParameterDescription;
 import ghidra.dbg.target.TargetMethod.TargetParameterMap;
 import ghidra.dbg.target.schema.TargetObjectSchema;
 import ghidra.dbg.util.PathUtils;
+import ghidra.debug.api.model.DebuggerProgramLaunchOffer;
+import ghidra.debug.api.model.TraceRecorder;
+import ghidra.debug.api.modules.*;
+import ghidra.debug.api.modules.ModuleMapProposal.ModuleMapEntry;
 import ghidra.framework.model.DomainFile;
 import ghidra.framework.options.SaveState;
 import ghidra.framework.plugintool.AutoConfigState.ConfigStateField;
@@ -53,7 +59,6 @@ import ghidra.trace.model.TraceLocation;
 import ghidra.trace.model.modules.TraceModule;
 import ghidra.util.Msg;
 import ghidra.util.Swing;
-import ghidra.util.database.UndoableTransaction;
 import ghidra.util.datastruct.CollectionChangeListener;
 import ghidra.util.exception.CancelledException;
 import ghidra.util.task.TaskMonitor;
@@ -77,6 +82,11 @@ public abstract class AbstractDebuggerProgramLaunchOffer implements DebuggerProg
 		this.factory = factory;
 	}
 
+	@Override
+	public Icon getIcon() {
+		return DebuggerResources.ICON_DEBUGGER;
+	}
+
 	@Override
 	public String getMenuParentTitle() {
 		String name = program.getName();
@@ -243,7 +253,7 @@ public abstract class AbstractDebuggerProgramLaunchOffer implements DebuggerProg
 		}
 		if (program != null) {
 			ProgramUserData userData = program.getProgramUserData();
-			try (UndoableTransaction tid = UndoableTransaction.start(userData)) {
+			try (Transaction tx = userData.openTransaction()) {
 				Element element = state.saveToXml();
 				userData.setStringProperty(TargetCmdLineLauncher.CMDLINE_ARGS_NAME,
 					XmlUtilities.toString(element));
@@ -275,7 +285,8 @@ public abstract class AbstractDebuggerProgramLaunchOffer implements DebuggerProg
 		for (Entry<String, ParameterDescription<?>> entry : params.entrySet()) {
 			map.put(entry.getKey(), entry.getValue().defaultValue);
 		}
-		map.put(TargetCmdLineLauncher.CMDLINE_ARGS_NAME, program.getExecutablePath());
+		map.put(TargetCmdLineLauncher.CMDLINE_ARGS_NAME,
+			TargetCmdLineLauncher.quoteImagePathIfSpaces(program.getExecutablePath()));
 		return map;
 	}
 
