@@ -21,11 +21,9 @@ import java.util.*;
 import java.util.concurrent.CompletableFuture;
 import java.util.stream.Collectors;
 
-import ghidra.app.plugin.core.debug.mapping.*;
-import ghidra.app.plugin.core.debug.service.model.DebuggerModelServicePlugin;
+import db.Transaction;
+import ghidra.app.plugin.core.debug.mapping.ObjectBasedDebuggerTargetTraceMapper;
 import ghidra.app.plugin.core.debug.service.model.PermanentTransactionExecutor;
-import ghidra.app.services.TraceRecorder;
-import ghidra.app.services.TraceRecorderListener;
 import ghidra.async.AsyncFence;
 import ghidra.async.AsyncUtils;
 import ghidra.dbg.AnnotatedDebuggerAttributeListener;
@@ -37,6 +35,8 @@ import ghidra.dbg.target.TargetEventScope.TargetEventType;
 import ghidra.dbg.target.TargetExecutionStateful.TargetExecutionState;
 import ghidra.dbg.util.PathMatcher;
 import ghidra.dbg.util.PathUtils;
+import ghidra.debug.api.model.*;
+import ghidra.framework.plugintool.PluginTool;
 import ghidra.pcode.utils.Utils;
 import ghidra.program.model.address.*;
 import ghidra.program.model.lang.Register;
@@ -52,11 +52,11 @@ import ghidra.trace.model.modules.*;
 import ghidra.trace.model.stack.TraceObjectStackFrame;
 import ghidra.trace.model.stack.TraceStackFrame;
 import ghidra.trace.model.target.TraceObject;
+import ghidra.trace.model.target.TraceObjectKeyPath;
 import ghidra.trace.model.thread.TraceObjectThread;
 import ghidra.trace.model.thread.TraceThread;
 import ghidra.trace.model.time.TraceSnapshot;
 import ghidra.util.Msg;
-import ghidra.util.database.UndoableTransaction;
 import ghidra.util.datastruct.ListenerSet;
 import ghidra.util.task.TaskMonitor;
 
@@ -81,7 +81,7 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 	protected final ListenerForRecord listenerForRecord;
 
 	protected final ListenerSet<TraceRecorderListener> listeners =
-		new ListenerSet<>(TraceRecorderListener.class);
+		new ListenerSet<>(TraceRecorderListener.class, true);
 
 	// TODO: I don't like this here. Should ask the model, not the recorder.
 	protected TargetObject curFocus;
@@ -193,8 +193,7 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 			long snap = timeRecorder.getSnap();
 			String path = object.getJoinedPath(".");
 			// Don't offload, because we need a consistent map
-			try (UndoableTransaction tid =
-				UndoableTransaction.start(trace, "Object created: " + path)) {
+			try (Transaction trans = trace.openTransaction("Object created: " + path)) {
 				objectRecorder.recordCreated(snap, object);
 			}
 		}
@@ -271,8 +270,8 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 		}
 	}
 
-	public ObjectBasedTraceRecorder(DebuggerModelServicePlugin service, Trace trace,
-			TargetObject target, ObjectBasedDebuggerTargetTraceMapper mapper) {
+	public ObjectBasedTraceRecorder(PluginTool tool, Trace trace, TargetObject target,
+			ObjectBasedDebuggerTargetTraceMapper mapper) {
 		trace.addConsumer(this);
 		this.trace = trace;
 		this.target = target;
@@ -296,7 +295,7 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 		// TODO: Make this method synchronous?
 		timeRecorder.createSnapshot("Started recording " + target.getModel(), null, null);
 		target.getModel().addModelListener(listenerForRecord, true);
-		return AsyncUtils.NIL;
+		return AsyncUtils.nil();
 	}
 
 	@Override
@@ -361,6 +360,11 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 		return objectRecorder.toTrace(obj);
 	}
 
+	@Override
+	public TargetObject getTargetObject(TraceObjectKeyPath path) {
+		return target.getModel().getModelObject(path.getKeyList());
+	}
+
 	@Override
 	public TargetBreakpointLocation getTargetBreakpoint(TraceBreakpoint bpt) {
 		return objectRecorder.getTargetInterface(bpt, TraceObjectBreakpointLocation.class,
@@ -470,7 +474,7 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 	public Set<TargetThread> getLiveTargetThreads() {
 		return trace.getObjectManager()
 				.getRootObject()
-				.querySuccessorsInterface(Lifespan.at(getSnap()), TraceObjectThread.class)
+				.querySuccessorsInterface(Lifespan.at(getSnap()), TraceObjectThread.class, true)
 				.map(t -> objectRecorder.getTargetInterface(t.getObject(), TargetThread.class))
 				.collect(Collectors.toSet());
 	}
@@ -534,7 +538,7 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 		 * what communicates that convention?
 		 */
 		if (regContainer == null) {
-			return AsyncUtils.NIL;
+			return AsyncUtils.nil();
 		}
 		return regContainer.resync();
 	}
@@ -594,7 +598,7 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 			int frameLevel, Map<Register, RegisterValue> values) {
 		TargetRegisterContainer regContainer = getTargetRegisterContainer(thread, frameLevel);
 		if (regContainer == null) {
-			return AsyncUtils.NIL;
+			return AsyncUtils.nil();
 		}
 		Map<TargetRegisterBank, Map<TargetRegister, byte[]>> writesByBank = new HashMap<>();
 		for (RegisterValue rv : values.values()) {
@@ -673,9 +677,10 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 	public List<TargetBreakpointSpecContainer> collectBreakpointContainers(TargetThread thread) {
 		if (thread == null) {
 			return objectRecorder.collectTargetSuccessors(target,
-				TargetBreakpointSpecContainer.class);
+				TargetBreakpointSpecContainer.class, false);
 		}
-		return objectRecorder.collectTargetSuccessors(thread, TargetBreakpointSpecContainer.class);
+		return objectRecorder.collectTargetSuccessors(thread, TargetBreakpointSpecContainer.class,
+			false);
 	}
 
 	private class BreakpointConvention {
@@ -711,7 +716,8 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 	@Override
 	public List<TargetBreakpointLocation> collectBreakpoints(TargetThread thread) {
 		if (thread == null) {
-			return objectRecorder.collectTargetSuccessors(target, TargetBreakpointLocation.class);
+			return objectRecorder.collectTargetSuccessors(target, TargetBreakpointLocation.class,
+				true);
 		}
 		BreakpointConvention convention = new BreakpointConvention(
 			objectRecorder.getTraceInterface(thread, TraceObjectThread.class));
@@ -725,7 +731,8 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 
 	@Override
 	public Set<TraceBreakpointKind> getSupportedBreakpointKinds() {
-		return objectRecorder.collectTargetSuccessors(target, TargetBreakpointSpecContainer.class)
+		return objectRecorder
+				.collectTargetSuccessors(target, TargetBreakpointSpecContainer.class, false)
 				.stream()
 				.flatMap(c -> c.getSupportedBreakpointKinds().stream())
 				.map(k -> TraceRecorder.targetToTraceBreakpointKind(k))
@@ -750,7 +757,7 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 	@Override
 	public CompletableFuture<Boolean> requestFocus(TargetObject focus) {
 		for (TargetFocusScope scope : objectRecorder.collectTargetSuccessors(target,
-			TargetFocusScope.class)) {
+			TargetFocusScope.class, false)) {
 			if (PathUtils.isAncestor(scope.getPath(), focus.getPath())) {
 				return scope.requestFocus(focus).thenApply(__ -> true).exceptionally(ex -> {
 					ex = AsyncUtils.unwrapThrowable(ex);
@@ -772,7 +779,7 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 	@Override
 	public CompletableFuture<Boolean> requestActivation(TargetObject active) {
 		for (TargetActiveScope scope : objectRecorder.collectTargetSuccessors(target,
-			TargetActiveScope.class)) {
+			TargetActiveScope.class, false)) {
 			if (PathUtils.isAncestor(scope.getPath(), active.getPath())) {
 				return scope.requestActivation(active).thenApply(__ -> true).exceptionally(ex -> {
 					ex = AsyncUtils.unwrapThrowable(ex);
@@ -798,11 +805,11 @@ public class ObjectBasedTraceRecorder implements TraceRecorder {
 	}
 
 	protected void fireSnapAdvanced(long key) {
-		listeners.fire.snapAdvanced(this, key);
+		listeners.invoke().snapAdvanced(this, key);
 	}
 
 	protected void fireRecordingStopped() {
-		listeners.fire.recordingStopped(this);
+		listeners.invoke().recordingStopped(this);
 	}
 
 	// TODO: Deprecate/remove the other callbacks: registerBankMapped, *accessibilityChanged
