@@ -27,13 +27,13 @@ import java.util.stream.Collectors;
 
 import org.junit.*;
 
+import db.Transaction;
 import docking.action.DockingActionIf;
 import generic.Unique;
 import ghidra.app.context.ListingActionContext;
 import ghidra.app.plugin.core.assembler.AssemblerPluginTestHelper;
 import ghidra.app.plugin.core.debug.gui.AbstractGhidraHeadedDebuggerGUITest;
-import ghidra.app.plugin.core.debug.gui.listing.DebuggerListingPlugin;
-import ghidra.app.plugin.core.debug.gui.listing.DebuggerListingProvider;
+import ghidra.app.plugin.core.debug.gui.listing.*;
 import ghidra.app.plugin.core.debug.service.control.DebuggerControlServicePlugin;
 import ghidra.app.plugin.core.debug.service.platform.DebuggerPlatformServicePlugin;
 import ghidra.app.plugin.core.debug.service.workflow.DebuggerWorkflowServiceProxyPlugin;
@@ -42,6 +42,8 @@ import ghidra.app.services.*;
 import ghidra.dbg.target.TargetEnvironment;
 import ghidra.dbg.target.schema.SchemaContext;
 import ghidra.dbg.target.schema.TargetObjectSchema.SchemaName;
+import ghidra.debug.api.control.ControlMode;
+import ghidra.debug.api.workflow.DebuggerBot;
 import ghidra.dbg.target.schema.XmlSchemaContext;
 import ghidra.program.model.address.Address;
 import ghidra.program.model.address.AddressSet;
@@ -54,19 +56,18 @@ import ghidra.trace.database.listing.DBTraceInstruction;
 import ghidra.trace.database.listing.DBTraceInstructionsMemoryView;
 import ghidra.trace.database.memory.DBTraceMemoryManager;
 import ghidra.trace.database.memory.DBTraceMemorySpace;
-import ghidra.trace.database.program.DBTraceVariableSnapProgramView;
 import ghidra.trace.database.target.DBTraceObject;
 import ghidra.trace.database.target.DBTraceObjectManager;
 import ghidra.trace.model.Lifespan;
 import ghidra.trace.model.guest.TraceGuestPlatform;
 import ghidra.trace.model.memory.TraceMemoryFlag;
 import ghidra.trace.model.memory.TraceObjectMemoryRegion;
+import ghidra.trace.model.program.TraceProgramView;
 import ghidra.trace.model.stack.TraceObjectStackFrame;
 import ghidra.trace.model.target.TraceObject.ConflictResolution;
 import ghidra.trace.model.target.TraceObjectKeyPath;
 import ghidra.trace.model.thread.TraceObjectThread;
 import ghidra.trace.model.thread.TraceThread;
-import ghidra.util.database.UndoableTransaction;
 import ghidra.util.task.TaskMonitor;
 
 public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest {
@@ -145,12 +146,19 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 		workflowService.enableBots(disBot);
 	}
 
+	protected DebuggerListingActionContext createActionContext(Address start, int len) {
+		TraceProgramView view = tb.trace.getProgramView();
+		ProgramSelection sel = new ProgramSelection(start, start.addWrap(len - 1));
+		return new DebuggerListingActionContext(listingProvider, new ProgramLocation(view, start),
+			sel, null);
+	}
+
 	protected TraceObjectThread createPolyglotTrace(String arch, long offset,
 			Supplier<ByteBuffer> byteSupplier) throws IOException {
 		createAndOpenTrace("DATA:BE:64:default");
 
 		DBTraceObjectManager objects = tb.trace.getObjectManager();
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			objects.createRootObject(ctx.getSchema(new SchemaName("Session")));
 			DBTraceObject env =
 				objects.createObject(TraceObjectKeyPath.parse("Targets[0].Environment"));
@@ -190,7 +198,7 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 			Supplier<ByteBuffer> byteSupplier) throws Throwable {
 		createAndOpenTrace(langID);
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			DBTraceMemoryManager memory = tb.trace.getMemoryManager();
 			memory.createRegion("Memory[bin:.text]", 0, tb.range(offset, offset + 0xffff),
 				Set.of(TraceMemoryFlag.EXECUTE));
@@ -221,7 +229,7 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 
 		// Fabricate the cpsr so that ARM is used. Otherwise, it will assume Cortex-M, so THUMB
 		TraceThread thread;
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			thread = tb.getOrAddThread("Threads[0]", 0);
 			DBTraceMemorySpace regs =
 				tb.trace.getMemoryManager().getMemoryRegisterSpace(thread, true);
@@ -236,10 +244,7 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 		// Ensure the mapper is added to the trace
 		assertNotNull(platformService.getMapper(tb.trace, null, 0));
 
-		DBTraceVariableSnapProgramView view = tb.trace.getProgramView();
-		ListingActionContext actionContext = new ListingActionContext(listingProvider,
-			listingProvider, view, new ProgramLocation(view, start),
-			new ProgramSelection(start, start.addWrap(3)), null);
+		ListingActionContext actionContext = createActionContext(start, 4);
 		performAction(disassemblerPlugin.actionDisassemble, actionContext, true);
 		waitForTasks();
 
@@ -255,7 +260,7 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 
 		// Fabricate the cpsr so that THUMB is used, even though we could omit as in Cortex-M
 		TraceThread thread;
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			thread = tb.getOrAddThread("Threads[0]", 0);
 			DBTraceMemorySpace regs =
 				tb.trace.getMemoryManager().getMemoryRegisterSpace(thread, true);
@@ -271,10 +276,7 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 		// Ensure the mapper is added to the trace
 		assertNotNull(platformService.getMapper(tb.trace, null, 0));
 
-		DBTraceVariableSnapProgramView view = tb.trace.getProgramView();
-		ListingActionContext actionContext = new ListingActionContext(listingProvider,
-			listingProvider, view, new ProgramLocation(view, start),
-			new ProgramSelection(start, start.addWrap(3)), null);
+		ListingActionContext actionContext = createActionContext(start, 4);
 		performAction(disassemblerPlugin.actionDisassemble, actionContext, true);
 		waitForTasks();
 
@@ -297,10 +299,7 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 		// Ensure the mapper is added to the trace
 		assertNotNull(platformService.getMapper(tb.trace, thread.getObject(), 0));
 
-		DBTraceVariableSnapProgramView view = tb.trace.getProgramView();
-		ListingActionContext actionContext = new ListingActionContext(listingProvider,
-			listingProvider, view, new ProgramLocation(view, start),
-			new ProgramSelection(start, start.addWrap(3)), null);
+		ListingActionContext actionContext = createActionContext(start, 4);
 		performAction(disassemblerPlugin.actionDisassemble, actionContext, true);
 		waitForTasks();
 
@@ -324,10 +323,7 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 		// Ensure the mapper is added to the trace
 		assertNotNull(platformService.getMapper(tb.trace, thread.getObject(), 0));
 
-		DBTraceVariableSnapProgramView view = tb.trace.getProgramView();
-		ListingActionContext actionContext = new ListingActionContext(listingProvider,
-			listingProvider, view, new ProgramLocation(view, start),
-			new ProgramSelection(start, start.addWrap(3)), null);
+		ListingActionContext actionContext = createActionContext(start, 4);
 		performAction(disassemblerPlugin.actionDisassemble, actionContext, true);
 		waitForTasks();
 
@@ -339,10 +335,7 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 
 	protected void performFixedDisassembleAction(Address start,
 			Predicate<DockingActionIf> actionPred) {
-		DBTraceVariableSnapProgramView view = tb.trace.getProgramView();
-		ListingActionContext actionContext = new ListingActionContext(listingProvider,
-			listingProvider, view, new ProgramLocation(view, start),
-			new ProgramSelection(start, start.addWrap(3)), null);
+		ListingActionContext actionContext = createActionContext(start, 4);
 		DockingActionIf action =
 			runSwing(() -> Unique.assertOne(disassemblerPlugin.getPopupActions(tool, actionContext)
 					.stream()
@@ -414,16 +407,12 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 		// Ensure the mapper is added to the trace
 		assertNotNull(platformService.getMapper(tb.trace, null, 0));
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			tb.addInstruction(0, start, tb.host);
 		}
 		waitForDomainObject(tb.trace);
 
-		DBTraceVariableSnapProgramView view = tb.trace.getProgramView();
-		ListingActionContext actionContext = new ListingActionContext(listingProvider,
-			listingProvider, view, new ProgramLocation(view, start),
-			new ProgramSelection(start, start.addWrap(1)), null);
-
+		ListingActionContext actionContext = createActionContext(start, 2);
 		assertTrue(disassemblerPlugin.actionPatchInstruction.isEnabledForContext(actionContext));
 		DebuggerDisassemblerPluginTestHelper helper = new DebuggerDisassemblerPluginTestHelper(
 			disassemblerPlugin, listingProvider, tb.trace.getProgramView());
@@ -446,7 +435,7 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 		// Ensure the mapper is added to the trace
 		assertNotNull(platformService.getMapper(tb.trace, null, 0));
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			TraceDisassembleCommand dis = new TraceDisassembleCommand(tb.host, start,
 				new AddressSet(start, start.addWrap(1)));
 			dis.setInitialContext(DebuggerDisassemblerPlugin.deriveAlternativeDefaultContext(
@@ -455,11 +444,7 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 		}
 		waitForDomainObject(tb.trace);
 
-		DBTraceVariableSnapProgramView view = tb.trace.getProgramView();
-		ListingActionContext actionContext = new ListingActionContext(listingProvider,
-			listingProvider, view, new ProgramLocation(view, start),
-			new ProgramSelection(start, start.addWrap(1)), null);
-
+		ListingActionContext actionContext = createActionContext(start, 2);
 		assertTrue(disassemblerPlugin.actionPatchInstruction.isEnabledForContext(actionContext));
 		DebuggerDisassemblerPluginTestHelper helper = new DebuggerDisassemblerPluginTestHelper(
 			disassemblerPlugin, listingProvider, tb.trace.getProgramView());
@@ -484,16 +469,12 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 
 		TraceGuestPlatform guest =
 			Unique.assertOne(tb.trace.getPlatformManager().getGuestPlatforms());
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			tb.addInstruction(0, start, guest);
 		}
 		waitForDomainObject(tb.trace);
 
-		DBTraceVariableSnapProgramView view = tb.trace.getProgramView();
-		ListingActionContext actionContext = new ListingActionContext(listingProvider,
-			listingProvider, view, new ProgramLocation(view, start),
-			new ProgramSelection(start, start.addWrap(1)), null);
-
+		ListingActionContext actionContext = createActionContext(start, 2);
 		assertTrue(disassemblerPlugin.actionPatchInstruction.isEnabledForContext(actionContext));
 		DebuggerDisassemblerPluginTestHelper helper = new DebuggerDisassemblerPluginTestHelper(
 			disassemblerPlugin, listingProvider, tb.trace.getProgramView());
@@ -519,7 +500,7 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 		waitForPass(() -> Unique.assertOne(tb.trace.getPlatformManager().getGuestPlatforms()));
 		TraceGuestPlatform guest =
 			Unique.assertOne(tb.trace.getPlatformManager().getGuestPlatforms());
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			TraceDisassembleCommand dis = new TraceDisassembleCommand(guest, start,
 				new AddressSet(start, start.addWrap(1)));
 			dis.setInitialContext(DebuggerDisassemblerPlugin.deriveAlternativeDefaultContext(
@@ -528,11 +509,7 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 		}
 		waitForDomainObject(tb.trace);
 
-		DBTraceVariableSnapProgramView view = tb.trace.getProgramView();
-		ListingActionContext actionContext = new ListingActionContext(listingProvider,
-			listingProvider, view, new ProgramLocation(view, start),
-			new ProgramSelection(start, start.addWrap(1)), null);
-
+		ListingActionContext actionContext = createActionContext(start, 2);
 		assertTrue(disassemblerPlugin.actionPatchInstruction.isEnabledForContext(actionContext));
 		DebuggerDisassemblerPluginTestHelper helper = new DebuggerDisassemblerPluginTestHelper(
 			disassemblerPlugin, listingProvider, tb.trace.getProgramView());
@@ -544,10 +521,7 @@ public class DebuggerDisassemblyTest extends AbstractGhidraHeadedDebuggerGUITest
 
 	protected Instruction performFixedAssembleAction(Address start,
 			Predicate<FixedPlatformTracePatchInstructionAction> actionPred, String assembly) {
-		DBTraceVariableSnapProgramView view = tb.trace.getProgramView();
-		ListingActionContext actionContext = new ListingActionContext(listingProvider,
-			listingProvider, view, new ProgramLocation(view, start),
-			new ProgramSelection(start, start.addWrap(1)), null);
+		ListingActionContext actionContext = createActionContext(start, 2);
 		FixedPlatformTracePatchInstructionAction action =
 			runSwing(() -> Unique.assertOne(disassemblerPlugin.getPopupActions(tool, actionContext)
 					.stream()
