@@ -27,6 +27,7 @@ import org.junit.Before;
 import org.junit.Test;
 import org.junit.experimental.categories.Category;
 
+import db.Transaction;
 import docking.widgets.table.RowWrappedEnumeratedColumnTableModel;
 import generic.Unique;
 import generic.test.category.NightlyCategory;
@@ -38,9 +39,13 @@ import ghidra.app.plugin.core.debug.service.control.DebuggerControlServicePlugin
 import ghidra.app.plugin.core.debug.service.emulation.ProgramEmulationUtils;
 import ghidra.app.plugin.core.debug.service.modules.DebuggerStaticMappingUtils;
 import ghidra.app.services.*;
-import ghidra.app.services.LogicalBreakpoint.State;
 import ghidra.dbg.model.TestTargetProcess;
 import ghidra.dbg.target.TargetBreakpointSpec.TargetBreakpointKind;
+import ghidra.debug.api.action.ActionSource;
+import ghidra.debug.api.breakpoint.LogicalBreakpoint;
+import ghidra.debug.api.breakpoint.LogicalBreakpoint.State;
+import ghidra.debug.api.control.ControlMode;
+import ghidra.debug.api.model.TraceRecorder;
 import ghidra.dbg.target.TargetBreakpointSpecContainer;
 import ghidra.framework.store.LockException;
 import ghidra.program.model.address.Address;
@@ -52,7 +57,6 @@ import ghidra.trace.model.*;
 import ghidra.trace.model.breakpoint.TraceBreakpoint;
 import ghidra.trace.model.time.TraceSnapshot;
 import ghidra.util.SystemUtilities;
-import ghidra.util.database.UndoableTransaction;
 import ghidra.util.exception.CancelledException;
 import ghidra.util.exception.DuplicateNameException;
 import ghidra.util.task.TaskMonitor;
@@ -75,14 +79,8 @@ public class DebuggerBreakpointsProviderTest extends AbstractGhidraHeadedDebugge
 		breakpointService = tool.getService(DebuggerLogicalBreakpointService.class);
 	}
 
-	protected void waitAndFlush(TraceRecorder recorder) throws Throwable {
-		waitOn(recorder.getTarget().getModel().flushEvents());
-		waitOn(recorder.flushTransactions());
-		waitForDomainObject(recorder.getTrace());
-	}
-
 	protected void addMapping(Trace trace, Program prog) throws Exception {
-		try (UndoableTransaction tid = UndoableTransaction.start(trace, "Add mapping")) {
+		try (Transaction tx = trace.openTransaction("Add mapping")) {
 			DebuggerStaticMappingUtils.addMapping(
 				new DefaultTraceLocation(trace, null, Lifespan.nowOn(0), addr(trace, 0x55550000)),
 				new ProgramLocation(prog, addr(prog, 0x00400000)), 0x1000, false);
@@ -103,14 +101,13 @@ public class DebuggerBreakpointsProviderTest extends AbstractGhidraHeadedDebugge
 
 	protected void addStaticMemoryAndBreakpoint() throws LockException, DuplicateNameException,
 			MemoryConflictException, AddressOverflowException, CancelledException {
-		try (UndoableTransaction tid =
-			UndoableTransaction.start(program, "Add bookmark break")) {
+		try (Transaction tx = program.openTransaction("Add bookmark break")) {
 			program.getMemory()
 					.createInitializedBlock(".text", addr(program, 0x00400000), 0x1000, (byte) 0,
 						TaskMonitor.DUMMY, false);
 			program.getBookmarkManager()
-					.setBookmark(addr(program, 0x00400123),
-						LogicalBreakpoint.BREAKPOINT_ENABLED_BOOKMARK_TYPE, "SW_EXECUTE;1", "");
+					.setBookmark(addr(program, 0x00400123), LogicalBreakpoint.ENABLED_BOOKMARK_TYPE,
+						"SW_EXECUTE;1", "");
 		}
 	}
 
@@ -133,8 +130,7 @@ public class DebuggerBreakpointsProviderTest extends AbstractGhidraHeadedDebugge
 		Trace trace = recorder.getTrace();
 
 		addLiveMemoryAndBreakpoint(mb.testProcess1, recorder);
-		waitOn(mb.testModel.flushEvents());
-		waitForDomainObject(trace);
+		waitRecorder(recorder);
 
 		// NB, optionally open trace. Mapping only works if open...
 		traceManager.openTrace(trace);
@@ -250,7 +246,7 @@ public class DebuggerBreakpointsProviderTest extends AbstractGhidraHeadedDebugge
 
 		// NOTE: This acts on the corresponding target, not directly on trace
 		waitOn(lb.disableForTrace(trace));
-		waitAndFlush(recorder);
+		waitRecorder(recorder);
 
 		waitForPass(() -> assertEquals(State.DISABLED, row.getState()));
 
@@ -261,7 +257,7 @@ public class DebuggerBreakpointsProviderTest extends AbstractGhidraHeadedDebugge
 
 		// This duplicates the initial case, but without it, I just feel incomplete
 		waitOn(lb.enableForTrace(trace));
-		waitAndFlush(recorder);
+		waitRecorder(recorder);
 
 		waitForPass(() -> assertEquals(State.ENABLED, row.getState()));
 	}
@@ -705,7 +701,7 @@ public class DebuggerBreakpointsProviderTest extends AbstractGhidraHeadedDebugge
 
 		// Do our own launch, so that object mode is enabled during load (region creation)
 		createTrace(program.getLanguageID().getIdAsString());
-		try (UndoableTransaction startTransaction = tb.startTransaction()) {
+		try (Transaction startTransaction = tb.startTransaction()) {
 			TraceSnapshot initial = tb.trace.getTimeManager().getSnapshot(0, true);
 			ProgramEmulationUtils.loadExecutable(initial, program);
 			Address pc = program.getMinAddress();
