@@ -22,10 +22,12 @@ import java.awt.datatransfer.StringSelection;
 import java.nio.ByteBuffer;
 import java.util.*;
 import java.util.concurrent.CompletableFuture;
+import java.util.function.Supplier;
 
 import org.junit.Before;
 import org.junit.Test;
 
+import db.Transaction;
 import docking.ActionContext;
 import docking.action.DockingAction;
 import docking.action.DockingActionIf;
@@ -41,16 +43,19 @@ import ghidra.app.plugin.core.debug.disassemble.DebuggerDisassemblerPlugin;
 import ghidra.app.plugin.core.debug.disassemble.DebuggerDisassemblerPluginTestHelper;
 import ghidra.app.plugin.core.debug.gui.AbstractGhidraHeadedDebuggerGUITest;
 import ghidra.app.plugin.core.debug.gui.listing.DebuggerListingPlugin;
-import ghidra.app.plugin.core.debug.mapping.DebuggerTargetTraceMapper;
 import ghidra.app.plugin.core.debug.mapping.ObjectBasedDebuggerTargetTraceMapper;
 import ghidra.app.plugin.core.debug.service.control.DebuggerControlServicePlugin;
 import ghidra.app.plugin.core.debug.service.emulation.DebuggerEmulationServicePlugin;
-import ghidra.app.services.*;
+import ghidra.app.services.DebuggerControlService;
+import ghidra.app.services.DebuggerEmulationService;
 import ghidra.app.services.DebuggerEmulationService.CachedEmulator;
 import ghidra.app.services.DebuggerEmulationService.EmulationResult;
 import ghidra.dbg.model.*;
 import ghidra.dbg.target.TargetObject;
 import ghidra.dbg.target.TargetSteppable.TargetStepKind;
+import ghidra.debug.api.control.ControlMode;
+import ghidra.debug.api.model.DebuggerTargetTraceMapper;
+import ghidra.debug.api.model.TraceRecorder;
 import ghidra.pcode.exec.SuspendedPcodeExecutionException;
 import ghidra.program.model.address.Address;
 import ghidra.program.model.data.ShortDataType;
@@ -65,7 +70,6 @@ import ghidra.trace.model.thread.TraceThread;
 import ghidra.trace.model.time.schedule.Scheduler;
 import ghidra.trace.model.time.schedule.TraceSchedule;
 import ghidra.util.Swing;
-import ghidra.util.database.UndoableTransaction;
 
 /**
  * Tests for target control and state editing
@@ -175,11 +179,13 @@ public class DebuggerControlPluginTest extends AbstractGhidraHeadedDebuggerGUITe
 		waitRecorder(recorder);
 		waitForSwing();
 
-		performEnabledAction(null, controlPlugin.actionTargetResume, true);
+		DockingAction actionTargetResume = controlPlugin.getTargetAction("Resume");
+		performEnabledAction(null, actionTargetResume, true);
+		waitForTasks();
 		waitRecorder(recorder);
 		assertEquals(List.of("resume"), commands);
 		waitForSwing();
-		assertFalse(controlPlugin.actionTargetResume.isEnabled());
+		assertFalse(actionTargetResume.isEnabled());
 	}
 
 	@Test
@@ -193,17 +199,19 @@ public class DebuggerControlPluginTest extends AbstractGhidraHeadedDebuggerGUITe
 		waitRecorder(recorder);
 		waitForSwing();
 
-		assertFalse(controlPlugin.actionTargetInterrupt.isEnabled());
+		DockingAction actionTargetInterrupt = controlPlugin.getTargetAction("Interrupt");
+		assertFalse(actionTargetInterrupt.isEnabled());
 		waitOn(mb.testThread1.resume());
 		waitRecorder(recorder);
 		commands.clear();
 		waitForSwing();
 
-		performEnabledAction(null, controlPlugin.actionTargetInterrupt, true);
+		performEnabledAction(null, actionTargetInterrupt, true);
+		waitForTasks();
 		waitRecorder(recorder);
 		assertEquals(List.of("interrupt"), commands);
 		waitForSwing();
-		assertFalse(controlPlugin.actionTargetInterrupt.isEnabled());
+		assertFalse(actionTargetInterrupt.isEnabled());
 	}
 
 	@Test
@@ -217,11 +225,13 @@ public class DebuggerControlPluginTest extends AbstractGhidraHeadedDebuggerGUITe
 		waitRecorder(recorder);
 		waitForSwing();
 
-		performEnabledAction(null, controlPlugin.actionTargetKill, true);
+		DockingAction actionTargetKill = controlPlugin.getTargetAction("Kill");
+		performEnabledAction(null, actionTargetKill, true);
+		waitForTasks();
 		waitRecorder(recorder);
 		assertEquals(List.of("kill"), commands);
 		waitForSwing();
-		assertFalse(controlPlugin.actionTargetKill.isEnabled());
+		assertFalse(actionTargetKill.isEnabled());
 	}
 
 	@Test
@@ -233,13 +243,14 @@ public class DebuggerControlPluginTest extends AbstractGhidraHeadedDebuggerGUITe
 		waitForSwing();
 
 		performEnabledAction(null, controlPlugin.actionTargetDisconnect, true);
+		waitForTasks();
 		waitRecorder(recorder);
 		assertEquals(List.of("close"), commands);
 		waitForSwing();
 		waitForPass(() -> assertFalse(controlPlugin.actionTargetDisconnect.isEnabled()));
 	}
 
-	protected void runTestTargetStepAction(DockingAction action, TargetStepKind expected)
+	protected void runTestTargetStepAction(Supplier<DockingAction> action, TargetStepKind expected)
 			throws Throwable {
 		createTestModel();
 		TraceRecorder recorder = recordAndWaitSync();
@@ -250,26 +261,30 @@ public class DebuggerControlPluginTest extends AbstractGhidraHeadedDebuggerGUITe
 		waitRecorder(recorder);
 		waitForSwing();
 
-		performEnabledAction(null, action, true);
+		performEnabledAction(null, action.get(), true);
+		waitForTasks();
 		waitRecorder(recorder);
 		assertEquals(List.of("step(" + expected + ")"), commands);
 		waitForSwing();
-		assertTrue(action.isEnabled());
+		assertTrue(action.get().isEnabled());
 	}
 
 	@Test
 	public void testTargetStepIntoAction() throws Throwable {
-		runTestTargetStepAction(controlPlugin.actionTargetStepInto, TargetStepKind.INTO);
+		runTestTargetStepAction(() -> controlPlugin.getTargetAction("Step Into"),
+			TargetStepKind.INTO);
 	}
 
 	@Test
 	public void testTargetStepOverAction() throws Throwable {
-		runTestTargetStepAction(controlPlugin.actionTargetStepOver, TargetStepKind.OVER);
+		runTestTargetStepAction(() -> controlPlugin.getTargetAction("Step Over"),
+			TargetStepKind.OVER);
 	}
 
 	@Test
-	public void testTargetStepFinishAction() throws Throwable {
-		runTestTargetStepAction(controlPlugin.actionTargetStepFinish, TargetStepKind.FINISH);
+	public void testTargetStepOutAction() throws Throwable {
+		runTestTargetStepAction(() -> controlPlugin.getTargetAction("Step Out"),
+			TargetStepKind.FINISH);
 	}
 
 	TraceThread createToyLoopTrace() throws Throwable {
@@ -277,7 +292,7 @@ public class DebuggerControlPluginTest extends AbstractGhidraHeadedDebuggerGUITe
 
 		Address start = tb.addr(0x00400000);
 		TraceThread thread;
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			Assembler asm = Assemblers.getAssembler(tb.language);
 			AssemblyBuffer buf = new AssemblyBuffer(asm, start);
 			buf.assemble("br 0x" + start);
@@ -306,6 +321,28 @@ public class DebuggerControlPluginTest extends AbstractGhidraHeadedDebuggerGUITe
 		assertTrue(controlPlugin.actionEmulateResume.isEnabled());
 	}
 
+	/**
+	 * Tests the UI so it does not error when the user presses resume
+	 * after already stepped into a pcode instruction.
+	 */	
+	@Test
+	public void testEmulateResumeActionAfterPcodeStep() throws Throwable {
+		TraceThread thread = createToyLoopTrace();
+		controlService.setCurrentMode(tb.trace, ControlMode.RW_EMULATOR);
+
+		traceManager.activateThread(thread);
+		traceManager.activateTime(TraceSchedule.parse("0:.t0-2"));
+		waitForSwing();
+		
+		performEnabledAction(null, controlPlugin.actionEmulateResume, true);
+		waitForPass(() -> assertFalse(controlPlugin.actionEmulateResume.isEnabled()));
+
+		CachedEmulator ce = Unique.assertOne(emulationService.getBusyEmulators());
+		ce.emulator().setSuspended(true);
+		waitForTasks();
+		assertTrue(controlPlugin.actionEmulateResume.isEnabled());
+	}
+
 	@Test
 	public void testEmulateInterruptAction() throws Throwable {
 		TraceThread thread = createToyLoopTrace();
@@ -376,7 +413,7 @@ public class DebuggerControlPluginTest extends AbstractGhidraHeadedDebuggerGUITe
 	protected void create2SnapTrace() throws Throwable {
 		createAndOpenTrace();
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			tb.trace.getTimeManager().getSnapshot(1, true);
 		}
 	}
@@ -421,7 +458,7 @@ public class DebuggerControlPluginTest extends AbstractGhidraHeadedDebuggerGUITe
 
 		createAndOpenTrace();
 		TraceVariableSnapProgramView view = tb.trace.getProgramView();
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			tb.getOrAddThread("Threads[0]", 0);
 			tb.trace.getMemoryManager()
 					.createRegion("Memory[bin:.text]", 0, tb.range(0x00400000, 0x00401000),
@@ -472,7 +509,7 @@ public class DebuggerControlPluginTest extends AbstractGhidraHeadedDebuggerGUITe
 
 		createAndOpenTrace();
 		TraceVariableSnapProgramView view = tb.trace.getProgramView();
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			tb.getOrAddThread("Threads[0]", 0);
 			tb.trace.getMemoryManager()
 					.createRegion("Memory[bin:.text]", 0, tb.range(0x00400000, 0x00401000),
@@ -528,7 +565,7 @@ public class DebuggerControlPluginTest extends AbstractGhidraHeadedDebuggerGUITe
 
 		createAndOpenTrace();
 		TraceVariableSnapProgramView view = tb.trace.getProgramView();
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			tb.getOrAddThread("Threads[0]", 0);
 			tb.trace.getMemoryManager()
 					.createRegion("Memory[bin:.text]", 0, tb.range(0x00400000, 0x00401000),
