@@ -26,6 +26,7 @@ import java.util.stream.Collectors;
 import org.junit.*;
 import org.junit.experimental.categories.Category;
 
+import db.Transaction;
 import generic.test.category.NightlyCategory;
 import ghidra.app.plugin.core.debug.gui.AbstractGhidraHeadedDebuggerGUITest;
 import ghidra.app.plugin.core.debug.gui.action.NoneLocationTrackingSpec;
@@ -34,6 +35,8 @@ import ghidra.app.plugin.core.debug.gui.register.DebuggerRegistersProvider.Regis
 import ghidra.app.plugin.core.debug.gui.register.DebuggerRegistersProvider.RegisterTableColumns;
 import ghidra.app.plugin.core.debug.service.control.DebuggerControlServicePlugin;
 import ghidra.app.services.*;
+import ghidra.debug.api.control.ControlMode;
+import ghidra.debug.api.model.TraceRecorder;
 import ghidra.docking.settings.FormatSettingsDefinition;
 import ghidra.docking.settings.Settings;
 import ghidra.program.model.address.AddressSpace;
@@ -48,7 +51,6 @@ import ghidra.trace.model.listing.*;
 import ghidra.trace.model.memory.TraceMemoryFlag;
 import ghidra.trace.model.memory.TraceMemorySpace;
 import ghidra.trace.model.thread.TraceThread;
-import ghidra.util.database.UndoableTransaction;
 import ghidra.util.exception.DuplicateNameException;
 
 @Category(NightlyCategory.class) // this may actually be an @PortSensitive test
@@ -107,7 +109,7 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 	}
 
 	protected TraceThread addThread(String threadName) throws DuplicateNameException {
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			return tb.trace.getThreadManager().createThread(threadName, 0);
 		}
 	}
@@ -121,12 +123,12 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 	}
 
 	protected void addRegisterValues(TraceThread thread) {
-		try (UndoableTransaction tid = tb.startTransaction()) {
-			addRegisterValues(thread, tid);
+		try (Transaction tx = tb.startTransaction()) {
+			addRegisterValues(thread, tx);
 		}
 	}
 
-	protected void addRegisterValues(TraceThread thread, UndoableTransaction tid) {
+	protected void addRegisterValues(TraceThread thread, Transaction tx) {
 		TraceMemorySpace regVals =
 			tb.trace.getMemoryManager().getMemoryRegisterSpace(thread, true);
 		regVals.putBytes(0, pc, tb.buf(0, 0, 0, 0, 0, 0x40, 0, 0));
@@ -134,7 +136,7 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 		regVals.putBytes(0, r0, tb.buf(1, 2, 3, 4, 5, 6, 7, 8));
 	}
 
-	protected void addRegisterTypes(TraceThread thread, UndoableTransaction tid)
+	protected void addRegisterTypes(TraceThread thread, Transaction tx)
 			throws CodeUnitInsertionException {
 		TraceCodeSpace regCode =
 			tb.trace.getCodeManager().getCodeRegisterSpace(thread, true);
@@ -146,8 +148,8 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 	}
 
 	protected void addRegisterTypes(TraceThread thread) throws CodeUnitInsertionException {
-		try (UndoableTransaction tid = tb.startTransaction()) {
-			addRegisterTypes(thread, tid);
+		try (Transaction tx = tb.startTransaction()) {
+			addRegisterTypes(thread, tx);
 		}
 	}
 
@@ -320,8 +322,7 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 		waitForSwing();
 
 		mb.testBank1.writeRegister("pc", new byte[] { 0x00, 0x40, 0x00, 0x00 });
-		waitOn(mb.testModel.flushEvents());
-		waitForDomainObject(recorder.getTrace());
+		waitRecorder(recorder);
 
 		RegisterRow rowL = findRegisterRow(pc);
 		waitForPass(() -> assertTrue(rowL.isKnown()));
@@ -475,7 +476,7 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 		traceManager.openTrace(tb.trace);
 
 		TraceThread thread = addThread();
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			tb.exec(getPlatform(), 0, thread, 0, "pc = 100;");
 		}
 		activateThread(thread);
@@ -540,9 +541,9 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 		TraceThread thread = addThread();
 		activateThread(thread);
 		// Group adds into a single transaction
-		try (UndoableTransaction tid = tb.startTransaction()) {
-			addRegisterValues(thread, tid);
-			addRegisterTypes(thread, tid);
+		try (Transaction tx = tb.startTransaction()) {
+			addRegisterValues(thread, tx);
+			addRegisterTypes(thread, tx);
 		}
 		waitForSwing();
 
@@ -574,9 +575,9 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 		TraceThread thread = addThread();
 		activateThread(thread);
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
-			addRegisterValues(thread, tid);
-			addRegisterTypes(thread, tid);
+		try (Transaction tx = tb.startTransaction()) {
+			addRegisterValues(thread, tx);
+			addRegisterTypes(thread, tx);
 			waitForSwing();
 
 			// Sanity
@@ -585,7 +586,7 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 			assertPCRowTypePopulated();
 			assertR0RowTypePopulated();
 
-			tid.abort();
+			tx.abort();
 		}
 		waitForDomainObject(tb.trace);
 
@@ -628,7 +629,7 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 		assertPCRowValuePopulated();
 		assertR0RowValuePopulated();
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			TraceMemorySpace regVals =
 				tb.trace.getMemoryManager().getMemoryRegisterSpace(thread, true);
 			TraceCodeSpace regCode =
@@ -657,7 +658,7 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 		assertEquals(1, traceManager.getCurrentSnap());
 		assertR0RowTypePopulated();
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			TraceCodeSpace regCode =
 				tb.trace.getCodeManager().getCodeRegisterSpace(thread, true);
 			TraceCodeUnit code = regCode.codeUnits().getContaining(getPlatform(), 1, r0);
@@ -687,7 +688,7 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 
 		assertR0RowTypePopulated();
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			TraceCodeSpace regCode =
 				tb.trace.getCodeManager().getCodeRegisterSpace(thread, true);
 			TraceCodeUnit code = regCode.codeUnits().getContaining(getPlatform(), 1, r0);
@@ -755,7 +756,7 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 		traceManager.openTrace(tb.trace);
 
 		TraceThread thread = addThread();
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			// Unconventional start, to ensure goto PC is actually the cause, not just min of view
 			tb.trace.getMemoryManager()
 					.addRegion("bin:.text", Lifespan.nowOn(0), tb.range(0x00300000, 0x00500000),
@@ -864,7 +865,7 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 			traceManager.openTrace(ub.trace);
 
 			TraceThread thread3;
-			try (UndoableTransaction tid = ub.startTransaction()) {
+			try (Transaction tx = ub.startTransaction()) {
 				thread3 = ub.trace.getThreadManager().createThread("Thread3", 0);
 			}
 			traceManager.activateTrace(ub.trace);
@@ -898,7 +899,7 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 		assertR0RowValuePopulated();
 		assertR0RowTypePopulated();
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			TraceMemorySpace regVals =
 				tb.trace.getMemoryManager().getMemoryRegisterSpace(thread, true);
 			TraceCodeSpace regCode =
@@ -940,7 +941,7 @@ public class DebuggerRegistersProviderTest extends AbstractGhidraHeadedDebuggerG
 		assertR0RowValuePopulated();
 		assertR0RowTypePopulated();
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			TraceMemorySpace regVals =
 				tb.trace.getMemoryManager().getMemoryRegisterSpace(thread, 1, true);
 			regVals.putBytes(getPlatform(), 0, pc, tb.buf(0, 0, 0, 0, 0, 0x50, 0, 0));
