@@ -23,17 +23,24 @@ import java.util.concurrent.TimeUnit;
 
 import org.junit.*;
 
+import db.Transaction;
 import generic.Unique;
 import ghidra.app.plugin.core.debug.gui.AbstractGhidraHeadedDebuggerGUITest;
 import ghidra.app.plugin.core.debug.service.control.DebuggerControlServicePlugin;
 import ghidra.app.plugin.core.debug.service.modules.DebuggerStaticMappingUtils;
 import ghidra.app.services.*;
-import ghidra.app.services.LogicalBreakpoint.State;
 import ghidra.async.AsyncReference;
 import ghidra.dbg.model.TestTargetMemoryRegion;
 import ghidra.dbg.model.TestTargetProcess;
 import ghidra.dbg.target.*;
 import ghidra.dbg.target.TargetBreakpointSpec.TargetBreakpointKind;
+import ghidra.debug.api.action.ActionSource;
+import ghidra.debug.api.breakpoint.LogicalBreakpoint;
+import ghidra.debug.api.breakpoint.LogicalBreakpoint.State;
+import ghidra.debug.api.breakpoint.LogicalBreakpointsChangeListener;
+import ghidra.debug.api.control.ControlMode;
+import ghidra.debug.api.model.TraceRecorder;
+import ghidra.debug.api.modules.DebuggerStaticMappingChangeListener;
 import ghidra.program.model.address.Address;
 import ghidra.program.model.listing.Bookmark;
 import ghidra.program.model.listing.Program;
@@ -46,8 +53,6 @@ import ghidra.trace.model.memory.TraceMemoryRegion;
 import ghidra.trace.model.modules.TraceStaticMapping;
 import ghidra.util.Msg;
 import ghidra.util.SystemUtilities;
-import ghidra.util.database.UndoableTransaction;
-import ghidra.util.datastruct.ListenerMap;
 
 public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDebuggerGUITest {
 	protected static final long TIMEOUT_MILLIS =
@@ -55,14 +60,13 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 
 	/**
 	 * Tracks the current set of logical breakpoints.
-	 * 
+	 *
 	 * <p>
 	 * Its assertions require perfection in the sequence of events: 1) No double-adds. 2) No
 	 * double-removes. 3) No extraneous updates. At the end of each test, the current set of
 	 * breakpoints in this listener should be verified against those reported by the service.
 	 */
-	protected class NoDuplicatesTrackingChangeListener
-			implements LogicalBreakpointsChangeListener {
+	protected class NoDuplicatesTrackingChangeListener implements LogicalBreakpointsChangeListener {
 		private Set<LogicalBreakpoint> current = new HashSet<>();
 
 		@Override
@@ -146,8 +150,6 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 
 	@Before
 	public void setUpBreakpointServiceTest() throws Throwable {
-		ListenerMap.clearErr();
-
 		addPlugin(tool, DebuggerLogicalBreakpointServicePlugin.class);
 		breakpointService = tool.getService(DebuggerLogicalBreakpointService.class);
 		mappingService = tool.getService(DebuggerStaticMappingService.class);
@@ -191,7 +193,6 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 				waitForLock(recorder3.getTrace());
 				recorder3.stopRecording();
 			}
-			ListenerMap.checkErr();
 		}
 		catch (Throwable t) {
 			Msg.error(this, "Failed during tear down: " + t);
@@ -220,8 +221,7 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		Map<Program, Set<LogicalBreakpoint>> breaksByProgramViaPer = new HashMap<>();
 		for (Program prog : programManager.getAllOpenPrograms()) {
 			Set<LogicalBreakpoint> breaks = new HashSet<>();
-			for (Entry<Address, Set<LogicalBreakpoint>> ent : breakpointService
-					.getBreakpoints(prog)
+			for (Entry<Address, Set<LogicalBreakpoint>> ent : breakpointService.getBreakpoints(prog)
 					.entrySet()) {
 				for (LogicalBreakpoint lb : ent.getValue()) {
 					ProgramLocation loc = lb.getProgramLocation();
@@ -256,11 +256,10 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 	}
 
 	protected void addProgramTextBlock(Program p) throws Throwable {
-		try (UndoableTransaction tid =
-			UndoableTransaction.start(program, "Add .text block")) {
+		try (Transaction tx = program.openTransaction("Add .text block")) {
 			p.getMemory()
-					.createInitializedBlock(".text", addr(p, 0x00400000), 0x1000, (byte) 0,
-						monitor, false);
+					.createInitializedBlock(".text", addr(p, 0x00400000), 0x1000, (byte) 0, monitor,
+						false);
 		}
 	}
 
@@ -281,19 +280,17 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		Trace t = r.getTrace();
 		TraceMemoryRegion textRegion =
 			waitFor(() -> r.getTraceMemoryRegion(region), "Recorder missed region: " + region);
-		try (UndoableTransaction tid =
-			UndoableTransaction.start(t, "Add .text mapping")) {
+		try (Transaction tx = t.openTransaction("Add .text mapping")) {
 			DebuggerStaticMappingUtils.addMapping(
 				new DefaultTraceLocation(t, null, textRegion.getLifespan(),
 					textRegion.getMinAddress()),
-				new ProgramLocation(p, addr(p, 0x00400000)), 0x1000,
-				false);
+				new ProgramLocation(p, addr(p, 0x00400000)), 0x1000, false);
 		}
 	}
 
 	protected void removeTextMapping(TraceRecorder r, Program p) throws Throwable {
 		Trace t = r.getTrace();
-		try (UndoableTransaction tid = UndoableTransaction.start(t, "Remove .text mapping")) {
+		try (Transaction tx = t.openTransaction("Remove .text mapping")) {
 			TraceStaticMapping mapping =
 				t.getStaticMappingManager().findContaining(addr(t, 0x55550000), r.getSnap());
 			mapping.delete();
@@ -325,8 +322,7 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		TargetBreakpointSpecContainer cont = getBreakpointContainer(r);
 		cont.fetchElements().thenAccept(elements -> {
 			for (TargetObject obj : elements.values()) {
-				if (!(obj instanceof TargetBreakpointSpec) ||
-					!(obj instanceof TargetDeletable)) {
+				if (!(obj instanceof TargetBreakpointSpec) || !(obj instanceof TargetDeletable)) {
 					continue;
 				}
 				TargetBreakpointSpec spec = (TargetBreakpointSpec) obj;
@@ -342,28 +338,28 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 	}
 
 	protected void addProgramBreakpoints(Program p) throws Throwable {
-		try (UndoableTransaction tid = UndoableTransaction.start(p, "Create bookmarks")) {
+		try (Transaction tx = p.openTransaction("Create bookmarks")) {
 			enBm = p.getBookmarkManager()
-					.setBookmark(addr(p, 0x00400123),
-						LogicalBreakpoint.BREAKPOINT_ENABLED_BOOKMARK_TYPE, "SW_EXECUTE;1", "");
+					.setBookmark(addr(p, 0x00400123), LogicalBreakpoint.ENABLED_BOOKMARK_TYPE,
+						"SW_EXECUTE;1", "");
 			disBm = p.getBookmarkManager()
-					.setBookmark(addr(p, 0x00400321),
-						LogicalBreakpoint.BREAKPOINT_DISABLED_BOOKMARK_TYPE, "SW_EXECUTE;1", "");
+					.setBookmark(addr(p, 0x00400321), LogicalBreakpoint.DISABLED_BOOKMARK_TYPE,
+						"SW_EXECUTE;1", "");
 		}
 	}
 
 	protected void refetchProgramBreakpoints(Program p) throws Throwable {
 		// After a redo
 		enBm = p.getBookmarkManager()
-				.getBookmark(addr(p, 0x00400123),
-					LogicalBreakpoint.BREAKPOINT_ENABLED_BOOKMARK_TYPE, "SW_EXECUTE;1");
+				.getBookmark(addr(p, 0x00400123), LogicalBreakpoint.ENABLED_BOOKMARK_TYPE,
+					"SW_EXECUTE;1");
 		disBm = p.getBookmarkManager()
-				.getBookmark(addr(p, 0x00400321),
-					LogicalBreakpoint.BREAKPOINT_DISABLED_BOOKMARK_TYPE, "SW_EXECUTE;1");
+				.getBookmark(addr(p, 0x00400321), LogicalBreakpoint.DISABLED_BOOKMARK_TYPE,
+					"SW_EXECUTE;1");
 	}
 
 	protected void removeProgramBreakpoints(Program p) throws Throwable {
-		try (UndoableTransaction tid = UndoableTransaction.start(p, "Remove breakpoints")) {
+		try (Transaction tx = p.openTransaction("Remove breakpoints")) {
 			p.getBookmarkManager().removeBookmark(enBm);
 			p.getBookmarkManager().removeBookmark(disBm);
 		}
@@ -390,8 +386,8 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 			int total) {
 		assertEquals(total, breakpointService.getAllBreakpoints().size());
 
-		LogicalBreakpoint enLb = Unique
-				.assertOne(breakpointService.getBreakpointsAt(trace, addr(trace, offset)));
+		LogicalBreakpoint enLb =
+			Unique.assertOne(breakpointService.getBreakpointsAt(trace, addr(trace, offset)));
 		assertNull(enLb.getProgramLocation());
 		assertEquals(Set.of(TraceBreakpointKind.SW_EXECUTE), enLb.getKinds());
 
@@ -954,10 +950,11 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		addTextMapping(recorder3, text3, program);
 		waitForSwing();
 		waitForPass(() -> {
-			assertEquals(2, mappingService
-					.getOpenMappedLocations(
-						new ProgramLocation(program, addr(program, 0x00400123)))
-					.size());
+			assertEquals(2,
+				mappingService
+						.getOpenMappedLocations(
+							new ProgramLocation(program, addr(program, 0x00400123)))
+						.size());
 		});
 		waitForSwing();
 
@@ -993,10 +990,11 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		addTextMapping(recorder3, text3, program);
 		waitForSwing();
 		waitForPass(() -> {
-			assertEquals(2, mappingService
-					.getOpenMappedLocations(
-						new ProgramLocation(program, addr(program, 0x00400123)))
-					.size());
+			assertEquals(2,
+				mappingService
+						.getOpenMappedLocations(
+							new ProgramLocation(program, addr(program, 0x00400123)))
+						.size());
 		});
 		waitForSwing();
 
@@ -1037,10 +1035,11 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		addTextMapping(recorder3, text3, program);
 		waitForSwing();
 		waitForPass(() -> {
-			assertEquals(2, mappingService
-					.getOpenMappedLocations(
-						new ProgramLocation(program, addr(program, 0x00400123)))
-					.size());
+			assertEquals(2,
+				mappingService
+						.getOpenMappedLocations(
+							new ProgramLocation(program, addr(program, 0x00400123)))
+						.size());
 		});
 		waitForSwing();
 
@@ -1090,10 +1089,11 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		addTextMapping(recorder3, text3, program);
 		waitForSwing();
 		waitForPass(() -> {
-			assertEquals(2, mappingService
-					.getOpenMappedLocations(
-						new ProgramLocation(program, addr(program, 0x00400123)))
-					.size());
+			assertEquals(2,
+				mappingService
+						.getOpenMappedLocations(
+							new ProgramLocation(program, addr(program, 0x00400123)))
+						.size());
 		});
 		waitForSwing();
 
@@ -1126,7 +1126,7 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 	 * breakpoints, so there's no context in which testing this service with aborted transactions on
 	 * breakpoints is sane.
 	 */
-	//@Test 
+	//@Test
 	public void testAbortAddBreakpoint() throws Throwable {
 		startRecorder1();
 		Trace trace = recorder1.getTrace();
@@ -1141,13 +1141,13 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		expectMappingChange(() -> addTextMapping(recorder1, text, program));
 		waitForSwing();
 
-		try (UndoableTransaction tid = UndoableTransaction.start(trace, "Will abort")) {
+		try (Transaction tx = trace.openTransaction("Will abort")) {
 			addTargetSoftwareBreakpoint(recorder1, text);
 			waitForDomainObject(trace);
 
 			// Sanity
 			assertLogicalBreakpointForMappedSoftwareBreakpoint(trace);
-			tid.abort();
+			tx.abort();
 		}
 		waitForDomainObject(trace);
 
@@ -1179,14 +1179,14 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		waitForDomainObject(trace);
 		changeListener.assertAgreesWithService();
 
-		try (UndoableTransaction tid = UndoableTransaction.start(trace, "Will abort")) {
+		try (Transaction tx = trace.openTransaction("Will abort")) {
 			expectMappingChange(() -> addTextMapping(recorder1, text, program));
 			waitForSwing();
 
 			// Sanity
 			assertLogicalBreakpointForMappedSoftwareBreakpoint(trace);
 
-			expectMappingChange(() -> tid.abort());
+			expectMappingChange(() -> tx.abort());
 		}
 
 		waitForPass(() -> {
@@ -1208,7 +1208,7 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		addProgramTextBlock(program);
 		TestTargetMemoryRegion text = addTargetTextRegion(mb.testProcess1);
 
-		try (UndoableTransaction tid = UndoableTransaction.start(trace, "Will abort")) {
+		try (Transaction tx = trace.openTransaction("Will abort")) {
 			addTargetSoftwareBreakpoint(recorder1, text);
 
 			expectMappingChange(() -> addTextMapping(recorder1, text, program));
@@ -1217,7 +1217,7 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 			// Sanity
 			assertLogicalBreakpointForMappedSoftwareBreakpoint(trace);
 
-			expectMappingChange(() -> tid.abort());
+			expectMappingChange(() -> tx.abort());
 		}
 		waitForDomainObject(trace); // Duplicative, but for form's sake....
 
@@ -1242,13 +1242,13 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		expectMappingChange(() -> addTextMapping(recorder1, text, program));
 		waitForSwing();
 
-		try (UndoableTransaction tid = UndoableTransaction.start(program, "Will abort")) {
+		try (Transaction tx = program.openTransaction("Will abort")) {
 			addProgramBreakpoints(program);
 			waitForDomainObject(program);
 
 			// Sanity
 			assertLogicalBreakpointsForMappedBookmarks(trace);
-			tid.abort();
+			tx.abort();
 		}
 		waitForDomainObject(program);
 
@@ -1268,7 +1268,7 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		addProgramTextBlock(program);
 		TestTargetMemoryRegion text = addTargetTextRegion(mb.testProcess1);
 
-		try (UndoableTransaction tid = UndoableTransaction.start(trace, "Will undo")) {
+		try (Transaction tx = trace.openTransaction("Will undo")) {
 			addTargetSoftwareBreakpoint(recorder1, text);
 			expectMappingChange(() -> addTextMapping(recorder1, text, program));
 		}
@@ -1310,7 +1310,7 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		expectMappingChange(() -> addTextMapping(recorder1, text, program));
 		waitForSwing();
 
-		try (UndoableTransaction tid = UndoableTransaction.start(program, "Will undo")) {
+		try (Transaction tx = program.openTransaction("Will undo")) {
 			addProgramBreakpoints(program);
 		}
 		waitForDomainObject(program);
@@ -1536,7 +1536,7 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 
 	protected void addTextMappingDead(Program p, ToyDBTraceBuilder tb) throws Throwable {
 		addProgramTextBlock(p);
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tid = tb.startTransaction()) {
 			TraceMemoryRegion textRegion = tb.trace.getMemoryManager()
 					.addRegion("Processes[1].Memory[bin:.text]", Lifespan.nowOn(0),
 						tb.range(0x55550000, 0x55550fff),
@@ -1544,18 +1544,15 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 			DebuggerStaticMappingUtils.addMapping(
 				new DefaultTraceLocation(tb.trace, null, textRegion.getLifespan(),
 					textRegion.getMinAddress()),
-				new ProgramLocation(p, addr(p, 0x00400000)), 0x1000,
-				false);
+				new ProgramLocation(p, addr(p, 0x00400000)), 0x1000, false);
 		}
 	}
 
 	protected void addEnabledProgramBreakpointWithSleigh(Program p) {
-		try (UndoableTransaction tid =
-			UndoableTransaction.start(p, "Create bookmark bp with sleigh")) {
+		try (Transaction tid = p.openTransaction("Create bookmark bp with sleigh")) {
 			enBm = p.getBookmarkManager()
-					.setBookmark(addr(p, 0x00400123),
-						LogicalBreakpoint.BREAKPOINT_ENABLED_BOOKMARK_TYPE, "SW_EXECUTE;1",
-						"{sleigh: 'r0=0xbeef;'}");
+					.setBookmark(addr(p, 0x00400123), LogicalBreakpoint.ENABLED_BOOKMARK_TYPE,
+						"SW_EXECUTE;1", "{sleigh: 'r0=0xbeef;'}");
 		}
 	}
 
@@ -1619,8 +1616,7 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 	@Test
 	public void testAddTraceBreakpointSetSleighThenMapThenSaveToProgramCopiesSleigh()
 			throws Throwable {
-		DebuggerControlService editingService =
-			addPlugin(tool, DebuggerControlServicePlugin.class);
+		DebuggerControlService editingService = addPlugin(tool, DebuggerControlServicePlugin.class);
 
 		// TODO: What if already mapped?
 		// Not sure I care about tb.setEmuSleigh() out of band
@@ -1632,11 +1628,10 @@ public class DebuggerLogicalBreakpointServiceTest extends AbstractGhidraHeadedDe
 		intoProject(program);
 		programManager.openProgram(program);
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tid = tb.startTransaction()) {
 			TraceBreakpoint bpt = tb.trace.getBreakpointManager()
 					.addBreakpoint("Processes[1].Breakpoints[0]", Lifespan.nowOn(0),
-						tb.addr(0x55550123),
-						Set.of(), Set.of(TraceBreakpointKind.SW_EXECUTE),
+						tb.addr(0x55550123), Set.of(), Set.of(TraceBreakpointKind.SW_EXECUTE),
 						false /* emuEnabled defaults to true */, "");
 			bpt.setEmuSleigh("r0=0xbeef;");
 		}
