@@ -23,14 +23,16 @@ import java.nio.ByteBuffer;
 import org.junit.Before;
 import org.junit.Test;
 
+import db.Transaction;
 import ghidra.app.plugin.assembler.*;
-import ghidra.app.plugin.core.debug.DebuggerCoordinates;
 import ghidra.app.plugin.core.debug.gui.AbstractGhidraHeadedDebuggerGUITest;
-import ghidra.app.plugin.core.debug.service.control.DebuggerControlServicePlugin;
 import ghidra.app.services.*;
 import ghidra.app.services.DebuggerControlService.StateEditor;
 import ghidra.async.AsyncUtils.TemperamentalRunnable;
 import ghidra.dbg.target.TargetRegisterBank;
+import ghidra.debug.api.control.ControlMode;
+import ghidra.debug.api.model.TraceRecorder;
+import ghidra.debug.api.tracemgr.DebuggerCoordinates;
 import ghidra.program.model.lang.*;
 import ghidra.program.model.mem.MemoryAccessException;
 import ghidra.trace.model.Lifespan;
@@ -38,7 +40,6 @@ import ghidra.trace.model.guest.TracePlatform;
 import ghidra.trace.model.memory.TraceMemorySpace;
 import ghidra.trace.model.thread.TraceThread;
 import ghidra.trace.model.time.schedule.TraceSchedule;
-import ghidra.util.database.UndoableTransaction;
 
 public class DebuggerControlServiceTest extends AbstractGhidraHeadedDebuggerGUITest {
 	protected DebuggerControlService editingService;
@@ -134,7 +135,7 @@ public class DebuggerControlServiceTest extends AbstractGhidraHeadedDebuggerGUIT
 		createAndOpenTrace();
 		editingService.setCurrentMode(tb.trace, ControlMode.RW_EMULATOR);
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			// NB. TraceManager should automatically activate the first thread
 			tb.getOrAddThread("Threads[0]", 0);
 		}
@@ -161,7 +162,7 @@ public class DebuggerControlServiceTest extends AbstractGhidraHeadedDebuggerGUIT
 		editingService.setCurrentMode(tb.trace, ControlMode.RW_EMULATOR);
 
 		TraceThread thread;
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			// NB. TraceManager should automatically activate the first thread
 			thread = tb.getOrAddThread("Threads[0]", 0);
 		}
@@ -189,7 +190,7 @@ public class DebuggerControlServiceTest extends AbstractGhidraHeadedDebuggerGUIT
 		createAndOpenTrace();
 		editingService.setCurrentMode(tb.trace, ControlMode.RW_TRACE);
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			// NB. TraceManager should automatically activate the first thread
 			TraceThread thread = tb.getOrAddThread("Threads[0]", 0);
 			Assembler asm = Assemblers.getAssembler(getPlatform().getLanguage());
@@ -228,7 +229,7 @@ public class DebuggerControlServiceTest extends AbstractGhidraHeadedDebuggerGUIT
 		editingService.setCurrentMode(tb.trace, ControlMode.RW_TRACE);
 
 		TraceThread thread;
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			// NB. TraceManager should automatically activate the first thread
 			thread = tb.getOrAddThread("Threads[0]", 0);
 			Assembler asm = Assemblers.getAssembler(getPlatform().getLanguage());
@@ -267,7 +268,7 @@ public class DebuggerControlServiceTest extends AbstractGhidraHeadedDebuggerGUIT
 		createAndOpenTrace();
 		editingService.setCurrentMode(tb.trace, ControlMode.RW_EMULATOR);
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			// NB. TraceManager should automatically activate the first thread
 			tb.getOrAddThread("Threads[0]", 0);
 		}
@@ -297,7 +298,7 @@ public class DebuggerControlServiceTest extends AbstractGhidraHeadedDebuggerGUIT
 		editingService.setCurrentMode(tb.trace, ControlMode.RW_EMULATOR);
 
 		TraceThread thread;
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			// NB. TraceManager should automatically activate the first thread
 			thread = tb.getOrAddThread("Threads[0]", 0);
 		}
@@ -367,7 +368,7 @@ public class DebuggerControlServiceTest extends AbstractGhidraHeadedDebuggerGUIT
 		editingService.setCurrentMode(tb.trace, ControlMode.RW_TRACE);
 
 		TraceThread thread;
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			// NB. TraceManager should automatically activate the first thread
 			thread = tb.getOrAddThread("Threads[0]", 0);
 		}
