@@ -25,6 +25,7 @@ import java.util.function.Predicate;
 
 import org.junit.Test;
 
+import db.Transaction;
 import docking.widgets.fieldpanel.Layout;
 import docking.widgets.fieldpanel.field.Field;
 import docking.widgets.fieldpanel.support.FieldLocation;
@@ -34,7 +35,6 @@ import ghidra.app.decompiler.component.*;
 import ghidra.app.plugin.assembler.*;
 import ghidra.app.plugin.assembler.sleigh.sem.*;
 import ghidra.app.plugin.core.codebrowser.CodeBrowserPlugin;
-import ghidra.app.plugin.core.debug.DebuggerCoordinates;
 import ghidra.app.plugin.core.debug.disassemble.TraceDisassembleCommand;
 import ghidra.app.plugin.core.debug.gui.AbstractGhidraHeadedDebuggerGUITest;
 import ghidra.app.plugin.core.debug.gui.listing.DebuggerListingPlugin;
@@ -48,11 +48,13 @@ import ghidra.app.plugin.core.decompile.DecompilePlugin;
 import ghidra.app.plugin.core.decompile.DecompilerProvider;
 import ghidra.app.plugin.core.disassembler.DisassemblerPlugin;
 import ghidra.app.services.*;
-import ghidra.app.services.DebuggerEmulationService.EmulationResult;
 import ghidra.app.services.DebuggerControlService.StateEditor;
+import ghidra.app.services.DebuggerEmulationService.EmulationResult;
 import ghidra.app.util.viewer.field.FieldFactory;
 import ghidra.app.util.viewer.field.ListingField;
 import ghidra.app.util.viewer.listingpanel.ListingPanel;
+import ghidra.debug.api.control.ControlMode;
+import ghidra.debug.api.tracemgr.DebuggerCoordinates;
 import ghidra.lifecycle.Unfinished;
 import ghidra.pcode.exec.DebuggerPcodeUtils.WatchValue;
 import ghidra.pcode.exec.DebuggerPcodeUtils.WatchValuePcodeArithmetic;
@@ -78,7 +80,6 @@ import ghidra.trace.model.thread.TraceThread;
 import ghidra.trace.model.time.schedule.Scheduler;
 import ghidra.util.Msg;
 import ghidra.util.NumericUtilities;
-import ghidra.util.database.UndoableTransaction;
 
 public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 
@@ -135,7 +136,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 	protected Function createSumSquaresProgramX86_32() throws Throwable {
 		createProgram("x86:LE:32:default", "gcc");
 		intoProject(program);
-		try (UndoableTransaction tid = UndoableTransaction.start(program, "Assemble")) {
+		try (Transaction tx = program.openTransaction("Assemble")) {
 			Address entry = addr(program, 0x00400000);
 			program.getMemory()
 					.createInitializedBlock(".text", entry, 0x1000, (byte) 0, monitor, false);
@@ -199,7 +200,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 	protected Function createFibonacciProgramX86_32() throws Throwable {
 		createProgram("x86:LE:32:default", "gcc");
 		intoProject(program);
-		try (UndoableTransaction tid = UndoableTransaction.start(program, "Assemble")) {
+		try (Transaction tx = program.openTransaction("Assemble")) {
 			Address entry = addr(program, 0x00400000);
 			program.getMemory()
 					.createInitializedBlock(".text", entry, 0x1000, (byte) 0, monitor, false);
@@ -276,7 +277,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		createProgram("x86:LE:32:default", "gcc");
 		intoProject(program);
 		Address entry;
-		try (UndoableTransaction tid = UndoableTransaction.start(program, "Assemble")) {
+		try (Transaction tx = program.openTransaction("Assemble")) {
 			entry = addr(program, 0x00400000);
 			Address externs = addr(program, 0x00700000);
 			program.getMemory()
@@ -338,7 +339,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		createProgram("x86:LE:32:default", "gcc");
 		intoProject(program);
 		Address entry;
-		try (UndoableTransaction tid = UndoableTransaction.start(program, "Assemble")) {
+		try (Transaction tx = program.openTransaction("Assemble")) {
 			entry = addr(program, 0x00400000);
 			program.getMemory()
 					.createInitializedBlock(".text", entry, 0x1000, (byte) 0, monitor, false);
@@ -393,7 +394,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		createProgram("x86:LE:32:default", "gcc");
 		intoProject(program);
 
-		try (UndoableTransaction tid = UndoableTransaction.start(program, "Assemble")) {
+		try (Transaction tx = program.openTransaction("Assemble")) {
 			Address entry = addr(program, 0x00400000);
 			program.getMemory()
 					.createInitializedBlock(".text", entry, 0x1000, (byte) 0, monitor, false);
@@ -430,7 +431,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		createProgram("x86:LE:32:default", "gcc");
 		intoProject(program);
 
-		try (UndoableTransaction tid = UndoableTransaction.start(program, "Assemble")) {
+		try (Transaction tx = program.openTransaction("Assemble")) {
 			ProgramBasedDataTypeManager dtm = program.getDataTypeManager();
 			Structure structure = new StructureDataType("MyStruct", 0, dtm);
 			structure.add(WordDataType.dataType, "y", "");
@@ -515,7 +516,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		createProgram("x86:LE:32:default", "gcc");
 		intoProject(program);
 
-		try (UndoableTransaction tid = UndoableTransaction.start(program, "Assemble")) {
+		try (Transaction tx = program.openTransaction("Assemble")) {
 			ProgramBasedDataTypeManager dtm = program.getDataTypeManager();
 			Structure structure = new StructureDataType("MyStruct", 0, dtm);
 			structure.add(WordDataType.dataType, "y", "");
@@ -602,14 +603,14 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 
 		UnwindInfo infoAtEntry = ua.computeUnwindInfo(entry, monitor);
 		assertEquals(
-			new UnwindInfo(function, 0, 4, stack(0), Map.of(), new StackUnwindWarningSet()),
+			new UnwindInfo(function, 0L, 4L, stack(0), Map.of(), new StackUnwindWarningSet(), null),
 			infoAtEntry);
 
 		UnwindInfo infoAtBody = ua.computeUnwindInfo(bodyInstr, monitor);
-		assertEquals(new UnwindInfo(function, -20, 4, stack(0),
+		assertEquals(new UnwindInfo(function, -20L, 4L, stack(0),
 			Map.of(
 				register("EBP"), stack(-4)),
-			new StackUnwindWarningSet()),
+			new StackUnwindWarningSet(), null),
 			infoAtBody);
 	}
 
@@ -629,16 +630,17 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 
 		UnwindInfo infoAtEntry = ua.computeUnwindInfo(entry, monitor);
 		assertEquals(
-			new UnwindInfo(function, 0, 4, stack(0), Map.of(), new StackUnwindWarningSet()),
+			new UnwindInfo(function, 0L, 4L, stack(0), Map.of(), new StackUnwindWarningSet(), null),
 			infoAtEntry);
 
 		UnwindInfo infoAtBody = ua.computeUnwindInfo(bodyInstr, monitor);
-		assertEquals(new UnwindInfo(function, -20, 4, stack(0),
+		assertEquals(new UnwindInfo(function, -20L, 4L, stack(0),
 			Map.of(
 				register("EBP"), stack(-4)),
 			new StackUnwindWarningSet(
 				new UnspecifiedConventionStackUnwindWarning(myExtern),
-				new UnknownPurgeStackUnwindWarning(myExtern))),
+				new UnknownPurgeStackUnwindWarning(myExtern)),
+			null),
 			infoAtBody);
 	}
 
@@ -656,16 +658,17 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 
 		UnwindInfo infoAtEntry = ua.computeUnwindInfo(entry, monitor);
 		assertEquals(
-			new UnwindInfo(function, 0, 4, stack(0), Map.of(), new StackUnwindWarningSet()),
+			new UnwindInfo(function, 0L, 4L, stack(0), Map.of(), new StackUnwindWarningSet(), null),
 			infoAtEntry);
 
 		UnwindInfo infoAtBody = ua.computeUnwindInfo(bodyInstr, monitor);
 		DataType ptr2Undef = new PointerDataType(DataType.DEFAULT, program.getDataTypeManager());
-		assertEquals(new UnwindInfo(function, -20, 4, stack(0),
+		assertEquals(new UnwindInfo(function, -20L, 4L, stack(0),
 			Map.of(
 				register("EBP"), stack(-4)),
 			new StackUnwindWarningSet(
-				new UnexpectedTargetTypeStackUnwindWarning(ptr2Undef))),
+				new UnexpectedTargetTypeStackUnwindWarning(ptr2Undef)),
+			null),
 			infoAtBody);
 	}
 
@@ -702,7 +705,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		waitOn(frameAtSetup.setValue(editor, param1, BigInteger.valueOf(4)));
 		waitForTasks();
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			tb.trace.getBreakpointManager()
 					.addBreakpoint("Breakpoints[0]", Lifespan.nowOn(0), retInstr, Set.of(),
 						Set.of(TraceBreakpointKind.SW_EXECUTE), true, "capture return value");
@@ -764,7 +767,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		waitForTasks();
 
 		TraceBreakpoint bptUnwind;
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			bptUnwind = tb.trace.getBreakpointManager()
 					.addBreakpoint("Breakpoints[0]", Lifespan.nowOn(0), retInstr,
 						Set.of(),
@@ -802,7 +805,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 			}
 		}
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			bptUnwind.delete();
 		}
 
@@ -845,7 +848,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		waitForSwing();
 
 		DebuggerCoordinates atSetup = traceManager.getCurrent();
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			new UnwindStackCommand(tool, atSetup).applyTo(tb.trace, monitor);
 		}
 		waitForDomainObject(tb.trace);
@@ -907,7 +910,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		waitOn(frameAtSetup.setReturnAddress(editor, tb.addr(0xdeadbeef)));
 		waitForTasks();
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			tb.trace.getBreakpointManager()
 					.addBreakpoint("Breakpoints[0]", Lifespan.nowOn(0), retInstr,
 						Set.of(),
@@ -921,7 +924,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		traceManager.activateTime(result.schedule());
 		waitForTasks();
 		DebuggerCoordinates tallest = traceManager.getCurrent();
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			new UnwindStackCommand(tool, tallest).applyTo(tb.trace, monitor);
 		}
 		waitForDomainObject(tb.trace);
@@ -950,7 +953,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		Register sp = program.getCompilerSpec().getStackPointer();
 		waitOn(editor.setRegister(new RegisterValue(sp, BigInteger.valueOf(0x4ff0))));
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			tb.trace.getBreakpointManager()
 					.addBreakpoint("Breakpoints[0]", Lifespan.nowOn(0), retInstr,
 						Set.of(),
@@ -965,7 +968,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		traceManager.activateTime(result.schedule());
 		waitForTasks();
 		DebuggerCoordinates atRet = traceManager.getCurrent();
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			new UnwindStackCommand(tool, atRet).applyTo(tb.trace, monitor);
 		}
 		waitForDomainObject(tb.trace);
@@ -994,7 +997,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		Register sp = program.getCompilerSpec().getStackPointer();
 		waitOn(editor.setRegister(new RegisterValue(sp, BigInteger.valueOf(0x4ff0))));
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			tb.trace.getBreakpointManager()
 					.addBreakpoint("Breakpoints[0]", Lifespan.nowOn(0), retInstr,
 						Set.of(),
@@ -1009,7 +1012,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		traceManager.activateTime(result.schedule());
 		waitForTasks();
 		DebuggerCoordinates atRet = traceManager.getCurrent();
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			new UnwindStackCommand(tool, atRet).applyTo(tb.trace, monitor);
 		}
 		waitForDomainObject(tb.trace);
@@ -1038,7 +1041,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		Register sp = program.getCompilerSpec().getStackPointer();
 		waitOn(editor.setRegister(new RegisterValue(sp, BigInteger.valueOf(0x4ff0))));
 
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			tb.trace.getBreakpointManager()
 					.addBreakpoint("Breakpoints[0]", Lifespan.nowOn(0), retInstr,
 						Set.of(),
@@ -1053,7 +1056,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		traceManager.activateTime(result.schedule());
 		waitForTasks();
 		DebuggerCoordinates atRet = traceManager.getCurrent();
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			new UnwindStackCommand(tool, atRet).applyTo(tb.trace, monitor);
 		}
 		waitForDomainObject(tb.trace);
@@ -1163,7 +1166,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 			ProgramLocation programLocation, DebuggerCoordinates current,
 			FieldLocation fieldLocation, Field field) throws Throwable {
 		VariableValueTable table = new VariableValueTable();
-		List<String> warnings = new ArrayList<>();
+		StackUnwindWarningSet warnings = new StackUnwindWarningSet();
 		waitOn(valuesService.fillVariableValueTable(table, programLocation, current,
 			fieldLocation, field, warnings));
 		table.add(new WarningsRow(warnings));
@@ -1261,7 +1264,7 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 		TraceLocation dynLoc = mappingService.getOpenMappedLocation(tb.trace,
 			new ProgramLocation(program, stIns.getAddress()), current.getSnap());
 		Address dynamicAddress = dynLoc.getAddress();
-		try (UndoableTransaction tid = tb.startTransaction()) {
+		try (Transaction tx = tb.startTransaction()) {
 			int length = stIns.getLength();
 			assertEquals(length, tb.trace.getMemoryManager()
 					.putBytes(current.getSnap(), dynamicAddress,
@@ -1386,7 +1389,22 @@ public class StackUnwinderTest extends AbstractGhidraHeadedDebuggerGUITest {
 	public static HoverLocation findTokenLocation(DecompilerPanel decompilerPanel,
 			Function function, String tokText, String fieldText) {
 		DecompileResults results = waitForValue(() -> {
-			ProgramLocation pLoc = decompilerPanel.getCurrentLocation();
+			ProgramLocation pLoc;
+			try {
+				pLoc = decompilerPanel.getCurrentLocation();
+			}
+			catch (NullPointerException e) {
+				/**
+				 * HACK: There's an unlikely race condition where the layout controller has created
+				 * the array of layouts but not fully populated it by the time we ask for the
+				 * current location. This may cause a line we inspect to still have null in it and
+				 * throw an NPE. Whatever. Just catch the thing and return null so that we try
+				 * again. As far as I can tell, this is not indicative of a problem in production,
+				 * because the controller won't issue an updated event until that array is fully
+				 * populated.
+				 */
+				return null;
+			}
 			if (!(pLoc instanceof DecompilerLocation dLoc)) {
 				return null;
 			}
