@@ -24,11 +24,13 @@ import java.util.function.BiFunction;
 
 import org.apache.commons.lang3.tuple.Pair;
 
+import db.Transaction;
 import ghidra.framework.data.DomainObjectEventQueues;
 import ghidra.framework.model.*;
 import ghidra.framework.options.Options;
 import ghidra.framework.store.LockException;
 import ghidra.program.database.IntRangeMap;
+import ghidra.program.database.ProgramOverlayAddressSpace;
 import ghidra.program.database.map.AddressMap;
 import ghidra.program.model.address.*;
 import ghidra.program.model.data.*;
@@ -42,15 +44,14 @@ import ghidra.program.model.util.AddressSetPropertyMap;
 import ghidra.program.model.util.PropertyMapManager;
 import ghidra.program.util.ChangeManager;
 import ghidra.program.util.ProgramChangeRecord;
-import ghidra.trace.database.DBTrace;
-import ghidra.trace.database.DBTraceTimeViewport;
+import ghidra.trace.database.*;
 import ghidra.trace.database.listing.DBTraceCodeSpace;
 import ghidra.trace.database.listing.DBTraceDefinedUnitsView;
 import ghidra.trace.database.memory.DBTraceMemorySpace;
-import ghidra.trace.database.symbol.DBTraceFunctionSymbolView;
 import ghidra.trace.model.*;
 import ghidra.trace.model.Trace.*;
-import ghidra.trace.model.TraceTimeViewport.*;
+import ghidra.trace.model.TraceTimeViewport.Occlusion;
+import ghidra.trace.model.TraceTimeViewport.RangeQueryOcclusion;
 import ghidra.trace.model.bookmark.TraceBookmark;
 import ghidra.trace.model.bookmark.TraceBookmarkType;
 import ghidra.trace.model.data.TraceBasedDataTypeManager;
@@ -63,8 +64,7 @@ import ghidra.trace.model.thread.TraceThread;
 import ghidra.trace.util.TraceAddressSpace;
 import ghidra.util.*;
 import ghidra.util.datastruct.WeakValueHashMap;
-import ghidra.util.exception.CancelledException;
-import ghidra.util.exception.DuplicateNameException;
+import ghidra.util.exception.*;
 import ghidra.util.task.TaskMonitor;
 
 /**
@@ -82,7 +82,8 @@ public class DBTraceProgramView implements TraceProgramView {
 	public static final int TIME_INTERVAL = 100;
 	public static final int BUF_SIZE = 1000;
 
-	protected class EventTranslator extends TraceDomainObjectListener {
+	protected class EventTranslator extends TypedEventDispatcher
+			implements DBTraceDirectChangeListener {
 		public EventTranslator() {
 			listenForUntyped(DomainObject.DO_OBJECT_SAVED, this::eventPassthrough);
 			listenForUntyped(DomainObject.DO_DOMAIN_FILE_CHANGED, this::eventPassthrough);
@@ -128,22 +129,8 @@ public class DBTraceProgramView implements TraceProgramView {
 			listenFor(TraceDataTypeChangeType.RENAMED, this::dataTypeRenamed);
 			listenFor(TraceDataTypeChangeType.DELETED, this::dataTypeDeleted);
 
-			listenFor(TraceFunctionChangeType.CHANGED, this::functionChanged);
-			listenFor(TraceFunctionChangeType.CHANGED_PURGE, this::functionChangedPurge);
-			listenFor(TraceFunctionChangeType.CHANGED_INLINE, this::functionChangedInline);
-			listenFor(TraceFunctionChangeType.CHANGED_NORETURN, this::functionChangedNoReturn);
-			listenFor(TraceFunctionChangeType.CHANGED_CALL_FIXUP, this::functionChangedCallFixup);
-			listenFor(TraceFunctionChangeType.CHANGED_RETURN, this::functionChangedReturn);
-			listenFor(TraceFunctionChangeType.CHANGED_PARAMETERS, this::functionChangedParameters);
-			listenFor(TraceFunctionChangeType.CHANGED_THUNK, this::functionChangedThunk);
-			listenFor(TraceFunctionChangeType.CHANGED_BODY, this::functionChangedBody);
-			listenFor(TraceFunctionChangeType.TAG_APPLIED, this::functionChangedTagApplied);
-			listenFor(TraceFunctionChangeType.TAG_REMOVED, this::functionChangedTagRemoved);
-
-			listenFor(TraceFunctionTagChangeType.ADDED, this::functionTagAdded);
-			listenFor(TraceFunctionTagChangeType.CHANGED, this::functionTagChanged);
-			listenFor(TraceFunctionTagChangeType.DELETED, this::functionTagDeleted);
-
+			listenFor(TraceInstructionChangeType.LENGTH_OVERRIDE_CHANGED,
+				this::instructionLengthOverrideChanged);
 			listenFor(TraceInstructionChangeType.FLOW_OVERRIDE_CHANGED,
 				this::instructionFlowOverrideChanged);
 			listenFor(TraceInstructionChangeType.FALL_THROUGH_OVERRIDE_CHANGED,
@@ -172,6 +159,11 @@ public class DBTraceProgramView implements TraceProgramView {
 			listenFor(TraceSymbolChangeType.DELETED, this::symbolDeleted);
 		}
 
+		@Override
+		public void changed(DomainObjectChangeRecord event) {
+			handleChangeRecord(event);
+		}
+
 		private void eventPassthrough(DomainObjectChangeRecord rec) {
 			fireEventAllViews(rec);
 		}
@@ -182,8 +174,8 @@ public class DBTraceProgramView implements TraceProgramView {
 		}
 
 		private void bookmarkTypeAdded(TraceBookmarkType type) {
-			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_BOOKMARK_TYPE_ADDED,
-				null, null, type, null, null));
+			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_BOOKMARK_TYPE_ADDED, null,
+				null, type, null, null));
 		}
 
 		private void bookmarkAdded(TraceAddressSpace space, TraceBookmark bm) {
@@ -242,14 +234,14 @@ public class DBTraceProgramView implements TraceProgramView {
 		}
 
 		private void categoryAdded(long id, Category oldIsNull, Category added) {
-			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_CATEGORY_ADDED, null,
-				null, null, oldIsNull, added));
+			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_CATEGORY_ADDED, null, null,
+				null, oldIsNull, added));
 		}
 
 		private void categoryMoved(long id, CategoryPath oldPath, CategoryPath newPath) {
 			Category category = getDataTypeManager().getCategory(id);
-			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_CATEGORY_MOVED, null,
-				null, null, oldPath, category));
+			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_CATEGORY_MOVED, null, null,
+				null, oldPath, category));
 		}
 
 		private void categoryRenamed(long id, String oldName, String newName) {
@@ -309,8 +301,8 @@ public class DBTraceProgramView implements TraceProgramView {
 
 		protected void fireCodeRemoved(DomainObjectEventQueues queues, Address min, Address max,
 				TraceCodeUnit removed) {
-			queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_CODE_REMOVED,
-				min, max, null, removed, null));
+			queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_CODE_REMOVED, min, max,
+				null, removed, null));
 		}
 
 		private void codeFragmentChanged(TraceAddressSpace space, TraceAddressSnapRange range,
@@ -346,14 +338,13 @@ public class DBTraceProgramView implements TraceProgramView {
 		}
 
 		private void commentChanged(int docrType, TraceAddressSpace space,
-				TraceAddressSnapRange range,
-				String oldValue, String newValue) {
+				TraceAddressSnapRange range, String oldValue, String newValue) {
 			DomainObjectEventQueues queues = isVisible(space, range);
 			if (queues == null) {
 				return;
 			}
-			queues.fireEvent(new ProgramChangeRecord(docrType,
-				range.getX1(), range.getX2(), null, oldValue, newValue));
+			queues.fireEvent(new ProgramChangeRecord(docrType, range.getX1(), range.getX2(), null,
+				oldValue, newValue));
 		}
 
 		private void commentEolChanged(TraceAddressSpace space, TraceAddressSnapRange range,
@@ -432,14 +423,14 @@ public class DBTraceProgramView implements TraceProgramView {
 		}
 
 		private void dataTypeChanged(long id, DataType oldIsNull, DataType changed) {
-			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_DATA_TYPE_CHANGED,
-				null, null, null, oldIsNull, changed));
+			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_DATA_TYPE_CHANGED, null,
+				null, null, oldIsNull, changed));
 		}
 
 		private void dataTypeReplaced(long id, DataTypePath oldPath, DataTypePath newPath) {
 			DataType newType = getDataTypeManager().getDataType(id);
-			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_DATA_TYPE_REPLACED,
-				null, null, null, newPath, newType));
+			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_DATA_TYPE_REPLACED, null,
+				null, null, newPath, newType));
 		}
 
 		private void dataTypeMoved(long id, DataTypePath oldPath, DataTypePath newPath) {
@@ -451,114 +442,13 @@ public class DBTraceProgramView implements TraceProgramView {
 
 		private void dataTypeRenamed(long id, String oldName, String newName) {
 			DataType dataType = getDataTypeManager().getDataType(id);
-			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_DATA_TYPE_RENAMED,
-				null, null, null, oldName, dataType));
+			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_DATA_TYPE_RENAMED, null,
+				null, null, oldName, dataType));
 		}
 
 		private void dataTypeDeleted(long id, DataTypePath oldPath, DataTypePath newIsNull) {
-			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_DATA_TYPE_REMOVED,
-				null, null, null, oldPath, newIsNull));
-		}
-
-		private void gatherThunksTo(Collection<TraceFunctionSymbol> into,
-				TraceFunctionSymbol function) {
-			into.add(function);
-			for (Address address : function.getFunctionThunkAddresses()) {
-				TraceFunctionSymbol thunkTo = functionManager.getFunctionAt(address);
-				if (thunkTo != null) {
-					gatherThunksTo(into, thunkTo);
-				}
-			}
-		}
-
-		private Collection<TraceFunctionSymbol> gatherThunksTo(TraceFunctionSymbol function) {
-			List<TraceFunctionSymbol> result = new ArrayList<>();
-			gatherThunksTo(result, function);
-			return result;
-		}
-
-		private void functionChangedGeneric(TraceAddressSpace space, TraceFunctionSymbol function,
-				int type, int subType) {
-			DomainObjectEventQueues queues = isFunctionVisible(space, function);
-			if (queues == null) {
-				return;
-			}
-			for (TraceFunctionSymbol f : gatherThunksTo(function)) {
-				queues.fireEvent(new ProgramChangeRecord(type, subType, f.getEntryPoint(),
-					f.getEntryPoint(), f, null, null));
-			}
-		}
-
-		private void functionChanged(TraceAddressSpace space, TraceFunctionSymbol function) {
-			functionChangedGeneric(space, function, ChangeManager.DOCR_FUNCTION_CHANGED, 0);
-		}
-
-		private void functionChangedPurge(TraceAddressSpace space, TraceFunctionSymbol function) {
-			functionChangedGeneric(space, function, ChangeManager.DOCR_FUNCTION_CHANGED,
-				ChangeManager.FUNCTION_CHANGED_PURGE);
-		}
-
-		private void functionChangedInline(TraceAddressSpace space, TraceFunctionSymbol function) {
-			functionChangedGeneric(space, function, ChangeManager.DOCR_FUNCTION_CHANGED,
-				ChangeManager.FUNCTION_CHANGED_INLINE);
-		}
-
-		private void functionChangedNoReturn(TraceAddressSpace space,
-				TraceFunctionSymbol function) {
-			functionChangedGeneric(space, function, ChangeManager.DOCR_FUNCTION_CHANGED,
-				ChangeManager.FUNCTION_CHANGED_NORETURN);
-		}
-
-		private void functionChangedCallFixup(TraceAddressSpace space,
-				TraceFunctionSymbol function) {
-			functionChangedGeneric(space, function, ChangeManager.DOCR_FUNCTION_CHANGED,
-				ChangeManager.FUNCTION_CHANGED_CALL_FIXUP);
-		}
-
-		private void functionChangedReturn(TraceAddressSpace space, TraceFunctionSymbol function) {
-			functionChangedGeneric(space, function, ChangeManager.DOCR_FUNCTION_CHANGED,
-				ChangeManager.FUNCTION_CHANGED_RETURN);
-		}
-
-		private void functionChangedParameters(TraceAddressSpace space,
-				TraceFunctionSymbol function) {
-			functionChangedGeneric(space, function, ChangeManager.DOCR_FUNCTION_CHANGED,
-				ChangeManager.FUNCTION_CHANGED_PARAMETERS);
-		}
-
-		private void functionChangedThunk(TraceAddressSpace space, TraceFunctionSymbol function) {
-			functionChangedGeneric(space, function, ChangeManager.DOCR_FUNCTION_CHANGED,
-				ChangeManager.FUNCTION_CHANGED_THUNK);
-		}
-
-		private void functionChangedBody(TraceAddressSpace space, TraceFunctionSymbol function) {
-			functionChangedGeneric(space, function, ChangeManager.DOCR_FUNCTION_BODY_CHANGED, 0);
-		}
-
-		private void functionChangedTagApplied(TraceAddressSpace space,
-				TraceFunctionSymbol function) {
-			functionChangedGeneric(space, function, ChangeManager.DOCR_TAG_ADDED_TO_FUNCTION, 0);
-		}
-
-		private void functionChangedTagRemoved(TraceAddressSpace space,
-				TraceFunctionSymbol function) {
-			functionChangedGeneric(space, function, ChangeManager.DOCR_TAG_REMOVED_FROM_FUNCTION,
-				0);
-		}
-
-		private void functionTagAdded(FunctionTag tag) {
-			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_FUNCTION_TAG_CREATED,
-				null, null, tag, null, null));
-		}
-
-		private void functionTagChanged(FunctionTag tag) {
-			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_FUNCTION_TAG_CHANGED,
-				null, null, tag, null, null));
-		}
-
-		private void functionTagDeleted(FunctionTag tag) {
-			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_FUNCTION_TAG_DELETED,
-				null, null, tag, null, null));
+			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_DATA_TYPE_REMOVED, null,
+				null, null, oldPath, newIsNull));
 		}
 
 		private void instructionFlowOverrideChanged(TraceAddressSpace space,
@@ -578,7 +468,17 @@ public class DBTraceProgramView implements TraceProgramView {
 				return;
 			}
 			queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_FALLTHROUGH_CHANGED,
-				instruction.getMinAddress(), instruction.getMaxAddress(), null, null, null));
+				instruction.getMinAddress(), instruction.getMinAddress(), null, null, null));
+		}
+
+		private void instructionLengthOverrideChanged(TraceAddressSpace space,
+				TraceInstruction instruction, int oldLengthOverride, int newLengthOverride) {
+			DomainObjectEventQueues queues = isCodeVisible(space, instruction);
+			if (queues == null) {
+				return;
+			}
+			queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_LENGTH_OVERRIDE_CHANGED,
+				instruction.getMinAddress(), instruction.getMinAddress(), null, null, null));
 		}
 
 		private void memoryBytesChanged(TraceAddressSpace space, TraceAddressSnapRange range,
@@ -623,19 +523,19 @@ public class DBTraceProgramView implements TraceProgramView {
 			boolean inOld = isRegionVisible(region, oldSpan);
 			boolean inNew = isRegionVisible(region, newSpan);
 			if (inOld && !inNew) {
-				eventQueues.fireEvent(
-					new ProgramChangeRecord(ChangeManager.DOCR_MEMORY_BLOCK_REMOVED,
-						region.getMinAddress(), region.getMaxAddress(), null, null, null));
+				eventQueues
+						.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_MEMORY_BLOCK_REMOVED,
+							region.getMinAddress(), region.getMaxAddress(), null, null, null));
 				// NOTE: MemoryMapDB does this, too. Otherwise, CodeBrowserPlugin does not hear.
-				eventQueues.fireEvent(
-					new DomainObjectChangeRecord(DomainObject.DO_OBJECT_RESTORED));
+				eventQueues
+						.fireEvent(new DomainObjectChangeRecord(DomainObject.DO_OBJECT_RESTORED));
 			}
 			if (!inOld && inNew) {
 				eventQueues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_MEMORY_BLOCK_ADDED,
 					region.getMinAddress(), region.getMaxAddress(), null, null, null));
 				// NOTE: MemoryMapDB does this, too. Otherwise, CodeBrowserPlugin does not hear.
-				eventQueues.fireEvent(
-					new DomainObjectChangeRecord(DomainObject.DO_OBJECT_RESTORED));
+				eventQueues
+						.fireEvent(new DomainObjectChangeRecord(DomainObject.DO_OBJECT_RESTORED));
 			}
 		}
 
@@ -653,8 +553,8 @@ public class DBTraceProgramView implements TraceProgramView {
 		}
 
 		private void sourceArchiveAdded(UniversalID id) {
-			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_SOURCE_ARCHIVE_ADDED,
-				null, null, id, null, null));
+			fireEventAllViews(new ProgramChangeRecord(ChangeManager.DOCR_SOURCE_ARCHIVE_ADDED, null,
+				null, id, null, null));
 		}
 
 		private void sourceArchiveChanged(UniversalID id) {
@@ -662,39 +562,12 @@ public class DBTraceProgramView implements TraceProgramView {
 				null, null, id, null, null));
 		}
 
-		private void checkVariableFunctionChanged(TraceAddressSpace space, TraceSymbol symbol) {
-			if (!(symbol instanceof TraceVariableSymbol)) {
-				return;
-			}
-			TraceFunctionSymbol function = ((TraceVariableSymbol) symbol).getFunction();
-			if (function == null) {
-				return;
-			}
-			int subType = symbol instanceof TraceParameterSymbol ? //
-					ChangeManager.FUNCTION_CHANGED_PARAMETERS : 0;
-			for (TraceFunctionSymbol f : gatherThunksTo(function)) {
-				// NOTE: Should probably not see functions in register views anyway...
-				DomainObjectEventQueues queues = getEventQueues(space);
-				if (queues == null) {
-					continue;
-				}
-				queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_FUNCTION_CHANGED,
-					subType, f.getEntryPoint(), f.getEntryPoint(), f, null, null));
-			}
-		}
-
 		private void symbolAdded(TraceAddressSpace space, TraceSymbol symbol) {
 			DomainObjectEventQueues queues = isSymbolVisible(space, symbol);
 			if (queues == null) {
 				return;
 			}
 			fireSymbolAdded(queues, symbol);
-			if (symbol instanceof TraceFunctionSymbol) {
-				TraceFunctionSymbol function = (TraceFunctionSymbol) symbol;
-				queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_FUNCTION_ADDED,
-					function.getEntryPoint(), function.getEntryPoint(), function, null, null));
-			}
-			checkVariableFunctionChanged(space, symbol);
 		}
 
 		public void fireSymbolAdded(DomainObjectEventQueues queues, TraceSymbol symbol) {
@@ -709,7 +582,6 @@ public class DBTraceProgramView implements TraceProgramView {
 			}
 			queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_SYMBOL_SOURCE_CHANGED,
 				symbol.getAddress(), symbol.getAddress(), symbol, null, null));
-			checkVariableFunctionChanged(space, symbol);
 		}
 
 		private void symbolSetAsPrimary(TraceAddressSpace space, TraceSymbol symbol,
@@ -726,7 +598,6 @@ public class DBTraceProgramView implements TraceProgramView {
 			assert oldQueues == newQueues || oldQueues == null;
 			newQueues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_SYMBOL_SET_AS_PRIMARY,
 				symbol.getAddress(), symbol.getAddress(), null, oldPrimary, newPrimary));
-			checkVariableFunctionChanged(space, symbol);
 		}
 
 		private void symbolRenamed(TraceAddressSpace space, TraceSymbol symbol, String oldName,
@@ -737,7 +608,6 @@ public class DBTraceProgramView implements TraceProgramView {
 			}
 			queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_SYMBOL_RENAMED,
 				symbol.getAddress(), symbol.getAddress(), symbol, oldName, newName));
-			checkVariableFunctionChanged(space, symbol);
 		}
 
 		private void symbolParentChanged(TraceAddressSpace space, TraceSymbol symbol,
@@ -748,7 +618,6 @@ public class DBTraceProgramView implements TraceProgramView {
 			}
 			queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_SYMBOL_SCOPE_CHANGED,
 				symbol.getAddress(), symbol.getAddress(), symbol, oldParent, newParent));
-			checkVariableFunctionChanged(space, symbol);
 		}
 
 		private void symbolAssociationAdded(TraceAddressSpace space, TraceSymbol symbol,
@@ -758,9 +627,8 @@ public class DBTraceProgramView implements TraceProgramView {
 				return;
 			}
 			// Strange. This is fired as if by the reference rather than the symbol
-			queues.fireEvent(
-				new ProgramChangeRecord(ChangeManager.DOCR_SYMBOL_ASSOCIATION_ADDED,
-					newRef.getFromAddress(), newRef.getFromAddress(), newRef, null, symbol));
+			queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_SYMBOL_ASSOCIATION_ADDED,
+				newRef.getFromAddress(), newRef.getFromAddress(), newRef, null, symbol));
 		}
 
 		private void symbolAssociationRemoved(TraceAddressSpace space, TraceSymbol symbol,
@@ -782,7 +650,6 @@ public class DBTraceProgramView implements TraceProgramView {
 			}
 			queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_SYMBOL_ADDRESS_CHANGED,
 				oldAddress, oldAddress, symbol, oldAddress, newAddress));
-			checkVariableFunctionChanged(space, symbol);
 		}
 
 		private void symbolLifespanChanged(TraceAddressSpace space, TraceSymbolWithLifespan symbol,
@@ -795,20 +662,9 @@ public class DBTraceProgramView implements TraceProgramView {
 			boolean inNew = isSymbolWithLifespanVisible(symbol, newSpan);
 			if (inOld && !inNew) {
 				fireSymbolRemoved(queues, symbol);
-				if (symbol instanceof TraceFunctionSymbol) {
-					TraceFunctionSymbol function = (TraceFunctionSymbol) symbol;
-					queues.fireEvent(new ProgramChangeRecord(
-						ChangeManager.DOCR_FUNCTION_REMOVED, function.getEntryPoint(),
-						function.getEntryPoint(), function, function.getBody(), null));
-				}
 			}
 			if (!inOld && inNew) {
 				fireSymbolAdded(queues, symbol);
-				if (symbol instanceof TraceFunctionSymbol) {
-					TraceFunctionSymbol function = (TraceFunctionSymbol) symbol;
-					queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_FUNCTION_ADDED,
-						function.getEntryPoint(), function.getEntryPoint(), function, null, null));
-				}
 			}
 		}
 
@@ -818,19 +674,12 @@ public class DBTraceProgramView implements TraceProgramView {
 				return;
 			}
 			fireSymbolRemoved(queues, symbol);
-			if (symbol instanceof TraceFunctionSymbol) {
-				TraceFunctionSymbol function = (TraceFunctionSymbol) symbol;
-				queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_FUNCTION_REMOVED,
-					function.getEntryPoint(), function.getEntryPoint(), function,
-					function.getBody(), null));
-			}
-			checkVariableFunctionChanged(space, symbol);
 		}
 
 		protected void fireSymbolRemoved(DomainObjectEventQueues queues, TraceSymbol symbol) {
-			queues.fireEvent(new ProgramChangeRecord(ChangeManager.DOCR_SYMBOL_REMOVED,
-				symbol.getAddress(), symbol.getAddress(), symbol, symbol.getName(),
-				symbol.getID()));
+			queues.fireEvent(
+				new ProgramChangeRecord(ChangeManager.DOCR_SYMBOL_REMOVED, symbol.getAddress(),
+					symbol.getAddress(), symbol, symbol.getName(), symbol.getID()));
 		}
 	}
 
@@ -911,8 +760,7 @@ public class DBTraceProgramView implements TraceProgramView {
 		this.viewport = trace.createTimeViewport();
 		this.viewport.setSnap(snap);
 
-		this.eventQueues =
-			new DomainObjectEventQueues(this, TIME_INTERVAL, trace.getLock());
+		this.eventQueues = new DomainObjectEventQueues(this, TIME_INTERVAL, trace.getLock());
 
 		this.regViewsByThread = new WeakValueHashMap<>();
 
@@ -1173,6 +1021,25 @@ public class DBTraceProgramView implements TraceProgramView {
 		return changes;
 	}
 
+	@Override
+	public ProgramOverlayAddressSpace createOverlaySpace(String overlaySpaceName,
+			AddressSpace baseSpace) throws IllegalStateException, DuplicateNameException,
+			InvalidNameException, LockException {
+		throw new UnsupportedOperationException();
+	}
+
+	@Override
+	public void renameOverlaySpace(String oldOverlaySpaceName, String newName)
+			throws NotFoundException, InvalidNameException, DuplicateNameException, LockException {
+		throw new UnsupportedOperationException();
+	}
+
+	@Override
+	public boolean removeOverlaySpace(String overlaySpaceName)
+			throws LockException, NotFoundException {
+		throw new UnsupportedOperationException();
+	}
+
 	@Override
 	public AddressFactory getAddressFactory() {
 		return trace.getBaseAddressFactory();
@@ -1221,7 +1088,7 @@ public class DBTraceProgramView implements TraceProgramView {
 
 	@Override
 	public Address getImageBase() {
-		return language.getAddressFactory().getAddressSet().getMinAddress();
+		return language.getDefaultSpace().getMinAddress();
 	}
 
 	@Override
@@ -1290,6 +1157,11 @@ public class DBTraceProgramView implements TraceProgramView {
 		return 0;
 	}
 
+	@Override
+	public Transaction openTransaction(String description) throws IllegalStateException {
+		return trace.openTransaction(description);
+	}
+
 	@Override
 	public int startTransaction(String description) {
 		return trace.startTransaction(description);
@@ -1306,8 +1178,8 @@ public class DBTraceProgramView implements TraceProgramView {
 	}
 
 	@Override
-	public Transaction getCurrentTransaction() {
-		return trace.getCurrentTransaction();
+	public TransactionInfo getCurrentTransactionInfo() {
+		return trace.getCurrentTransactionInfo();
 	}
 
 	@Override
@@ -1376,7 +1248,7 @@ public class DBTraceProgramView implements TraceProgramView {
 	protected synchronized EventTranslator getEventTranslator() {
 		if (eventTranslator == null) {
 			eventTranslator = new EventTranslator();
-			trace.addListener(eventTranslator);
+			trace.addDirectChangeListener(eventTranslator);
 		}
 		return eventTranslator;
 	}
@@ -1563,6 +1435,16 @@ public class DBTraceProgramView implements TraceProgramView {
 		return trace.getRedoName();
 	}
 
+	@Override
+	public List<String> getAllUndoNames() {
+		return trace.getAllUndoNames();
+	}
+
+	@Override
+	public List<String> getAllRedoNames() {
+		return trace.getAllRedoNames();
+	}
+
 	@Override
 	public void addTransactionListener(TransactionListener listener) {
 		trace.addTransactionListener(listener);
@@ -1594,8 +1476,8 @@ public class DBTraceProgramView implements TraceProgramView {
 		memory.updateChangeRegionBlockFlags(region);
 	}
 
-	public void updateMemoryChangeRegionBlockRange(TraceMemoryRegion region,
-			AddressRange oldRange, AddressRange newRange) {
+	public void updateMemoryChangeRegionBlockRange(TraceMemoryRegion region, AddressRange oldRange,
+			AddressRange newRange) {
 		if (!isRegionVisible(region)) {
 			return;
 		}
@@ -1695,8 +1577,7 @@ public class DBTraceProgramView implements TraceProgramView {
 					return RangeQueryOcclusion.super.occluded(cu, range, span);
 				}
 				byte[] memBytes = new byte[cu.getLength()];
-				memSpace.getBytes(span.lmax(), cu.getMinAddress(),
-					ByteBuffer.wrap(memBytes));
+				memSpace.getBytes(span.lmax(), cu.getMinAddress(), ByteBuffer.wrap(memBytes));
 				byte[] cuBytes;
 				try {
 					cuBytes = cu.getBytes();
@@ -1714,8 +1595,7 @@ public class DBTraceProgramView implements TraceProgramView {
 
 			@Override
 			public Iterable<? extends TraceCodeUnit> query(AddressRange range, Lifespan span) {
-				return definedUnits == null
-						? Collections.emptyList()
+				return definedUnits == null ? Collections.emptyList()
 						: definedUnits.get(span.lmax(), range, true);
 			}
 
@@ -1759,74 +1639,20 @@ public class DBTraceProgramView implements TraceProgramView {
 		return getEventQueues(space);
 	}
 
-	protected Occlusion<TraceFunctionSymbol> getFunctionOcclusion(TraceFunctionSymbol func) {
-		return new QueryOcclusion<>() {
-			DBTraceFunctionSymbolView functions = trace.getSymbolManager().functions();
-			AddressSetView body = func.getBody();
-
-			@Override
-			public Iterable<? extends TraceFunctionSymbol> query(AddressRange range,
-					Lifespan span) {
-				// NB. No functions in register space!
-				return functions.getIntersecting(Lifespan.at(span.lmax()), null, range,
-					false);
-			}
-
-			public boolean itemOccludes(AddressRange range, TraceFunctionSymbol f) {
-				return body.intersects(f.getBody());
-			}
-
-			@Override
-			public void removeItem(AddressSet remains, TraceFunctionSymbol t) {
-				remains.delete(t.getBody());
-			}
-		};
-	}
-
-	protected boolean isFunctionVisible(TraceFunctionSymbol function, Lifespan lifespan) {
-		AddressSetView body = function.getBody();
-		AddressRange bodySpan =
-			new AddressRangeImpl(body.getMinAddress(), body.getMaxAddress());
-		return viewport.isCompletelyVisible(bodySpan, function.getLifespan(), function,
-			getFunctionOcclusion(function));
-	}
-
-	protected DomainObjectEventQueues isFunctionVisible(TraceAddressSpace space,
-			TraceFunctionSymbol function) {
-		DomainObjectEventQueues queues = getEventQueues(space);
-		if (queues == null) {
-			return null;
-		}
-		return isFunctionVisible(function, function.getLifespan()) ? queues : null;
-	}
-
 	protected boolean isSymbolWithLifespanVisible(TraceSymbolWithLifespan symbol,
 			Lifespan lifespan) {
-		if (symbol instanceof TraceFunctionSymbol) {
-			TraceFunctionSymbol func = (TraceFunctionSymbol) symbol;
-			return isFunctionVisible(func, lifespan);
-		}
 		if (!viewport.containsAnyUpper(lifespan)) {
 			return false;
 		}
 		return true;
 	}
 
-	protected DomainObjectEventQueues isSymbolVisible(TraceAddressSpace space,
-			TraceSymbol symbol) {
+	protected DomainObjectEventQueues isSymbolVisible(TraceAddressSpace space, TraceSymbol symbol) {
 		// NB. Most symbols do not occlude each other
 		DomainObjectEventQueues queues = getEventQueues(space);
 		if (queues == null) {
 			return null;
 		}
-		if (symbol instanceof TraceVariableSymbol) {
-			TraceVariableSymbol var = (TraceVariableSymbol) symbol;
-			TraceFunctionSymbol func = var.getFunction();
-			if (func == null) {
-				return queues;
-			}
-			return isFunctionVisible(space, func);
-		}
 		if (!(symbol instanceof TraceSymbolWithLifespan)) {
 			return queues;
 		}
@@ -1850,8 +1676,7 @@ public class DBTraceProgramView implements TraceProgramView {
 	protected Occlusion<TraceMemoryRegion> regionOcclusion = new RangeQueryOcclusion<>() {
 		@Override
 		public Iterable<? extends TraceMemoryRegion> query(AddressRange range, Lifespan span) {
-			return trace.getMemoryManager()
-					.getRegionsIntersecting(Lifespan.at(span.lmax()), range);
+			return trace.getMemoryManager().getRegionsIntersecting(Lifespan.at(span.lmax()), range);
 		}
 
 		@Override
@@ -1865,7 +1690,6 @@ public class DBTraceProgramView implements TraceProgramView {
 	}
 
 	protected boolean isRegionVisible(TraceMemoryRegion reg, Lifespan lifespan) {
-		return viewport.isCompletelyVisible(reg.getRange(), lifespan, reg,
-			regionOcclusion);
+		return viewport.isCompletelyVisible(reg.getRange(), lifespan, reg, regionOcclusion);
 	}
 }
