@@ -26,6 +26,7 @@ import ghidra.dbg.util.PathPattern;
 import ghidra.dbg.util.PathPredicates;
 import ghidra.trace.model.*;
 import ghidra.trace.model.Lifespan.LifeSet;
+import ghidra.trace.model.target.TraceObject.ConflictResolution;
 
 /**
  * The trace record of an observed {@link TargetObject}
@@ -47,6 +48,13 @@ public interface TraceObject extends TraceUniqueObject {
 	 */
 	Trace getTrace();
 
+	/**
+	 * Get the database key for this object
+	 * 
+	 * @return the key
+	 */
+	long getKey();
+
 	/**
 	 * Get the root of the tree containing this object
 	 * 
@@ -171,7 +179,11 @@ public interface TraceObject extends TraceUniqueObject {
 		 * Throw {@link DuplicateKeyException} if the specified lifespan would result in conflicting
 		 * entries
 		 */
-		DENY;
+		DENY,
+		/**
+		 * Adjust the new entry to fit into the span available, possibly ignoring it altogether
+		 */
+		ADJUST;
 	}
 
 	/**
@@ -466,10 +478,11 @@ public interface TraceObject extends TraceUniqueObject {
 	 * 
 	 * @param span the span which the found paths must intersect
 	 * @param targetIf the target interface class
+	 * @param requireCanonical if the objects must be found within their canonical container
 	 * @return the stream of found paths to values
 	 */
 	Stream<? extends TraceObjectValPath> querySuccessorsTargetInterface(Lifespan span,
-			Class<? extends TargetObject> targetIf);
+			Class<? extends TargetObject> targetIf, boolean requireCanonical);
 
 	/**
 	 * Search for successors providing the given interface and retrieve those interfaces
@@ -477,10 +490,11 @@ public interface TraceObject extends TraceUniqueObject {
 	 * @param <I> the interface type
 	 * @param span the span which the found objects must intersect
 	 * @param ifClass the interface class
+	 * @param requireCanonical if the objects must be found within their canonical container
 	 * @return the stream of interfaces
 	 */
 	<I extends TraceObjectInterface> Stream<I> querySuccessorsInterface(Lifespan span,
-			Class<I> ifClass);
+			Class<I> ifClass, boolean requireCanonical);
 
 	/**
 	 * Delete this object along with parent and child value entries referring to it
@@ -539,6 +553,9 @@ public interface TraceObject extends TraceUniqueObject {
 	 * @return the suitable object, or null if not found
 	 */
 	default TraceObject querySuitableTargetInterface(Class<? extends TargetObject> targetIf) {
+		if (targetIf == TargetObject.class) {
+			return this;
+		}
 		List<String> path = getRoot().getTargetSchema()
 				.searchForSuitable(targetIf, getCanonicalPath().getKeyList());
 		if (path == null) {
@@ -547,6 +564,25 @@ public interface TraceObject extends TraceUniqueObject {
 		return getTrace().getObjectManager().getObjectByCanonicalPath(TraceObjectKeyPath.of(path));
 	}
 
+	/**
+	 * Search for a suitable object having the given schema
+	 * 
+	 * <p>
+	 * This operates by examining the schema for a unique suitable path, without regard to
+	 * lifespans. If needed, the caller should inspect the object's life.
+	 * 
+	 * @param schema the schema
+	 * @return the suitable object, or null if not found
+	 */
+	default TraceObject querySuitableSchema(TargetObjectSchema schema) {
+		List<String> path = getRoot().getTargetSchema()
+				.searchForSuitable(schema, getCanonicalPath().getKeyList());
+		if (path == null) {
+			return null;
+		}
+		return getTrace().getObjectManager().getObjectByCanonicalPath(TraceObjectKeyPath.of(path));
+	}
+
 	/**
 	 * Search for a suitable register container
 	 * 
