@@ -26,10 +26,13 @@ import java.nio.charset.CharsetEncoder;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.util.Collection;
+import java.util.List;
 
 import db.DBHandle;
+import db.Transaction;
 import generic.theme.GThemeDefaults.Colors.Messages;
 import ghidra.app.plugin.processors.sleigh.SleighLanguage;
+import ghidra.dbg.util.PathPredicates;
 import ghidra.pcode.exec.*;
 import ghidra.pcode.exec.trace.TraceSleighUtils;
 import ghidra.program.disassemble.Disassembler;
@@ -51,10 +54,10 @@ import ghidra.trace.model.*;
 import ghidra.trace.model.guest.TraceGuestPlatform;
 import ghidra.trace.model.guest.TracePlatform;
 import ghidra.trace.model.symbol.TraceReferenceManager;
+import ghidra.trace.model.target.*;
 import ghidra.trace.model.thread.TraceThread;
 import ghidra.util.Msg;
 import ghidra.util.database.DBOpenMode;
-import ghidra.util.database.UndoableTransaction;
 import ghidra.util.exception.*;
 import ghidra.util.task.ConsoleTaskMonitor;
 
@@ -432,8 +435,8 @@ public class ToyDBTraceBuilder implements AutoCloseable {
 	 * 
 	 * @return the transaction handle
 	 */
-	public UndoableTransaction startTransaction() {
-		return UndoableTransaction.start(trace, "Testing");
+	public Transaction startTransaction() {
+		return trace.openTransaction("Testing");
 	}
 
 	/**
@@ -561,7 +564,8 @@ public class ToyDBTraceBuilder implements AutoCloseable {
 		InstructionBlock block = dis.pseudoDisassembleBlock(memBuf, defaultContextValue, 1);
 		Instruction pseudoIns = block.iterator().next();
 		return code.instructions()
-				.create(Lifespan.nowOn(snap), start, platform, pseudoIns.getPrototype(), pseudoIns);
+				.create(Lifespan.nowOn(snap), start, platform, pseudoIns.getPrototype(), pseudoIns,
+					0);
 	}
 
 	/**
@@ -750,6 +754,60 @@ public class ToyDBTraceBuilder implements AutoCloseable {
 		return getLanguage(langID).getCompilerSpecByID(new CompilerSpecID(compID));
 	}
 
+	/**
+	 * Get an object by its canonical path
+	 * 
+	 * @param canonicalPath the canonical path
+	 * @return the object or null
+	 */
+	public TraceObject obj(String canonicalPath) {
+		return trace.getObjectManager()
+				.getObjectByCanonicalPath(TraceObjectKeyPath.parse(canonicalPath));
+	}
+
+	
+	/**
+	 * Get an object by its path pattern
+	 * 
+	 * @param path the path pattern
+	 * @return the object or null
+	 */
+	public TraceObject objAny(String pat) {
+		return objAny(pat, Lifespan.at(0));
+	}
+	public TraceObject objAny(String path, Lifespan span) {
+		return trace.getObjectManager().getObjectsByPath(span, TraceObjectKeyPath.parse(path))
+				.findFirst()
+				.orElse(null);
+	}
+
+	/**
+	 * Get the value (not value entry) of an object
+	 * 
+	 * @param obj the object
+	 * @param snap the snapshot key
+	 * @param key the entry key
+	 * @return the value, possibly null
+	 */
+	public Object objValue(TraceObject obj, long snap, String key) {
+		TraceObjectValue value = obj.getValue(snap, key);
+		return value == null ? null : value.getValue();
+	}
+
+	/**
+	 * List all values matching the given pattern at the given stnap.
+	 * 
+	 * @param snap the snap
+	 * @param pattern the pattern
+	 * @return the list of values
+	 */
+	public List<Object> objValues(long snap, String pattern) {
+		return trace.getObjectManager()
+				.getValuePaths(Lifespan.at(snap), PathPredicates.parse(pattern))
+				.map(p -> p.getDestinationValue(trace.getObjectManager().getRootObject()))
+				.toList();
+	}
+
 	@Override
 	public void close() {
 		if (trace.getConsumerList().contains(this)) {
