@@ -32,14 +32,12 @@ import java.util.function.Consumer;
 import javax.swing.JFrame;
 import javax.swing.JPanel;
 
+import org.apache.commons.collections4.IteratorUtils;
 import org.apache.commons.lang3.tuple.ImmutablePair;
 import org.apache.commons.lang3.tuple.Pair;
 import org.junit.*;
 
-import com.google.common.collect.Iterators;
-
-import db.DBHandle;
-import db.DBRecord;
+import db.*;
 import generic.theme.GThemeDefaults.Colors.Palette;
 import ghidra.util.ColorUtils;
 import ghidra.util.LockHold;
@@ -637,7 +635,7 @@ public class RStarTreeMapTest {
 			super(new DBHandle(), DBOpenMode.CREATE, new ConsoleTaskMonitor(), "Testing", 500, 1000,
 				consumer);
 			storeFactory = new DBCachedObjectStoreFactory(this);
-			try (UndoableTransaction tid = UndoableTransaction.start(this, "CreateMaps")) {
+			try (Transaction tx = openTransaction("CreateMaps")) {
 				tree = new IntRStarTree(storeFactory, DBIntRectStringDataRecord.TABLE_NAME,
 					true, MAX_CHILDREN);
 				map = tree.asSpatialMap();
@@ -725,11 +723,13 @@ public class RStarTreeMapTest {
 	@Test
 	public void testQueryIntersecting() {
 		List<IntRect> expected = new ArrayList<>();
-		Iterators.filter(allRects(range), queryRect::intersects).forEachRemaining(expected::add);
+		IteratorUtils.filteredIterator(allRects(range), queryRect::intersects)
+				.forEachRemaining(expected::add);
 
 		IntRectQuery query = IntRectQuery.intersecting(queryRect);
 		List<IntRect> actual = new ArrayList<>();
-		Iterators.filter(allRects(range), query::testData).forEachRemaining(actual::add);
+		IteratorUtils.filteredIterator(allRects(range), query::testData)
+				.forEachRemaining(actual::add);
 
 		assertEquals(expected, actual);
 	}
@@ -737,11 +737,13 @@ public class RStarTreeMapTest {
 	@Test
 	public void testQueryEnclosing() {
 		List<IntRect> expected = new ArrayList<>();
-		Iterators.filter(allRects(range), queryRect::enclosedBy).forEachRemaining(expected::add);
+		IteratorUtils.filteredIterator(allRects(range), queryRect::enclosedBy)
+				.forEachRemaining(expected::add);
 
 		IntRectQuery query = IntRectQuery.enclosing(queryRect);
 		List<IntRect> actual = new ArrayList<>();
-		Iterators.filter(allRects(range), query::testData).forEachRemaining(actual::add);
+		IteratorUtils.filteredIterator(allRects(range), query::testData)
+				.forEachRemaining(actual::add);
 
 		assertEquals(expected, actual);
 	}
@@ -749,11 +751,13 @@ public class RStarTreeMapTest {
 	@Test
 	public void testQueryEnclosed() {
 		List<IntRect> expected = new ArrayList<>();
-		Iterators.filter(allRects(range), queryRect::encloses).forEachRemaining(expected::add);
+		IteratorUtils.filteredIterator(allRects(range), queryRect::encloses)
+				.forEachRemaining(expected::add);
 
 		IntRectQuery query = IntRectQuery.enclosed(queryRect);
 		List<IntRect> actual = new ArrayList<>();
-		Iterators.filter(allRects(range), query::testData).forEachRemaining(actual::add);
+		IteratorUtils.filteredIterator(allRects(range), query::testData)
+				.forEachRemaining(actual::add);
 
 		assertEquals(expected, actual);
 	}
@@ -763,7 +767,7 @@ public class RStarTreeMapTest {
 		IntRect queryRect1 = rect(1, 1, 12, 13);
 		IntRect queryRect2 = rect(4, 4, 12, 13);
 		List<IntRect> expected = new ArrayList<>();
-		Iterators.filter(allRects(range),
+		IteratorUtils.filteredIterator(allRects(range),
 			r -> queryRect1.intersects(r) && queryRect2.intersects(r))
 				.forEachRemaining(
 					expected::add);
@@ -773,7 +777,8 @@ public class RStarTreeMapTest {
 		IntRectQuery query =
 			IntRectQuery.intersecting(queryRect1).and(IntRectQuery.intersecting(queryRect2));
 		List<IntRect> actual = new ArrayList<>();
-		Iterators.filter(allRects(range), query::testData).forEachRemaining(actual::add);
+		IteratorUtils.filteredIterator(allRects(range), query::testData)
+				.forEachRemaining(actual::add);
 
 		assertEquals(expected, actual);
 	}
@@ -859,7 +864,7 @@ public class RStarTreeMapTest {
 		List<Pair<IntRect, String>> entries = generateRandom(rect(0, 100, 0, 100), 10, 10, 125);
 		obj.tree.checkIntegrity();
 
-		try (UndoableTransaction tid = UndoableTransaction.start(obj, "AddRandom")) {
+		try (Transaction tx = obj.openTransaction("AddRandom")) {
 			for (Entry<IntRect, String> ent : entries) {
 				obj.map.put(ent.getKey(), ent.getValue());
 				obj.tree.checkIntegrity();
@@ -875,7 +880,7 @@ public class RStarTreeMapTest {
 		// NOTE: This "thrashing" test covers nearly all the R*-Tree insertion logic.
 		List<Pair<IntRect, String>> entries = generateRandom(rect(0, 100, 0, 100), 10, 10, 1000);
 		Consumer<List<Pair<IntRect, String>>> inserter = list -> {
-			try (UndoableTransaction tid = UndoableTransaction.start(obj, "AddRandom")) {
+			try (Transaction tx = obj.openTransaction("AddRandom")) {
 				for (Entry<IntRect, String> ent : list) {
 					obj.map.put(ent.getKey(), ent.getValue());
 					// Note, underlying tree is not synchronized, but map is
@@ -903,7 +908,7 @@ public class RStarTreeMapTest {
 
 	@Test
 	public void testIntegrityWith2000VerticallyStackedRects() throws Exception {
-		try (UndoableTransaction tid = UndoableTransaction.start(obj, "AddVertical")) {
+		try (Transaction tx = obj.openTransaction("AddVertical")) {
 			for (int i = 0; i < 2000; i++) {
 				obj.map.put(rect(0, 10, i, i + 1), "Ent" + i);
 				// Note, underlying tree is not synchronized, but map is
@@ -916,7 +921,7 @@ public class RStarTreeMapTest {
 
 	@Test
 	public void testSaveAndLoad() throws IOException, CancelledException, VersionException {
-		try (UndoableTransaction tid = UndoableTransaction.start(obj, "AddRecord")) {
+		try (Transaction tx = obj.openTransaction("AddRecord")) {
 			obj.map.put(rect(1, 5, 6, 10), "Some value");
 		}
 
@@ -958,7 +963,7 @@ public class RStarTreeMapTest {
 		// NOTE: This test is made also to cover the visitation logic.
 		assertTrue(obj.map.isEmpty());
 
-		try (UndoableTransaction tid = UndoableTransaction.start(obj, "AddPoints")) {
+		try (Transaction tx = obj.openTransaction("AddPoints")) {
 			for (Entry<IntRect, String> ent : generatePoints(rect(1, 12, 1, 12))) {
 				obj.map.put(ent.getKey(), ent.getValue());
 			}
@@ -977,7 +982,7 @@ public class RStarTreeMapTest {
 
 	@Test
 	public void testFirst() {
-		try (UndoableTransaction tid = UndoableTransaction.start(obj, "AddPoints")) {
+		try (Transaction tx = obj.openTransaction("AddPoints")) {
 			for (Entry<IntRect, String> ent : generatePoints(rect(1, 12, 1, 12))) {
 				obj.map.put(ent.getKey(), ent.getValue());
 			}
@@ -1015,7 +1020,7 @@ public class RStarTreeMapTest {
 	@Test
 	public void testIterator() {
 		List<Pair<IntRect, String>> points = generatePoints(rect(1, 12, 1, 12));
-		try (UndoableTransaction tid = UndoableTransaction.start(obj, "AddPoints")) {
+		try (Transaction tx = obj.openTransaction("AddPoints")) {
 			for (Entry<IntRect, String> ent : points) {
 				obj.map.put(ent.getKey(), ent.getValue());
 			}
@@ -1045,7 +1050,7 @@ public class RStarTreeMapTest {
 	@Test
 	public void testOrderedIterator() {
 		List<Pair<IntRect, String>> points = generatePoints(rect(1, 12, 1, 12));
-		try (UndoableTransaction tid = UndoableTransaction.start(obj, "AddPoints")) {
+		try (Transaction tx = obj.openTransaction("AddPoints")) {
 			for (Entry<IntRect, String> ent : points) {
 				obj.map.put(ent.getKey(), ent.getValue());
 			}
@@ -1073,13 +1078,13 @@ public class RStarTreeMapTest {
 	public void testRemove() {
 		// TODO: Add a "minimal query including" abstract method to reduce search for removed item
 		List<Pair<IntRect, String>> points = generatePoints(rect(1, 12, 1, 12));
-		try (UndoableTransaction tid = UndoableTransaction.start(obj, "AddPoints")) {
+		try (Transaction tx = obj.openTransaction("AddPoints")) {
 			for (Entry<IntRect, String> ent : points) {
 				obj.map.put(ent.getKey(), ent.getValue());
 			}
 		}
 
-		try (UndoableTransaction tid = UndoableTransaction.start(obj, "RemovePoints")) {
+		try (Transaction tx = obj.openTransaction("RemovePoints")) {
 			assertFalse(obj.map.reduce(IntRectQuery.enclosed(rect(6, 6, 6, 6))).isEmpty());
 			obj.map.remove(rect(6, 6, 6, 6), "NotHere");
 			assertFalse(obj.map.reduce(IntRectQuery.enclosed(rect(6, 6, 6, 6))).isEmpty());
@@ -1099,13 +1104,13 @@ public class RStarTreeMapTest {
 	@Test
 	public void testClear() {
 		List<Pair<IntRect, String>> points = generatePoints(rect(1, 12, 1, 12));
-		try (UndoableTransaction tid = UndoableTransaction.start(obj, "AddPoints")) {
+		try (Transaction tx = obj.openTransaction("AddPoints")) {
 			for (Entry<IntRect, String> ent : points) {
 				obj.map.put(ent.getKey(), ent.getValue());
 			}
 		}
 
-		try (UndoableTransaction tid = UndoableTransaction.start(obj, "RemovePoints")) {
+		try (Transaction tx = obj.openTransaction("RemovePoints")) {
 			obj.map.reduce(IntRectQuery.enclosed(rect(6, 6, 6, 6))).clear();
 			obj.tree.checkIntegrity();
 			assertEquals(143, obj.map.size());
@@ -1135,7 +1140,7 @@ public class RStarTreeMapTest {
 	@Test
 	public void testValuesToArray() {
 		List<Pair<IntRect, String>> points = generatePoints(rect(1, 12, 1, 12));
-		try (UndoableTransaction tid = UndoableTransaction.start(obj, "AddPoints")) {
+		try (Transaction tx = obj.openTransaction("AddPoints")) {
 			for (Entry<IntRect, String> ent : points) {
 				obj.map.put(ent.getKey(), ent.getValue());
 			}
