@@ -23,8 +23,7 @@ import java.util.concurrent.atomic.AtomicInteger;
 import javax.swing.*;
 import javax.swing.tree.TreePath;
 
-import docking.ActionContext;
-import docking.WindowPosition;
+import docking.*;
 import docking.action.*;
 import docking.resources.icons.NumberIcon;
 import docking.widgets.dialogs.NumberInputDialog;
@@ -366,16 +365,15 @@ public class CallTreeProvider extends ComponentProviderAdapter implements Domain
 				doUpdate();
 			}
 		};
-		filterDuplicates
-				.setToolBarData(new ToolBarData(new GIcon("icon.plugin.calltree.filter.duplicates"),
-					filterOptionsToolbarGroup, "1"));
+		filterDuplicates.setToolBarData(new ToolBarData(
+			new GIcon("icon.plugin.calltree.filter.duplicates"), filterOptionsToolbarGroup, "1"));
 		filterDuplicates.setSelected(true);
 		filterDuplicates
 				.setHelpLocation(new HelpLocation(plugin.getName(), "Call_Tree_Action_Filter"));
 		tool.addLocalAction(this, filterDuplicates);
 
 		//
-		// recurse depth		
+		// recurse depth
 		//
 		recurseDepthAction = new DockingAction("Recurse Depth", plugin.getName()) {
 			@Override
@@ -403,7 +401,7 @@ public class CallTreeProvider extends ComponentProviderAdapter implements Domain
 
 		//
 		// navigate outgoing nodes on selection
-		//	
+		//
 		navigationOutgoingAction =
 			new ToggleDockingAction("Navigate Outgoing Nodes", plugin.getName()) {
 
@@ -420,7 +418,7 @@ public class CallTreeProvider extends ComponentProviderAdapter implements Domain
 		tool.addLocalAction(this, navigationOutgoingAction);
 
 		//
-		// navigate incoming nodes on selection	
+		// navigate incoming nodes on selection
 		//
 		navigateIncomingToggleAction =
 			new ToggleDockingAction("Navigation Incoming Location Changes", plugin.getName()) {
@@ -439,8 +437,8 @@ public class CallTreeProvider extends ComponentProviderAdapter implements Domain
 				}
 			};
 
-		// note: the default state is to follow navigation events for the primary provider; 
-		//       non-primary providers will function like snapshots of the function with 
+		// note: the default state is to follow navigation events for the primary provider;
+		//       non-primary providers will function like snapshots of the function with
 		//       which they were activated.
 		navigateIncomingToggleAction.setSelected(isPrimary);
 		navigateIncomingToggleAction.setToolBarData(new ToolBarData(
@@ -704,7 +702,7 @@ public class CallTreeProvider extends ComponentProviderAdapter implements Domain
 			return;
 		}
 
-		// no goto service...navigate the old fashioned way (this doesn't have history)		
+		// no goto service...navigate the old fashioned way (this doesn't have history)
 		plugin.firePluginEvent(new ProgramLocationPluginEvent(getName(), location, currentProgram));
 		isFiringNavigationEvent = false;
 	}
@@ -712,7 +710,7 @@ public class CallTreeProvider extends ComponentProviderAdapter implements Domain
 	@Override
 	public ActionContext getActionContext(MouseEvent e) {
 		if (e == null) {
-			return new ActionContext(this, getActiveComponent());
+			return new DefaultActionContext(this, getActiveComponent());
 		}
 
 		Object source = e.getSource();
@@ -722,7 +720,7 @@ public class CallTreeProvider extends ComponentProviderAdapter implements Domain
 			if (outgoingTree.isMyJTree(jTree)) {
 				gTree = outgoingTree;
 			}
-			return new ActionContext(this, gTree);
+			return new DefaultActionContext(this, gTree);
 		}
 
 		return null;
@@ -813,7 +811,14 @@ public class CallTreeProvider extends ComponentProviderAdapter implements Domain
 	}
 
 	private GTree createTree() {
-		GTree tree = new GTree(new EmptyRootNode());
+		GTree tree = new GTree(new EmptyRootNode()) {
+			@Override
+			protected boolean supportsPopupActions() {
+				// The base tree adds collapse/ expand actions, which we already provide, so signal
+				// that we do not want those actions.
+				return false;
+			}
+		};
 		tree.setPaintHandlesForLeafNodes(false);
 //		tree.setFilterVisible(false);
 		return tree;
@@ -1129,7 +1134,7 @@ public class CallTreeProvider extends ComponentProviderAdapter implements Domain
 				return;
 			}
 
-			// first, if the given node represents the function we have, then we don't need to 
+			// first, if the given node represents the function we have, then we don't need to
 			// go any further
 			if (function.equals(node.getRemoteFunction())) {
 				GTreeNode parent = node.getParent();
@@ -1154,7 +1159,7 @@ public class CallTreeProvider extends ComponentProviderAdapter implements Domain
 		}
 	}
 
-// TODO if we ever want specific staleness detection	
+// TODO if we ever want specific staleness detection
 //	private CallNode findNode(CallNode node, Function newFunction) {
 //		Function function = node.getContainingFunction();
 //		if (function == null) {
