@@ -222,7 +222,9 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 			throw new InvalidDataTypeException("Data types of size 0 are not allowed.");
 		}
 
-		return DataTypeInstance.getDataTypeInstance(resultDt, resultLen);
+		// TODO: Need to handle proper placement for big-endian within a larger component (i.e., right-justified)
+		return DataTypeInstance.getDataTypeInstance(resultDt, resultLen,
+			viewComposite.isPackingEnabled());
 	}
 
 	/**
@@ -271,18 +273,15 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 		try {
 			applyingFieldEdit = true;
 			if (columnIndex == getDataTypeColumn()) {
-				setComponentDataType(rowIndex, value);
+				return setComponentDataType(rowIndex, value);
 			}
 			else if (columnIndex == getNameColumn()) {
-				setComponentName(rowIndex, ((String) value).trim());
+				return setComponentName(rowIndex, ((String) value).trim());
 			}
 			else if (columnIndex == getCommentColumn()) {
-				setComponentComment(rowIndex, (String) value);
+				return setComponentComment(rowIndex, (String) value);
 			}
-			else {
-				return false;
-			}
-			return true;
+			return false;
 		}
 		catch (UsrException e) {
 			setStatus(e.getMessage());
@@ -368,7 +367,7 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 	}
 
 	@Override
-	public void setComponentDataType(int rowIndex, Object dataTypeObject) throws UsrException {
+	public boolean setComponentDataType(int rowIndex, Object dataTypeObject) throws UsrException {
 		DataType previousDt = null;
 		int previousLength = 0;
 		String dtName = "";
@@ -392,7 +391,7 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 		else if (dataTypeObject instanceof String) {
 			String dtString = (String) dataTypeObject;
 			if (dtString.equals(dtName)) {
-				return;
+				return false;
 			}
 			DataTypeManager originalDTM = getOriginalDataTypeManager();
 			newDt = DataTypeHelper.parseDataType(rowIndex, dtString, this, originalDTM,
@@ -400,7 +399,7 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 			newLength = newDt.getLength();
 		}
 		if (newDt == null) {
-			return; // Was nothing and is nothing.
+			return false; // Was nothing and is nothing.
 		}
 
 		if (DataTypeComponent.usesZeroLengthComponent(newDt)) {
@@ -417,7 +416,7 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 			DataTypeInstance sizedDataType = DataTypeHelper.getSizedDataType(provider, newDt,
 				suggestedLength, getMaxReplaceLength(rowIndex));
 			if (sizedDataType == null) {
-				return;
+				return false;
 			}
 			newDt = resolveDataType(sizedDataType.getDataType(), viewDTM,
 				DataTypeConflictHandler.DEFAULT_HANDLER);
@@ -427,7 +426,7 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 			}
 		}
 		if ((previousDt != null) && newDt.isEquivalent(previousDt) && newLength == previousLength) {
-			return;
+			return false;
 		}
 
 		int maxLength = getMaxReplaceLength(rowIndex);
@@ -437,6 +436,7 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 		}
 		setComponentDataTypeInstance(rowIndex, newDt, newLength);
 		notifyCompositeChanged();
+		return true;
 	}
 
 	/**
@@ -703,15 +703,15 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 //==================================================================================================
 
 	@Override
-	public boolean beginEditingField(int rowIndex, int columnIndex) {
+	public boolean beginEditingField(int modelRow, int modelColumn) {
 		if (isEditingField()) {
 			return false;
 		}
 		try {
 			stillBeginningEdit = true; // We want to know we are still beginning an edit when we fix the selection.
 			editingField = true;
-			setLocation(rowIndex, columnIndex);
-			setSelection(new int[] { rowIndex });
+			setLocation(modelRow, modelColumn);
+			setSelection(new int[] { modelRow });
 			notifyEditingChanged();
 		}
 		finally {
@@ -735,17 +735,6 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 		return !settingValueAt && editingField;
 	}
 
-	@Override
-	public int getFirstEditableColumn(int rowIndex) {
-		int numFields = this.getColumnCount();
-		for (int i = 0; i < numFields; i++) {
-			if (this.isCellEditable(rowIndex, i)) {
-				return i;
-			}
-		}
-		return -1;
-	}
-
 	private void notifyEditingChanged() {
 		for (CompositeEditorModelListener listener : listeners) {
 			listener.compositeEditStateChanged(
@@ -766,7 +755,8 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 			int currentIndex = getMinIndexSelected();
 			DataType dt = getNextCycleDataType(cycleGroup);
 			if (dt != null) {
-				DataTypeInstance dti = DataTypeHelper.getFixedLength(this, currentIndex, dt);
+				DataTypeInstance dti = DataTypeHelper.getFixedLength(this, currentIndex, dt,
+					usesAlignedLengthComponents());
 				if (dti == null) {
 					return;
 				}
@@ -941,11 +931,12 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 		}
 		return ((baseDt != null) && !(baseDt instanceof BuiltInDataType) &&
 			!(baseDt instanceof MissingBuiltInDataType) &&
-			((baseDt instanceof Structure) || baseDt instanceof Union || baseDt instanceof Enum));
+			((baseDt instanceof Structure) || (baseDt instanceof Union) ||
+				(baseDt instanceof Enum) || (baseDt instanceof FunctionDefinition)));
 	}
 
 	@Override
-	public boolean isEditFieldAllowed(int rowIndex, int columnIndex) {
+	public boolean isEditFieldAllowed() {
 		return !isEditingField();
 	}
 
@@ -1172,7 +1163,7 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 			dtName = dt.getDisplayName();
 			if (dtString.equals(dtName)) {
 				return DataTypeInstance.getDataTypeInstance(element.getDataType(),
-					element.getLength());
+					element.getLength(), usesAlignedLengthComponents());
 			}
 		}
 
@@ -1204,7 +1195,8 @@ public abstract class CompositeEditorModel extends CompositeViewerModel implemen
 		if (maxLength > 0 && newLength > maxLength) {
 			throw new UsrException(newDt.getDisplayName() + " doesn't fit.");
 		}
-		return DataTypeInstance.getDataTypeInstance(newDt, newLength);
+		return DataTypeInstance.getDataTypeInstance(newDt, newLength,
+			usesAlignedLengthComponents());
 	}
 
 	@SuppressWarnings("unused") // the exception is thrown by subclasses
