@@ -28,11 +28,11 @@ import org.apache.commons.collections4.IterableUtils;
 import org.apache.commons.collections4.map.LazyMap;
 
 import docking.widgets.PopupWindow;
+import generic.theme.*;
 import ghidra.app.nav.Navigatable;
 import ghidra.app.services.*;
 import ghidra.app.util.viewer.listingpanel.*;
 import ghidra.app.util.viewer.util.AddressIndexMap;
-import ghidra.framework.model.DomainObjectClosedListener;
 import ghidra.framework.plugintool.Plugin;
 import ghidra.framework.plugintool.PluginTool;
 import ghidra.program.model.address.Address;
@@ -85,6 +85,7 @@ public class MarkerManager implements MarkerService {
 
 	private List<ChangeListener> listeners = new ArrayList<>();
 	private MarkerClickedListener markerClickedListener = null;
+	private ThemeListener themeListener = e -> themeChanged(e);
 
 	public MarkerManager(Plugin plugin) {
 		this(plugin.getName(), plugin.getTool());
@@ -103,6 +104,13 @@ public class MarkerManager implements MarkerService {
 		primaryMarginProvider = createMarginProvider();
 		primaryOverviewProvider = createOverviewProvider();
 
+		Gui.addThemeListener(themeListener);
+	}
+
+	private void themeChanged(ThemeEvent e) {
+		if (e instanceof ColorChangedThemeEvent) {
+			markerSetCache.clearColors();
+		}
 	}
 
 	private void programClosed(Program program) {
@@ -230,6 +238,7 @@ public class MarkerManager implements MarkerService {
 	}
 
 	public void dispose() {
+		Gui.removeThemeListener(themeListener);
 		updater.dispose();
 		markerSetCache.clear();
 		overviewProviders.forEach(provider -> provider.dispose());
@@ -291,7 +300,7 @@ public class MarkerManager implements MarkerService {
 	List<String> getMarkerTooltipLines(Program program, int y, int x, Address minAddr,
 			Address maxAddr) {
 		MarkerSetCacheEntry entry = markerSetCache.get(program);
-		return entry.getTooltipLines(y, x, minAddr, maxAddr);
+		return entry == null ? List.of() : entry.getTooltipLines(y, x, minAddr, maxAddr);
 	}
 
 	static String getMarkerToolTip(MarkerSetImpl marker, Address a, int x, int y) {
@@ -475,6 +484,12 @@ public class MarkerManager implements MarkerService {
 			return entry;
 		}
 
+		void clearColors() {
+			for (MarkerSetCacheEntry entry : map.values()) {
+				entry.clearColors();
+			}
+		}
+
 		public void clear() {
 			map.clear();
 		}
@@ -494,24 +509,17 @@ public class MarkerManager implements MarkerService {
 		private final AddressColorCache colorCache = new AddressColorCache();
 		private final ColorBlender blender = new ColorBlender();
 
-		private final MarkerSetCache cache;
-		private final Program program;
-		private final DomainObjectClosedListener closeListener = this::programClosed;
-
 		public MarkerSetCacheEntry(MarkerSetCache cache, Program program) {
-			this.cache = cache;
-			this.program = program;
 			/**
 			 * Use this close listener approach instead of plugin events, since we don't get a
 			 * ProgramClosedPluginEvent when a trace view is closed, but we can listen for its
 			 * domain object closing, which works for plain programs, too.
 			 */
-			program.addCloseListener(closeListener);
+			program.addCloseListener(dobj -> cache.programClosed(program));
 		}
 
-		private void programClosed() {
-			program.removeCloseListener(closeListener);
-			cache.programClosed(program);
+		void clearColors() {
+			colorCache.clear();
 		}
 
 		MarkerSetImpl getByName(String name) {
