@@ -15,8 +15,7 @@
  */
 package ghidra.app.plugin.core.searchtext;
 
-import java.awt.Component;
-import java.awt.KeyboardFocusManager;
+import java.awt.*;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.regex.Matcher;
@@ -24,6 +23,8 @@ import java.util.regex.Pattern;
 
 import javax.swing.Icon;
 
+import org.apache.commons.lang3.StringUtils;
+
 import docking.*;
 import docking.action.builder.ActionBuilder;
 import docking.tool.ToolConstants;
@@ -37,13 +38,16 @@ import ghidra.app.nav.Navigatable;
 import ghidra.app.nav.NavigatableRemovalListener;
 import ghidra.app.plugin.PluginCategoryNames;
 import ghidra.app.plugin.ProgramPlugin;
+import ghidra.app.plugin.core.searchtext.Searcher.TextSearchResult;
 import ghidra.app.plugin.core.searchtext.databasesearcher.ProgramDatabaseSearchTableModel;
 import ghidra.app.plugin.core.searchtext.databasesearcher.ProgramDatabaseSearcher;
 import ghidra.app.plugin.core.table.TableComponentProvider;
-import ghidra.app.services.*;
+import ghidra.app.services.GoToService;
+import ghidra.app.services.ProgramManager;
 import ghidra.app.util.*;
 import ghidra.app.util.query.TableService;
 import ghidra.app.util.viewer.field.*;
+import ghidra.app.util.viewer.proxy.ProxyObj;
 import ghidra.framework.model.DomainObject;
 import ghidra.framework.options.OptionsChangeListener;
 import ghidra.framework.options.ToolOptions;
@@ -83,7 +87,7 @@ import ghidra.util.task.*;
 			"on the entire program. Multiple matches are displayed " +
 			"in a query results table. An option allows the search results " +
 			"to be highlighted in the Code Browser.",
-	servicesRequired = { ProgramManager.class, GoToService.class, CodeViewerService.class /*, TableService.class */ }
+	servicesRequired = { ProgramManager.class, GoToService.class }
 )
 //@formatter:on
 public class SearchTextPlugin extends ProgramPlugin implements OptionsChangeListener, TaskListener,
@@ -92,7 +96,6 @@ public class SearchTextPlugin extends ProgramPlugin implements OptionsChangeList
 	private static final Icon SEARCH_MARKER_ICON = new GIcon("icon.base.search.marker");
 
 	private static final String DESCRIPTION = "Search program text for string";
-	private final static Highlight[] NO_HIGHLIGHTS = new Highlight[0];
 
 	private boolean waitingForSearchAll;
 	private SearchTextDialog searchDialog;
@@ -142,20 +145,22 @@ public class SearchTextPlugin extends ProgramPlugin implements OptionsChangeList
 			return;
 		}
 
-		ProgramLocation loc = searchTask.getSearchLocation();
+		TextSearchResult result = searchTask.getSearchLocation();
 		Searcher textSearcher = searchTask.getTextSearcher();
 		SearchOptions searchOptions = textSearcher.getSearchOptions();
-		if (loc != null && loc.equals(currentLocation)) {
+		if (result == null) {
+			searchDialog.setStatusText("Not found");
+		}
+		else if (result.programLocation().equals(currentLocation)) {
 			searchNext(searchTask.getProgram(), searchNavigatable, textSearcher);
 		}
-		else if (loc != null) {
-			searchDialog.setStatusText("");
-			if (goToService.goTo(searchNavigatable, loc, program)) {
-				new HighlightHandler(searchNavigatable, searchOptions, null, program, loc);
-			}
-		}
 		else {
-			searchDialog.setStatusText("Not found");
+			searchDialog.setStatusText("");
+			ProgramLocation loc = result.programLocation();
+			if (goToService.goTo(searchNavigatable, loc, program)) {
+				new SearchTextHighlightProvider(searchNavigatable, searchOptions, null, program,
+					result);
+			}
 		}
 
 		lastSearchedText = searchOptions.getText();
@@ -174,7 +179,7 @@ public class SearchTextPlugin extends ProgramPlugin implements OptionsChangeList
 		ToolOptions opt = tool.getOptions(ToolConstants.TOOL_OPTIONS);
 		opt.removeOptionsChangeListener(this);
 
-		opt = tool.getOptions(PluginConstants.SEARCH_OPTION_NAME);
+		opt = tool.getOptions(SearchConstants.SEARCH_OPTION_NAME);
 		opt.removeOptionsChangeListener(this);
 
 		navigatable = null;
@@ -324,7 +329,8 @@ public class SearchTextPlugin extends ProgramPlugin implements OptionsChangeList
 		searchAllTaskMonitor = tablePanel.getTaskMonitor();
 
 		tableProvider.setHelpLocation(new HelpLocation(HelpTopics.SEARCH, "SearchAllResults"));
-		new HighlightHandler(searchNavigatable, searchOptions, tableProvider, searchProgram, null);
+		new SearchTextHighlightProvider(searchNavigatable, searchOptions, tableProvider,
+			searchProgram, null);
 	}
 
 	private TableComponentProvider<ProgramLocation> getTableResultsProvider(
@@ -333,7 +339,7 @@ public class SearchTextPlugin extends ProgramPlugin implements OptionsChangeList
 		if (navigatable.supportsMarkers()) {
 			return query.showTableWithMarkers(
 				"Search Text - \"" + searchString + "\"  [" + matchType + "]", "Search", model,
-				PluginConstants.SEARCH_HIGHLIGHT_COLOR, SEARCH_MARKER_ICON, "Search", navigatable);
+				SearchConstants.SEARCH_HIGHLIGHT_COLOR, SEARCH_MARKER_ICON, "Search", navigatable);
 		}
 		return query.showTable("Search Text - \"" + searchString + "\"  [" + matchType + "]",
 			"Search", model, "Search", navigatable);
@@ -373,36 +379,34 @@ public class SearchTextPlugin extends ProgramPlugin implements OptionsChangeList
 		String subGroup = getClass().getName();
 
 		new ActionBuilder("Search Text", getName())
-				.menuPath("&Search", "Program &Text...")
-				.menuGroup("search", subGroup)
-				.keyBinding("ctrl shift E")
-				.description(DESCRIPTION)
-				.helpLocation(new HelpLocation(HelpTopics.SEARCH, "Search Text"))
-				.withContext(NavigatableActionContext.class)
-				.validContextWhen(c -> !(c instanceof RestrictedAddressSetContext))
-				.inWindow(ActionBuilder.When.CONTEXT_MATCHES)
-				.supportsDefaultToolContext(true)
-				.onAction(c -> {
-					setNavigatable(c.getNavigatable());
-					displayDialog(c);
-				})
-				.buildAndInstall(tool);
+			.menuPath("&Search", "Program &Text...")
+			.menuGroup("search", subGroup)
+			.keyBinding("ctrl shift E")
+			.description(DESCRIPTION)
+			.helpLocation(new HelpLocation(HelpTopics.SEARCH, "Search Text"))
+			.withContext(NavigatableActionContext.class, true)
+			.validContextWhen(c -> !(c instanceof RestrictedAddressSetContext))
+			.inWindow(ActionBuilder.When.CONTEXT_MATCHES)
+			.onAction(c -> {
+				setNavigatable(c.getNavigatable());
+				displayDialog(c);
+			})
+			.buildAndInstall(tool);
 
 		new ActionBuilder("Repeat Text Search", getName())
-				.menuPath("&Search", "Repeat Text Search")
-				.menuGroup("search", subGroup)
-				.keyBinding("ctrl shift F3")
-				.description(DESCRIPTION)
-				.supportsDefaultToolContext(true)
-				.helpLocation(new HelpLocation(HelpTopics.SEARCH, "Repeat Text Search"))
-				.withContext(NavigatableActionContext.class)
-				.inWindow(ActionBuilder.When.CONTEXT_MATCHES)
-				.enabledWhen(c -> searchedOnce)
-				.onAction(c -> {
-					setNavigatable(c.getNavigatable());
-					searchDialog.repeatSearch();
-				})
-				.buildAndInstall(tool);
+			.menuPath("&Search", "Repeat Text Search")
+			.menuGroup("search", subGroup)
+			.keyBinding("ctrl shift F3")
+			.description(DESCRIPTION)
+			.helpLocation(new HelpLocation(HelpTopics.SEARCH, "Repeat Text Search"))
+			.withContext(NavigatableActionContext.class, true)
+			.inWindow(ActionBuilder.When.CONTEXT_MATCHES)
+			.enabledWhen(c -> searchedOnce)
+			.onAction(c -> {
+				setNavigatable(c.getNavigatable());
+				searchDialog.repeatSearch();
+			})
+			.buildAndInstall(tool);
 	}
 
 	protected void updateNavigatable(ActionContext context) {
@@ -426,29 +430,29 @@ public class SearchTextPlugin extends ProgramPlugin implements OptionsChangeList
 			}
 			searchLimit = newSearchLimit;
 		}
-		else if (optionName.equals(PluginConstants.SEARCH_HIGHLIGHT_NAME)) {
+		else if (optionName.equals(SearchConstants.SEARCH_HIGHLIGHT_NAME)) {
 			doHighlight = ((Boolean) newValue).booleanValue();
 		}
 	}
 
 	private void initializeOptions() {
 
-		ToolOptions opt = tool.getOptions(PluginConstants.SEARCH_OPTION_NAME);
+		ToolOptions opt = tool.getOptions(SearchConstants.SEARCH_OPTION_NAME);
 		HelpLocation loc = new HelpLocation(HelpTopics.SEARCH, "HighlightText");
 
-		opt.registerOption(PluginConstants.SEARCH_HIGHLIGHT_NAME, true, loc,
+		opt.registerOption(SearchConstants.SEARCH_HIGHLIGHT_NAME, true, loc,
 			"Determines whether to highlight the matched string for a search in the listing.");
-		opt.registerThemeColorBinding(PluginConstants.SEARCH_HIGHLIGHT_COLOR_OPTION_NAME,
-			PluginConstants.SEARCH_HIGHLIGHT_COLOR.getId(), null,
+		opt.registerThemeColorBinding(SearchConstants.SEARCH_HIGHLIGHT_COLOR_OPTION_NAME,
+			SearchConstants.SEARCH_HIGHLIGHT_COLOR.getId(), null,
 			"The search result highlight color");
-		opt.registerThemeColorBinding(PluginConstants.SEARCH_HIGHLIGHT_CURRENT_COLOR_OPTION_NAME,
-			PluginConstants.SEARCH_HIGHLIGHT_CURRENT_ADDR_COLOR.getId(), null,
+		opt.registerThemeColorBinding(SearchConstants.SEARCH_HIGHLIGHT_CURRENT_COLOR_OPTION_NAME,
+			SearchConstants.SEARCH_HIGHLIGHT_CURRENT_ADDR_COLOR.getId(), null,
 			"The search result highlight color for the currently selected match");
 
 		searchLimit =
-			opt.getInt(GhidraOptions.OPTION_SEARCH_LIMIT, PluginConstants.DEFAULT_SEARCH_LIMIT);
+			opt.getInt(GhidraOptions.OPTION_SEARCH_LIMIT, SearchConstants.DEFAULT_SEARCH_LIMIT);
 
-		doHighlight = opt.getBoolean(PluginConstants.SEARCH_HIGHLIGHT_NAME, true);
+		doHighlight = opt.getBoolean(SearchConstants.SEARCH_HIGHLIGHT_NAME, true);
 
 		opt.setOptionsHelpLocation(new HelpLocation(HelpTopics.SEARCH, "Search_Text"));
 
@@ -593,20 +597,26 @@ public class SearchTextPlugin extends ProgramPlugin implements OptionsChangeList
 		}
 	}
 
-	class HighlightHandler implements HighlightProvider, ComponentProviderActivationListener {
+	private class SearchTextHighlightProvider
+			implements ListingHighlightProvider, ComponentProviderActivationListener {
 		private SearchOptions searchOptions;
 		private TableComponentProvider<?> provider;
 		private Program highlightProgram;
 		private final Navigatable highlightNavigatable;
-		private ProgramLocation loc;
+		private boolean showAllResults;
 
-		HighlightHandler(Navigatable navigatable, SearchOptions searchOptions,
-				TableComponentProvider<?> provider, Program program, ProgramLocation loc) {
+		// this is non-null for a single search
+		private TextSearchResult searchResult;
+
+		SearchTextHighlightProvider(Navigatable navigatable, SearchOptions searchOptions,
+				TableComponentProvider<?> provider, Program program,
+				TextSearchResult searchResult) {
 			highlightNavigatable = navigatable;
 			this.searchOptions = searchOptions;
 			this.provider = provider;
 			this.highlightProgram = program;
-			this.loc = loc;
+			this.searchResult = searchResult;
+			this.showAllResults = searchResult == null;
 
 			if (provider != null) {
 				provider.addActivationListener(this);
@@ -615,8 +625,10 @@ public class SearchTextPlugin extends ProgramPlugin implements OptionsChangeList
 		}
 
 		@Override
-		public Highlight[] getHighlights(String text, Object obj,
-				Class<? extends FieldFactory> fieldFactoryClass, int cursorTextOffset) {
+		public Highlight[] createHighlights(String text, ListingField field, int cursorTextOffset) {
+
+			Class<? extends FieldFactory> fieldFactoryClass = field.getFieldFactory().getClass();
+
 			if (!doHighlight) {
 				return NO_HIGHLIGHTS;
 			}
@@ -625,7 +637,7 @@ public class SearchTextPlugin extends ProgramPlugin implements OptionsChangeList
 				return NO_HIGHLIGHTS;
 			}
 
-			if (!shouldHighlight(fieldFactoryClass, obj)) {
+			if (!shouldHighlight(field)) {
 				return NO_HIGHLIGHTS;
 			}
 
@@ -634,50 +646,93 @@ public class SearchTextPlugin extends ProgramPlugin implements OptionsChangeList
 				return NO_HIGHLIGHTS;
 			}
 
-			return getHighlights(text, cursorTextOffset);
+			if (showAllResults) {
+				return getAllHighlights(text, cursorTextOffset);
+			}
+
+			Address address = searchResult.programLocation().getAddress();
+			ProxyObj<?> proxy = field.getProxy();
+			if (proxy.contains(address)) {
+				return getSingleSearchHighlight(text, field, cursorTextOffset);
+			}
+
+			return NO_HIGHLIGHTS;
 		}
 
-		private Highlight[] getHighlights(String text, int cursorTextOffset) {
+		private Highlight[] getAllHighlights(String text, int cursorTextOffset) {
 
-			String matchStr = searchOptions.getText().trim();
-			if (matchStr == null || text == null) {
+			String searchText = searchOptions.getText();
+			if (StringUtils.isBlank(searchText) || StringUtils.isBlank(text)) {
 				return NO_HIGHLIGHTS;
 			}
 
 			List<Highlight> list = new ArrayList<>();
 			Pattern regexp =
-				UserSearchUtils.createSearchPattern(matchStr, searchOptions.isCaseSensitive());
+				UserSearchUtils.createSearchPattern(searchText, searchOptions.isCaseSensitive());
 			Matcher matcher = regexp.matcher(text);
 			while (matcher.find()) {
 				int start = matcher.start();
 				int end = matcher.end() - 1;
+				Color hlColor = SearchConstants.SEARCH_HIGHLIGHT_COLOR;
 				if (start <= cursorTextOffset && end >= cursorTextOffset) {
-					list.add(new Highlight(start, end,
-						PluginConstants.SEARCH_HIGHLIGHT_CURRENT_ADDR_COLOR));
-				}
-				else if (loc == null) { // only add in matches around current match if loc is null
-					// meaning that this is a one at a time search and not a table
-					// of results.
-					list.add(new Highlight(start, end,
-						PluginConstants.SEARCH_HIGHLIGHT_CURRENT_ADDR_COLOR));
+					// change the highlight color when in the field so it stands out
+					hlColor = SearchConstants.SEARCH_HIGHLIGHT_CURRENT_ADDR_COLOR;
 				}
+				list.add(new Highlight(start, end, hlColor));
 			}
 
-			if (list.size() == 0) {
+			if (list.isEmpty()) {
 				return NO_HIGHLIGHTS;
 			}
-			Highlight[] h = new Highlight[list.size()];
-			return list.toArray(h);
+			return list.toArray(Highlight[]::new);
 		}
 
-		/**
-		 * Return whether the field for the given factory class should be highlighted; compare
-		 * against the search options
-		 *
-		 * @param factoryClass field factory class
-		 * @param obj object associated with the field, e.g. CodeUnit
-		 */
-		private boolean shouldHighlight(Class<?> factoryClass, Object obj) {
+		private Highlight[] getSingleSearchHighlight(String text, ListingField field,
+				int cursorTextOffset) {
+
+			String searchText = searchOptions.getText();
+			if (StringUtils.isBlank(searchText) || StringUtils.isBlank(text)) {
+				return NO_HIGHLIGHTS;
+			}
+
+			FieldFactory fieldFactory = field.getFieldFactory();
+			ProgramLocation loc = searchResult.programLocation();
+			if (!fieldFactory.supportsLocation(field, loc)) {
+				return NO_HIGHLIGHTS;
+			}
+
+			int charOffset = searchResult.offset();
+			int searchStart = charOffset;
+			int searchEnd = searchStart + searchText.length();
+
+			Pattern regexp =
+				UserSearchUtils.createSearchPattern(searchText, searchOptions.isCaseSensitive());
+			Matcher matcher = regexp.matcher(text);
+			while (matcher.find()) {
+				int start = matcher.start();
+				int end = matcher.end();
+
+				// ensure the particular regex match is the actual search result
+				if (start == searchStart && end == searchEnd) {
+
+					Color hlColor = SearchConstants.SEARCH_HIGHLIGHT_COLOR;
+					if (start <= cursorTextOffset && end >= cursorTextOffset) {
+						// change the highlight color when in the field so it stands out
+						hlColor = SearchConstants.SEARCH_HIGHLIGHT_CURRENT_ADDR_COLOR;
+					}
+
+					// this is the matching search hit for a single search
+					int endEx = end - 1;
+					return new Highlight[] { new Highlight(start, endEx, hlColor) };
+				}
+			}
+			return NO_HIGHLIGHTS;
+		}
+
+		private boolean shouldHighlight(ListingField field) {
+
+			ProxyObj<?> proxy = field.getProxy();
+			Object obj = proxy.getObject();
 			Program navigatableProgram = navigatable == null ? null : navigatable.getProgram();
 			if (navigatableProgram != highlightProgram) {
 				return false;
@@ -686,6 +741,8 @@ public class SearchTextPlugin extends ProgramPlugin implements OptionsChangeList
 			if (searchOptions.searchAllFields()) {
 				return true;
 			}
+
+			Class<? extends FieldFactory> factoryClass = field.getFieldFactory().getClass();
 			if (searchOptions.searchComments()) {
 				if (factoryClass == PreCommentFieldFactory.class ||
 					factoryClass == PlateFieldFactory.class ||
