@@ -95,7 +95,7 @@ public class AddEditDialoglTest extends AbstractGhidraHeadedIntegrationTest {
 
 	@After
 	public void tearDown() throws Exception {
-		dialog.close();
+		close(dialog);
 		env.dispose();
 	}
 
@@ -362,6 +362,34 @@ public class AddEditDialoglTest extends AbstractGhidraHeadedIntegrationTest {
 		assertTrue(function.getSymbol().isPrimary());
 	}
 
+	@Test
+	public void testRenameFunction_Trim() throws Exception {
+
+		Symbol s = getUniqueSymbol(program, "entry", null);
+		Function function = program.getFunctionManager().getFunctionAt(s.getAddress());
+		if (function == null) {
+			tool.execute(new CreateFunctionCmd(s.getAddress()), program);
+			program.flushEvents();
+			waitForSwing();
+			function = program.getFunctionManager().getFunctionAt(s.getAddress());
+			s = getUniqueSymbol(program, "entry", null);
+		}
+		// add another label at this address
+		AddLabelCmd cmd = new AddLabelCmd(addr(0x01006420), "fred", SourceType.USER_DEFINED);
+		tool.execute(cmd, program);
+
+		// now attempt to rename the entry label
+		editLabel(s);
+		assertEquals("entry", getText());
+		String newText = "  bob  ";
+		setText(newText);
+		pressOk();
+		program.flushEvents();
+		waitForSwing();
+		assertEquals("bob", function.getName());
+		assertTrue(function.getSymbol().isPrimary());
+	}
+
 	@Test
 	public void testSetPrimaryOnOtherLabel() throws Exception {
 		Symbol s = getUniqueSymbol(program, "entry", null);
