@@ -22,8 +22,7 @@ import java.awt.Rectangle;
 import java.util.*;
 
 import javax.swing.*;
-import javax.swing.table.JTableHeader;
-import javax.swing.table.TableCellEditor;
+import javax.swing.table.*;
 
 import org.junit.*;
 
@@ -55,7 +54,7 @@ public class MemoryMapProvider1Test extends AbstractGhidraHeadedIntegrationTest
 	private Program program;
 	private Memory memory;
 	private JTable table;
-	private MemoryMapModel model;
+	private TableModel model;
 
 	private Program buildProgram(String programName) throws Exception {
 		ProgramBuilder builder = new ProgramBuilder(programName, ProgramBuilder._TOY);
@@ -114,11 +113,13 @@ public class MemoryMapProvider1Test extends AbstractGhidraHeadedIntegrationTest
 		table.addRowSelectionInterval(0, 0);
 		Set<DockingActionIf> actions = getActionsByOwner(tool, plugin.getName());
 		for (DockingActionIf action : actions) {
-			if (action.getName().equals("Merge Blocks") || action.getName().equals("Local Menu")) {
+			if (action.getName().equals("Merge Blocks") || action.getName().equals("Local Menu") ||
+				action.getName().equals("Rename Overlay Space")) {
 				assertFalse(action.isEnabled());
 			}
 			else {
-				assertTrue(action.isEnabled());
+				assertTrue("Action not enabled when it should be: " + action.getName(),
+					action.isEnabled());
 			}
 		}
 	}
@@ -133,7 +134,8 @@ public class MemoryMapProvider1Test extends AbstractGhidraHeadedIntegrationTest
 			String name = action.getName();
 			if (name.equals("Add Block") || name.equals("Merge Blocks") ||
 				name.equals("Delete Block") || name.equals("Set Image Base") ||
-				name.equals("Memory Map") || name.equals("Close Window")) {
+				name.equals("Memory Map") || name.equals("Close Window") ||
+				name.equals("Make Selection")) {
 				assertTrue("Action should be enabled for  a multi-row selection - '" + name + "'",
 					action.isEnabled());
 			}
@@ -201,19 +203,19 @@ public class MemoryMapProvider1Test extends AbstractGhidraHeadedIntegrationTest
 		memory.createUninitializedBlock(".test", getAddr(0), 0x100, false);
 		program.endTransaction(transactionID, true);
 		program.flushEvents();
-		waitForPostedSwingRunnables();
+		waitForSwing();
 
 		assertEquals(Boolean.FALSE, model.getValueAt(0, MemoryMapModel.INIT));
-		waitForPostedSwingRunnables();
+		waitForSwing();
 
 		Rectangle rect = table.getCellRect(0, MemoryMapModel.INIT, true);
 		clickMouse(table, 1, rect.x, rect.y, 2, 0);
-		waitForPostedSwingRunnables();
+		waitForSwing();
 
 		NumberInputDialog dialog = waitForDialogComponent(NumberInputDialog.class);
 		assertNotNull(dialog);
 		invokeInstanceMethod("okCallback", dialog);
-		waitForPostedSwingRunnables();
+		waitForSwing();
 
 		assertEquals(Boolean.TRUE, model.getValueAt(0, MemoryMapModel.INIT));
 
@@ -229,12 +231,12 @@ public class MemoryMapProvider1Test extends AbstractGhidraHeadedIntegrationTest
 
 		Rectangle rect = table.getCellRect(0, MemoryMapModel.INIT, true);
 		clickMouse(table, 1, rect.x, rect.y, 2, 0);
-		waitForPostedSwingRunnables();
+		waitForSwing();
 
 		OptionDialog dialog = waitForDialogComponent(OptionDialog.class);
 		assertNotNull(dialog);
 		invokeInstanceMethod("okCallback", dialog);
-		waitForPostedSwingRunnables();
+		waitForSwing();
 
 		waitForBusyTool(tool);
 
@@ -248,7 +250,7 @@ public class MemoryMapProvider1Test extends AbstractGhidraHeadedIntegrationTest
 		table.addRowSelectionInterval(0, 0);
 		Rectangle rect = table.getCellRect(0, MemoryMapModel.NAME, true);
 		clickMouse(table, 1, rect.x, rect.y, 2, 0);
-		waitForPostedSwingRunnables();
+		waitForSwing();
 
 		SwingUtilities.invokeAndWait(() -> {
 			int row = 0;
@@ -260,7 +262,7 @@ public class MemoryMapProvider1Test extends AbstractGhidraHeadedIntegrationTest
 			tf.setText(".test");
 			editor.stopCellEditing();
 		});
-		waitForPostedSwingRunnables();
+		waitForSwing();
 		assertEquals(".test", model.getValueAt(0, MemoryMapModel.NAME));
 	}
 
@@ -271,7 +273,7 @@ public class MemoryMapProvider1Test extends AbstractGhidraHeadedIntegrationTest
 //		table.addRowSelectionInterval(0, 0);
 //		Rectangle rect = table.getCellRect(0, MemoryMapModel.NAME, true);
 //		clickMouse(table, 1, rect.x, rect.y, 2, 0);
-//		waitForPostedSwingRunnables();
+//		waitForSwing();
 //
 //		SwingUtilities.invokeLater(() -> {
 //			int row = 0;
@@ -283,7 +285,7 @@ public class MemoryMapProvider1Test extends AbstractGhidraHeadedIntegrationTest
 //			tf.setText(".data");
 //			editor.stopCellEditing();
 //		});
-//		waitForPostedSwingRunnables();
+//		waitForSwing();
 //		assertEquals(".text", model.getValueAt(0, MemoryMapModel.NAME));
 //
 //		final OptionDialog d =
@@ -302,7 +304,7 @@ public class MemoryMapProvider1Test extends AbstractGhidraHeadedIntegrationTest
 		table.addRowSelectionInterval(0, 0);
 		Rectangle rect = table.getCellRect(0, MemoryMapModel.COMMENT, true);
 		clickMouse(table, 1, rect.x, rect.y, 2, 0);
-		waitForPostedSwingRunnables();
+		waitForSwing();
 
 		SwingUtilities.invokeAndWait(() -> {
 			int row = 0;
@@ -314,7 +316,7 @@ public class MemoryMapProvider1Test extends AbstractGhidraHeadedIntegrationTest
 			tf.setText("these are test comments");
 			editor.stopCellEditing();
 		});
-		waitForPostedSwingRunnables();
+		waitForSwing();
 		assertEquals("these are test comments", model.getValueAt(0, MemoryMapModel.COMMENT));
 	}
 
@@ -670,11 +672,10 @@ public class MemoryMapProvider1Test extends AbstractGhidraHeadedIntegrationTest
 	private void showProvider() {
 		DockingActionIf action = getAction(plugin, "Memory Map");
 		performAction(action, true);
-		waitForPostedSwingRunnables();
+		waitForSwing();
 		provider = plugin.getMemoryMapProvider();
 		table = provider.getTable();
-		model = (MemoryMapModel) table.getModel();
-
+		model = table.getModel();
 	}
 
 	private Address getAddr(long offset) {
