@@ -67,7 +67,7 @@ public class OptionsTest extends AbstractGuiTest {
 
 	@Test
 	public void testDefaultsNotSaved() {
-		options.registerOption("Foo", 5, null, null);
+		options.registerOption("Foo", 5, null, "foo");
 		assertTrue(options.contains("Foo"));
 		assertEquals(5, options.getInt("Foo", 0));
 		saveAndRestoreOptions();
@@ -198,7 +198,7 @@ public class OptionsTest extends AbstractGuiTest {
 		options.setInt("Foo", 3);
 		options.setColor("COLOR", Palette.RED);
 		options.getLong("LONG", 10);
-		options.registerOption("Bar", true, null, null);
+		options.registerOption("Bar", true, null, "foo");
 		Options optionsCopy = options.copy();
 		assertTrue(optionsCopy.contains("Foo"));
 		assertTrue(optionsCopy.contains("COLOR"));
@@ -287,7 +287,7 @@ public class OptionsTest extends AbstractGuiTest {
 
 	@Test
 	public void testGetDefaultValue() {
-		options.registerOption("Foo", Color.RED, null, null);
+		options.registerOption("Foo", Color.RED, null, "foo");
 		options.setColor("Foo", Color.BLUE);
 		assertColorsEqual(Color.BLUE, options.getColor("Foo", null));
 		assertColorsEqual(Color.RED, (Color) options.getDefaultValue("Foo"));
@@ -296,21 +296,21 @@ public class OptionsTest extends AbstractGuiTest {
 	@Test
 	public void testRegisterPropertyEditor() {
 		MyPropertyEditor editor = new MyPropertyEditor();
-		options.registerOption("color", OptionType.COLOR_TYPE, Color.RED, null, null, editor);
+		options.registerOption("color", OptionType.COLOR_TYPE, Color.RED, null, "foo", editor);
 		assertEquals(editor, options.getRegisteredPropertyEditor("color"));
 	}
 
 	@Test
 	public void testGetHelpLocation() {
 		HelpLocation helpLocation = new HelpLocation("topic", "anchor");
-		options.registerOption("Foo", 3, helpLocation, null);
+		options.registerOption("Foo", 3, helpLocation, "foo");
 		assertEquals(helpLocation, options.getHelpLocation("Foo"));
 	}
 
 	@Test
 	public void testRestoreOptionValue() {
 
-		options.registerOption("Foo", Color.RED, null, null);
+		options.registerOption("Foo", Color.RED, null, "foo");
 		options.setColor("Foo", Color.BLUE);
 		assertColorsEqual(Color.BLUE, options.getColor("Foo", null));
 
@@ -378,16 +378,16 @@ public class OptionsTest extends AbstractGuiTest {
 		assertTrue(!options.isRegistered("Bar"));
 
 		assertTrue(!options.isRegistered("aaa"));
-		options.registerOption("aaa", 3, null, null);
+		options.registerOption("aaa", 3, null, "foo");
 		assertTrue(options.isRegistered("aaa"));
 
 	}
 
 	@Test
 	public void testRestoreDefaults() {
-		options.registerOption("Foo", 10, null, null);
+		options.registerOption("Foo", 10, null, "foo");
 		options.setInt("Foo", 2);
-		options.registerOption("Bar", 100, null, null);
+		options.registerOption("Bar", 100, null, "foo");
 		options.setInt("Bar", 1);
 		options.restoreDefaultValues();
 		assertEquals(10, options.getInt("Foo", 0));
@@ -423,7 +423,7 @@ public class OptionsTest extends AbstractGuiTest {
 		assertTrue(options.contains("Foo"));
 		assertTrue(options.contains("Bar"));
 
-		options.registerOption("Bar", 0, null, null);
+		options.registerOption("Bar", 0, null, "foo");
 
 		options.removeUnusedOptions();
 
@@ -527,7 +527,7 @@ public class OptionsTest extends AbstractGuiTest {
 
 	@Test
 	public void testGetDefaultValueAsString() {
-		options.registerOption("foo", 7, null, null);
+		options.registerOption("foo", 7, null, "foo");
 		options.setInt("foo", 5);
 		assertEquals("7", options.getDefaultValueAsString("foo"));
 		assertNull(options.getDefaultValueAsString("bar"));
@@ -536,7 +536,7 @@ public class OptionsTest extends AbstractGuiTest {
 	@Test
 	public void testResgisteringOptionWithNullValue() {
 		try {
-			options.registerOption("Foo", null, null, null);
+			options.registerOption("Foo", null, null, "foo");
 			Assert.fail("Should not be able to register an options with a default value");
 		}
 		catch (IllegalArgumentException e) {
@@ -547,7 +547,7 @@ public class OptionsTest extends AbstractGuiTest {
 	@Test
 	public void testRegisteringOptionWithUnsupportedType() {
 		try {
-			options.registerOption("Foo", new ArrayList<String>(), null, null);
+			options.registerOption("Foo", new ArrayList<String>(), null, "foo");
 			Assert.fail(
 				"Should not be able to register an options with an ArrayList as a default value");
 		}
@@ -559,7 +559,7 @@ public class OptionsTest extends AbstractGuiTest {
 	@Test
 	public void testRegisteringOptionWithTypeNone() {
 		try {
-			options.registerOption("Foo", OptionType.NO_TYPE, null, null, null);
+			options.registerOption("Foo", OptionType.NO_TYPE, null, null, "foo");
 			Assert.fail("Should not be able to register an options of type NONE");
 		}
 		catch (IllegalArgumentException e) {
@@ -643,13 +643,13 @@ public class OptionsTest extends AbstractGuiTest {
 		}
 
 		@Override
-		public void readState(SaveState saveState) {
-			value = saveState.getInt("VALUE", 0);
+		public void readState(GProperties properties) {
+			value = properties.getInt("VALUE", 0);
 		}
 
 		@Override
-		public void writeState(SaveState saveState) {
-			saveState.putInt("VALUE", value);
+		public void writeState(GProperties properties) {
+			properties.putInt("VALUE", value);
 		}
 
 		@Override
