@@ -19,11 +19,12 @@
 
 #include <cmath>
 #include <limits>
+
+namespace ghidra {
+
 using std::ldexp;
 using std::frexp;
 using std::signbit;
-using std::isnan;
-using std::isinf;
 using std::sqrt;
 using std::floor;
 using std::ceil;
@@ -92,8 +93,8 @@ FloatFormat::floatclass FloatFormat::extractExpSig(double x,bool *sgn,uintb *sig
 
   *sgn = signbit(x);
   if (x == 0.0) return zero;
-  if (isinf(x)) return infinity;
-  if (isnan(x)) return nan;
+  if (std::isinf(x)) return infinity;
+  if (std::isnan(x)) return nan;
   if (*sgn)
     x = -x;
   double norm = frexp(x,&e);  // norm is between 1/2 and 1
@@ -568,8 +569,7 @@ uintb FloatFormat::opSqrt(uintb a) const
 uintb FloatFormat::opInt2Float(uintb a,int4 sizein) const
 
 {
-  intb ival = (intb)a;
-  sign_extend(ival,8*sizein-1);
+  intb ival = sign_extend(a,8*sizein-1);
   double val = (double) ival;	// Convert integer to float
   return getEncoding(val);
 }
@@ -689,3 +689,5 @@ void FloatFormat::restoreXml(const Element *el)
   maxexponent = (1<<exp_size)-1;
   calcPrecision();
 }
+
+} // End namespace ghidra
