@@ -29,16 +29,16 @@ import generic.theme.Gui;
 import ghidra.GhidraOptions;
 import ghidra.GhidraOptions.CURSOR_MOUSE_BUTTON_NAMES;
 import ghidra.app.util.HelpTopics;
-import ghidra.framework.options.Options;
+import ghidra.app.util.template.TemplateSimplifier;
 import ghidra.framework.options.ToolOptions;
-import ghidra.framework.plugintool.Plugin;
-import ghidra.framework.plugintool.PluginTool;
 import ghidra.program.database.ProgramCompilerSpec;
 import ghidra.program.model.lang.*;
 import ghidra.program.model.lang.CompilerSpec.EvaluationModelType;
 import ghidra.program.model.listing.Program;
 import ghidra.program.model.pcode.ElementId;
 import ghidra.program.model.pcode.Encoder;
+import ghidra.program.model.symbol.IdentityNameTransformer;
+import ghidra.program.model.symbol.NameTransformer;
 import ghidra.util.HelpLocation;
 
 /**
@@ -98,6 +98,63 @@ public class DecompileOptions {
 	private final static boolean ANALYZEFORLOOPS_OPTIONDEFAULT = true;	// Must match Architecture::resetDefaultsInternal
 	private boolean analyzeForLoops;
 
+	private final static String SPLITSTRUCTURES_OPTIONSTRING =
+		"Analysis.Split combined structure fields";
+	private final static String SPLITSTRUCTURES_OPTIONDESCRIPTION =
+		"If set, the decompiler will split a copy operation to or from a structure that affects more than " +
+			"one field. The copy will be split into multiple operations so that each logical field is copied " +
+			"separately.";
+	private final static boolean SPLITSTRUCTURES_OPTIONDEFAULT = true;	// Must match Architecture::resetDefaultsInternal
+	private boolean splitStructures;
+
+	private final static String SPLITARRAYS_OPTIONSTRING = "Analysis.Split combined array elements";
+	private final static String SPLITARRAYS_OPTIONDESCRIPTION =
+		"If set, the decompiler will split a copy operation to or from an array that affects more than " +
+			"one element. The copy will be split into multiple operations so that each logical element is copied " +
+			"separately.";
+	private final static boolean SPLITARRAYS_OPTIONDEFAULT = true;	// Must match Architecture::resetDefaultsInternal
+	private boolean splitArrays;
+
+	private final static String SPLITPOINTERS_OPTIONSTRING =
+		"Analysis.Split pointers to combined elements";
+	private final static String SPLITPOINTERS_OPTIONDESCRIPTION =
+		"If set, a single copy, through a pointer, to either multiple array elements or multiple structure fields " +
+			"will be split.  The copy, via LOAD or STORE, will be split into multiple operations so that each " +
+			"logical element is accessed separately.";
+	private final static boolean SPLITPOINTERS_OPTIONDEFAULT = true;	// Must match Architecture::resetDefaultsInternal
+	private boolean splitPointers;
+
+	private final static String NANIGNORE_OPTIONSTRING = "Analysis.NaN operations";
+	private final static String NANIGNORE_OPTIONDESCRIPTION =
+		"Specify how much to ignore floating-point NaN operations in decompiler output";
+
+	public enum NanIgnoreEnum {
+
+		None("none", "Ignore none"),
+		Compare("compare", "Ignore with comparisons"),
+		All("all", "Ignore all");
+
+		private String label;
+		private String optionString;
+
+		private NanIgnoreEnum(String optString, String label) {
+			this.label = label;
+			this.optionString = optString;
+		}
+
+		public String getOptionString() {
+			return optionString;
+		}
+
+		@Override
+		public String toString() {
+			return label;
+		}
+	}
+
+	private final static NanIgnoreEnum NANIGNORE_OPTIONDEFAULT = NanIgnoreEnum.Compare;	// Must match Architecture::resetDefaultsInternal
+	private NanIgnoreEnum nanIgnore;
+
 	private final static String NULLTOKEN_OPTIONSTRING = "Display.Print 'NULL' for null pointers";
 	private final static String NULLTOKEN_OPTIONDESCRIPTION =
 		"If set, any zero valued pointer (null pointer) will " +
@@ -185,6 +242,7 @@ public class DecompileOptions {
 	public static final int SUGGESTED_DECOMPILE_TIMEOUT_SECS = 30;
 	public static final int SUGGESTED_MAX_PAYLOAD_BYTES = 50;
 	public static final int SUGGESTED_MAX_INSTRUCTIONS = 100000;		// Must match Architecture::resetDefaultsInternal
+	public static final int SUGGESTED_MAX_JUMPTABLE_ENTRIES = 1024;		// Must match Architecture::resetDefaultsInternal
 
 	public enum CommentStyleEnum {
 
@@ -340,9 +398,7 @@ public class DecompileOptions {
 	private final static GColor HIGHLIGHT_DEFAULT_COLOR =  new GColor("color.fg.decompiler");
 
 	private static final String SEARCH_HIGHLIGHT_MSG = "Display.Color for Highlighting Find Matches";
-	private static final GColor SEARCH_HIGHLIGHT_COLOR = new GColor("color.bg.decompiler.highlights.search");
-
-
+	private static final GColor SEARCH_HIGHLIGHT_COLOR = new GColor("color.bg.decompiler.highlights.find");
 	//@formatter:on
 
 	private static final String BACKGROUND_COLOR_MSG = "Display.Background Color";
@@ -364,15 +420,19 @@ public class DecompileOptions {
 	private final static String DECOMPILE_TIMEOUT = "Decompiler Timeout (seconds)";
 	private final static String PAYLOAD_LIMIT = "Decompiler Max-Payload (MBytes)";
 	private final static String MAX_INSTRUCTIONS = "Max Instructions per Function";
+	private final static String MAX_JUMPTABLE_ENTRIES = "Max Entries per Jumptable";
 	private final static Boolean LINE_NUMBER_DEF = Boolean.TRUE;
 	private boolean displayLineNumbers;
 	private int decompileTimeoutSeconds;
 	private int payloadLimitMBytes;
 	private int maxIntructionsPer;
+	private int maxJumpTableEntries;
 	private int cachedResultsSize;
 
 	private DecompilerLanguage displayLanguage; // Output language displayed by the decompiler
 
+	private NameTransformer nameTransformer;	// Transformer applied to data-type/function names
+
 	private String protoEvalModel; // Name of the prototype evaluation model
 
 	public DecompileOptions() {
@@ -380,6 +440,10 @@ public class DecompileOptions {
 		readOnly = READONLY_OPTIONDEFAULT; // This flipped values
 		eliminateUnreachable = ELIMINATE_UNREACHABLE_OPTIONDEFAULT;
 		simplifyDoublePrecision = SIMPLIFY_DOUBLEPRECISION_OPTIONDEFAULT;
+		splitStructures = SPLITSTRUCTURES_OPTIONDEFAULT;
+		splitArrays = SPLITARRAYS_OPTIONDEFAULT;
+		splitPointers = SPLITPOINTERS_OPTIONDEFAULT;
+		nanIgnore = NANIGNORE_OPTIONDEFAULT;
 		ignoreunimpl = IGNOREUNIMPL_OPTIONDEFAULT;
 		inferconstptr = INFERCONSTPTR_OPTIONDEFAULT;
 		analyzeForLoops = ANALYZEFORLOOPS_OPTIONDEFAULT;
@@ -406,17 +470,19 @@ public class DecompileOptions {
 		decompileTimeoutSeconds = SUGGESTED_DECOMPILE_TIMEOUT_SECS;
 		payloadLimitMBytes = SUGGESTED_MAX_PAYLOAD_BYTES;
 		maxIntructionsPer = SUGGESTED_MAX_INSTRUCTIONS;
+		maxJumpTableEntries = SUGGESTED_MAX_JUMPTABLE_ENTRIES;
 		cachedResultsSize = SUGGESTED_CACHED_RESULTS_SIZE;
+		nameTransformer = null;
 	}
 
 	/**
 	 * Grab all the decompiler options from various sources within a specific tool and program
 	 * and cache them in this object.
-	 * @param ownerPlugin  the plugin that owns the "tool options" for the decompiler
+	 * @param fieldOptions the Options object containing options specific to listing fields
 	 * @param opt          the Options object that contains the "tool options" specific to the decompiler
 	 * @param program      the program whose "program options" are relevant to the decompiler
 	 */
-	public void grabFromToolAndProgram(Plugin ownerPlugin, ToolOptions opt, Program program) {
+	public void grabFromToolAndProgram(ToolOptions fieldOptions, ToolOptions opt, Program program) {
 
 		grabFromProgram(program);
 
@@ -435,6 +501,12 @@ public class DecompileOptions {
 		inferconstptr = opt.getBoolean(INFERCONSTPTR_OPTIONSTRING, INFERCONSTPTR_OPTIONDEFAULT);
 		analyzeForLoops =
 			opt.getBoolean(ANALYZEFORLOOPS_OPTIONSTRING, ANALYZEFORLOOPS_OPTIONDEFAULT);
+		splitStructures =
+			opt.getBoolean(SPLITSTRUCTURES_OPTIONSTRING, SPLITSTRUCTURES_OPTIONDEFAULT);
+		splitArrays = opt.getBoolean(SPLITARRAYS_OPTIONSTRING, SPLITARRAYS_OPTIONDEFAULT);
+		splitPointers = opt.getBoolean(SPLITPOINTERS_OPTIONSTRING, SPLITPOINTERS_OPTIONDEFAULT);
+		nanIgnore = opt.getEnum(NANIGNORE_OPTIONSTRING, NANIGNORE_OPTIONDEFAULT);
+
 		nullToken = opt.getBoolean(NULLTOKEN_OPTIONSTRING, NULLTOKEN_OPTIONDEFAULT);
 		inplaceTokens = opt.getBoolean(INPLACEOP_OPTIONSTRING, INPLACEOP_OPTIONDEFAULT);
 		aliasBlock = opt.getEnum(ALIASBLOCK_OPTIONSTRING, ALIASBLOCK_OPTIONDEFAULT);
@@ -457,22 +529,21 @@ public class DecompileOptions {
 		decompileTimeoutSeconds = opt.getInt(DECOMPILE_TIMEOUT, SUGGESTED_DECOMPILE_TIMEOUT_SECS);
 		payloadLimitMBytes = opt.getInt(PAYLOAD_LIMIT, SUGGESTED_MAX_PAYLOAD_BYTES);
 		maxIntructionsPer = opt.getInt(MAX_INSTRUCTIONS, SUGGESTED_MAX_INSTRUCTIONS);
+		maxJumpTableEntries = opt.getInt(MAX_JUMPTABLE_ENTRIES, SUGGESTED_MAX_JUMPTABLE_ENTRIES);
 		cachedResultsSize = opt.getInt(CACHED_RESULTS_SIZE_MSG, SUGGESTED_CACHED_RESULTS_SIZE);
 
-		grabFromToolOptions(ownerPlugin);
+		grabFromFieldOptions(fieldOptions);
 	}
 
-	private void grabFromToolOptions(Plugin ownerPlugin) {
-		if (ownerPlugin == null) {
+	private void grabFromFieldOptions(ToolOptions fieldOptions) {
+		if (fieldOptions == null) {
 			return;
 		}
 
-		PluginTool tool = ownerPlugin.getTool();
-		Options toolOptions = tool.getOptions(CATEGORY_BROWSER_FIELDS);
-
 		CURSOR_MOUSE_BUTTON_NAMES mouseEvent =
-			toolOptions.getEnum(CURSOR_HIGHLIGHT_BUTTON_NAME, CURSOR_MOUSE_BUTTON_NAMES.MIDDLE);
+			fieldOptions.getEnum(CURSOR_HIGHLIGHT_BUTTON_NAME, CURSOR_MOUSE_BUTTON_NAMES.MIDDLE);
 		middleMouseHighlightButton = mouseEvent.getMouseEventID();
+		nameTransformer = new TemplateSimplifier(fieldOptions);
 	}
 
 	/**
@@ -499,10 +570,18 @@ public class DecompileOptions {
 		displayLanguage = cspec.getDecompilerOutputLanguage();
 	}
 
+	/**
+	 * @return the default prototype to assume if no other information about a function is known
+	 */
 	public String getProtoEvalModel() {
 		return protoEvalModel;
 	}
 
+	/**
+	 * Set the default prototype model for the decompiler.  This is the model assumed if no other
+	 * information about a function is known.
+	 * @param protoEvalModel is the name of the prototype model to set as default
+	 */
 	public void setProtoEvalModel(String protoEvalModel) {
 		this.protoEvalModel = protoEvalModel;
 	}
@@ -510,11 +589,11 @@ public class DecompileOptions {
 	/**
 	 * This registers all the decompiler tool options with ghidra, and has the side effect of
 	 * pulling all the current values for the options if they exist
-	 * @param ownerPlugin  the plugin to which the options should be registered
-	 * @param opt          the options object to register with
+	 * @param fieldOptions the options object specific to listing fields
+	 * @param opt          the options object specific to the decompiler
 	 * @param program      the program
 	 */
-	public void registerOptions(Plugin ownerPlugin, ToolOptions opt, Program program) {
+	public void registerOptions(ToolOptions fieldOptions, ToolOptions opt, Program program) {
 		opt.registerOption(PREDICATE_OPTIONSTRING, PREDICATE_OPTIONDEFAULT,
 			new HelpLocation(HelpTopics.DECOMPILER, "AnalysisPredicate"),
 			PREDICATE_OPTIONDESCRIPTION);
@@ -537,6 +616,18 @@ public class DecompileOptions {
 		opt.registerOption(ANALYZEFORLOOPS_OPTIONSTRING, ANALYZEFORLOOPS_OPTIONDEFAULT,
 			new HelpLocation(HelpTopics.DECOMPILER, "AnalysisForLoops"),
 			ANALYZEFORLOOPS_OPTIONDESCRIPTION);
+		opt.registerOption(SPLITSTRUCTURES_OPTIONSTRING, SPLITSTRUCTURES_OPTIONDEFAULT,
+			new HelpLocation(HelpTopics.DECOMPILER, "AnalysisSplitStruct"),
+			SPLITSTRUCTURES_OPTIONDESCRIPTION);
+		opt.registerOption(SPLITARRAYS_OPTIONSTRING, SPLITARRAYS_OPTIONDEFAULT,
+			new HelpLocation(HelpTopics.DECOMPILER, "AnalysisSplitArray"),
+			SPLITARRAYS_OPTIONDESCRIPTION);
+		opt.registerOption(SPLITPOINTERS_OPTIONSTRING, SPLITPOINTERS_OPTIONDEFAULT,
+			new HelpLocation(HelpTopics.DECOMPILER, "AnalysisSplitPointers"),
+			SPLITPOINTERS_OPTIONDESCRIPTION);
+		opt.registerOption(NANIGNORE_OPTIONSTRING, NANIGNORE_OPTIONDEFAULT,
+			new HelpLocation(HelpTopics.DECOMPILER, "AnalysisNanIgnore"),
+			NANIGNORE_OPTIONDESCRIPTION);
 		opt.registerOption(NULLTOKEN_OPTIONSTRING, NULLTOKEN_OPTIONDEFAULT,
 			new HelpLocation(HelpTopics.DECOMPILER, "DisplayNull"), NULLTOKEN_OPTIONDESCRIPTION);
 		opt.registerOption(INPLACEOP_OPTIONSTRING, INPLACEOP_OPTIONDEFAULT,
@@ -639,13 +730,16 @@ public class DecompileOptions {
 		opt.registerOption(MAX_INSTRUCTIONS, SUGGESTED_MAX_INSTRUCTIONS,
 			new HelpLocation(HelpTopics.DECOMPILER, "GeneralMaxInstruction"),
 			"The maximum number of instructions decompiled in a single function");
+		opt.registerOption(MAX_JUMPTABLE_ENTRIES, SUGGESTED_MAX_JUMPTABLE_ENTRIES,
+			new HelpLocation(HelpTopics.DECOMPILER, "GeneralMaxJumptable"),
+			"The maximum number of entries that can be recovered from a single jumptable");
 		opt.registerThemeColorBinding(HIGHLIGHT_CURRENT_VARIABLE_MSG,
 			HIGHLIGHT_CURRENT_VARIABLE_COLOR.getId(),
 			new HelpLocation(HelpTopics.DECOMPILER, "DisplayCurrentHighlight"),
 			"Current variable highlight");
 		opt.registerOption(CACHED_RESULTS_SIZE_MSG, SUGGESTED_CACHED_RESULTS_SIZE,
 			new HelpLocation(HelpTopics.DECOMPILER, "GeneralCacheSize"), CACHE_RESULTS_DESCRIPTION);
-		grabFromToolAndProgram(ownerPlugin, opt, program);
+		grabFromToolAndProgram(fieldOptions, opt, program);
 	}
 
 	private static void appendOption(Encoder encoder, ElementId option, String p1, String p2,
@@ -680,13 +774,31 @@ public class DecompileOptions {
 	 */
 	public void encode(Encoder encoder, DecompInterface iface) throws IOException {
 		encoder.openElement(ELEM_OPTIONSLIST);
-		appendOption(encoder, ELEM_CURRENTACTION, "conditionalexe", predicate ? "on" : "off", "");
-		appendOption(encoder, ELEM_READONLY, readOnly ? "on" : "off", "", "");
-		appendOption(encoder, ELEM_CURRENTACTION, iface.getSimplificationStyle(), "unreachable",
-			eliminateUnreachable ? "on" : "off");
-		appendOption(encoder, ELEM_CURRENTACTION, iface.getSimplificationStyle(), "doubleprecis",
-			simplifyDoublePrecision ? "on" : "off");
+		if (predicate != PREDICATE_OPTIONDEFAULT) {
+			appendOption(encoder, ELEM_CURRENTACTION, "conditionalexe", predicate ? "on" : "off",
+				"");
+		}
+		if (eliminateUnreachable != ELIMINATE_UNREACHABLE_OPTIONDEFAULT) {
+			appendOption(encoder, ELEM_CURRENTACTION, iface.getSimplificationStyle(), "unreachable",
+				eliminateUnreachable ? "on" : "off");
+		}
+		if (simplifyDoublePrecision != SIMPLIFY_DOUBLEPRECISION_OPTIONDEFAULT) {
+			appendOption(encoder, ELEM_CURRENTACTION, iface.getSimplificationStyle(),
+				"doubleprecis", simplifyDoublePrecision ? "on" : "off");
+		}
+		if (splitStructures != SPLITSTRUCTURES_OPTIONDEFAULT ||
+			splitArrays != SPLITARRAYS_OPTIONDEFAULT ||
+			splitPointers != SPLITPOINTERS_OPTIONDEFAULT) {
+			String p1 = splitStructures ? "struct" : "";
+			String p2 = splitArrays ? "array" : "";
+			String p3 = splitPointers ? "pointer" : "";
+			appendOption(encoder, ELEM_SPLITDATATYPE, p1, p2, p3);
+		}
+		if (nanIgnore != NANIGNORE_OPTIONDEFAULT) {
+			appendOption(encoder, ELEM_NANIGNORE, nanIgnore.getOptionString(), "", "");
+		}
 
+		appendOption(encoder, ELEM_READONLY, readOnly ? "on" : "off", "", "");
 		// Must set language early so that the object is in place before other option changes
 		appendOption(encoder, ELEM_SETLANGUAGE, displayLanguage.toString(), "", "");
 
@@ -765,14 +877,24 @@ public class DecompileOptions {
 		if (maxIntructionsPer != SUGGESTED_MAX_INSTRUCTIONS) {
 			appendOption(encoder, ELEM_MAXINSTRUCTION, Integer.toString(maxIntructionsPer), "", "");
 		}
+		if (maxJumpTableEntries != SUGGESTED_MAX_JUMPTABLE_ENTRIES) {
+			appendOption(encoder, ELEM_JUMPTABLEMAX, Integer.toString(maxJumpTableEntries), "", "");
+		}
 		appendOption(encoder, ELEM_PROTOEVAL, protoEvalModel, "", "");
 		encoder.closeElement(ELEM_OPTIONSLIST);
 	}
 
+	/**
+	 * @return the maximum number of characters the decompiler displays in a single line of output
+	 */
 	public int getMaxWidth() {
 		return maxwidth;
 	}
 
+	/**
+	 * Set the maximum number of characters the decompiler displays in a single line of output
+	 * @param maxwidth is the maximum number of characters
+	 */
 	public void setMaxWidth(int maxwidth) {
 		this.maxwidth = maxwidth;
 	}
@@ -848,7 +970,7 @@ public class DecompileOptions {
 	}
 
 	/**
-	 * @return color used on tokens that need to warn of an error or other unusual conditions 
+	 * @return color used on tokens that need to warn of an error or other unusual conditions
 	 */
 	public Color getErrorColor() {
 		return ERROR_COLOR;
@@ -882,139 +1004,316 @@ public class DecompileOptions {
 		return SEARCH_HIGHLIGHT_COLOR;
 	}
 
+	/**
+	 * @return the mouse button that should be used to toggle the primary token highlight
+	 */
 	public int getMiddleMouseHighlightButton() {
 		return middleMouseHighlightButton;
 	}
 
+	/**
+	 * @return true if Pre comments are included as part of decompiler output
+	 */
 	public boolean isPRECommentIncluded() {
 		return commentPREInclude;
 	}
 
+	/**
+	 * Set whether Pre comments are displayed as part of decompiler output
+	 * @param commentPREInclude is true if Pre comments are output
+	 */
 	public void setPRECommentIncluded(boolean commentPREInclude) {
 		this.commentPREInclude = commentPREInclude;
 	}
 
+	/**
+	 * @return true if Plate comments are included as part of decompiler output
+	 */
 	public boolean isPLATECommentIncluded() {
 		return commentPLATEInclude;
 	}
 
+	/**
+	 * Set whether Plate comments are displayed as part of decompiler output
+	 * @param commentPLATEInclude is true if Plate comments are output
+	 */
 	public void setPLATECommentIncluded(boolean commentPLATEInclude) {
 		this.commentPLATEInclude = commentPLATEInclude;
 	}
 
+	/**
+	 * @return true if Post comments are included as part of decompiler output
+	 */
 	public boolean isPOSTCommentIncluded() {
 		return commentPOSTInclude;
 	}
 
+	/**
+	 * Set whether Post comments are displayed as part of decompiler output
+	 * @param commentPOSTInclude is true if Post comments are output
+	 */
 	public void setPOSTCommentIncluded(boolean commentPOSTInclude) {
 		this.commentPOSTInclude = commentPOSTInclude;
 	}
 
+	/**
+	 * @return true if End-of-line comments are included as part of decompiler output
+	 */
 	public boolean isEOLCommentIncluded() {
 		return commentEOLInclude;
 	}
 
+	/**
+	 * Set whether End-of-line comments are displayed as part of decompiler output.
+	 * @param commentEOLInclude is true if End-of-line comments are output
+	 */
 	public void setEOLCommentIncluded(boolean commentEOLInclude) {
 		this.commentEOLInclude = commentEOLInclude;
 	}
 
+	/**
+	 * @return true if WARNING comments are included as part of decompiler output
+	 */
 	public boolean isWARNCommentIncluded() {
 		return commentWARNInclude;
 	}
 
+	/**
+	 * Set whether automatically generated WARNING comments are displayed as part of
+	 * decompiler output.
+	 * @param commentWARNInclude is true if WARNING comments are output
+	 */
 	public void setWARNCommentIncluded(boolean commentWARNInclude) {
 		this.commentWARNInclude = commentWARNInclude;
 	}
 
+	/**
+	 * @return true if function header comments are included as part of decompiler output
+	 */
 	public boolean isHeadCommentIncluded() {
 		return commentHeadInclude;
 	}
 
+	/**
+	 * Set whether function header comments are included as part of decompiler output.
+	 * @param commentHeadInclude is true if header comments are output
+	 */
 	public void setHeadCommentIncluded(boolean commentHeadInclude) {
 		this.commentHeadInclude = commentHeadInclude;
 	}
 
+	/**
+	 * @return true if the decompiler currently eliminates unreachable code
+	 */
 	public boolean isEliminateUnreachable() {
 		return eliminateUnreachable;
 	}
 
+	/**
+	 * Set whether the decompiler should eliminate unreachable code as part of its analysis.
+	 * @param eliminateUnreachable is true if unreachable code is eliminated
+	 */
 	public void setEliminateUnreachable(boolean eliminateUnreachable) {
 		this.eliminateUnreachable = eliminateUnreachable;
 	}
 
+	/**
+	 * If the decompiler currently applies transformation rules that identify and
+	 * simplify double precision arithmetic operations, true is returned.
+	 * @return true if the decompiler applies double precision rules
+	 */
 	public boolean isSimplifyDoublePrecision() {
 		return simplifyDoublePrecision;
 	}
 
+	/**
+	 * Set whether the decompiler should apply transformation rules that identify and
+	 * simplify double precision arithmetic operations.
+	 * @param simplifyDoublePrecision is true if double precision rules should be applied
+	 */
 	public void setSimplifyDoublePrecision(boolean simplifyDoublePrecision) {
 		this.simplifyDoublePrecision = simplifyDoublePrecision;
 	}
 
+	/**
+	 * @return true if line numbers should be displayed with decompiler output.
+	 */
 	public boolean isDisplayLineNumbers() {
 		return displayLineNumbers;
 	}
 
+	/**
+	 * @return the source programming language that decompiler output is rendered in
+	 */
 	public DecompilerLanguage getDisplayLanguage() {
 		return displayLanguage;
 	}
 
+	/**
+	 * Retrieve the transformer being applied to data-type, function, and namespace names.
+	 * If no transform is being applied, a pass-through object is returned.
+	 * @return the transformer object
+	 */
+	public NameTransformer getNameTransformer() {
+		if (nameTransformer == null) {
+			nameTransformer = new IdentityNameTransformer();
+		}
+		return nameTransformer;
+	}
+
+	/**
+	 * Set a specific transformer to be applied to all data-type, function, and namespace
+	 * names in decompiler output.  A null value indicates no transform should be applied.
+	 * @param transformer is the transformer to apply
+	 */
+	public void setNameTransformer(NameTransformer transformer) {
+		nameTransformer = transformer;
+	}
+
+	/**
+	 * @return true if calling convention names are displayed as part of function signatures
+	 */
 	public boolean isConventionPrint() {
 		return conventionPrint;
 	}
 
+	/**
+	 * Set whether the calling convention name should be displayed as part of function signatures
+	 * in decompiler output.
+	 * @param conventionPrint is true if calling convention names should be displayed
+	 */
 	public void setConventionPrint(boolean conventionPrint) {
 		this.conventionPrint = conventionPrint;
 	}
 
+	/**
+	 * @return true if cast operations are not displayed in decompiler output
+	 */
 	public boolean isNoCastPrint() {
 		return noCastPrint;
 	}
 
+	/**
+	 * Set whether decompiler output should display cast operations.
+	 * @param noCastPrint is true if casts should NOT be displayed.
+	 */
 	public void setNoCastPrint(boolean noCastPrint) {
 		this.noCastPrint = noCastPrint;
 	}
 
+	/**
+	 * Set the source programming language that decompiler output should be rendered in.
+	 * @param val is the source language
+	 */
 	public void setDisplayLanguage(DecompilerLanguage val) {
 		displayLanguage = val;
 	}
 
+	/**
+	 * @return the font that should be used to render decompiler output
+	 */
 	public Font getDefaultFont() {
 		return Gui.getFont(DEFAULT_FONT_ID);
 	}
 
+	/**
+	 * If the time a decompiler process is allowed to analyze a single
+	 * function exceeds this value, decompilation is aborted.
+	 * @return the maximum time in seconds
+	 */
 	public int getDefaultTimeout() {
 		return decompileTimeoutSeconds;
 	}
 
+	/**
+	 * Set the maximum time (in seconds) a decompiler process is allowed to analyze a single
+	 * function. If it is exceeded, decompilation is aborted.
+	 * @param timeout is the maximum time in seconds
+	 */
 	public void setDefaultTimeout(int timeout) {
 		decompileTimeoutSeconds = timeout;
 	}
 
+	/**
+	 * If the size (in megabytes) of the payload returned by the decompiler
+	 * process exceeds this value for a single function, decompilation is
+	 * aborted.
+	 * @return the maximum number of megabytes in a function payload
+	 */
 	public int getMaxPayloadMBytes() {
 		return payloadLimitMBytes;
 	}
 
+	/**
+	 * Set the maximum size (in megabytes) of the payload that can be returned by the decompiler
+	 * process when analyzing a single function.  If this size is exceeded, decompilation is
+	 * aborted.
+	 * @param mbytes is the maximum number of megabytes in a function payload
+	 */
 	public void setMaxPayloadMBytes(int mbytes) {
 		payloadLimitMBytes = mbytes;
 	}
 
+	/**
+	 * If the number of assembly instructions in a function exceeds this value, the function
+	 * is not decompiled.
+	 * @return the maximum number of instructions
+	 */
 	public int getMaxInstructions() {
 		return maxIntructionsPer;
 	}
 
+	/**
+	 * Set the maximum number of assembly instructions in a function to decompile.
+	 * If the number exceeds this, the function is not decompiled.
+	 * @param num is the number of instructions
+	 */
 	public void setMaxInstructions(int num) {
 		maxIntructionsPer = num;
 	}
 
+	/**
+	 * If the number of entries in a single jumptable exceeds this value, the decompiler will
+	 * not recover the table and control flow from the indirect jump corresponding to the table
+	 * will not be followed.
+	 * @return the maximum number of entries
+	 */
+	public int getMaxJumpTableEntries() {
+		return maxJumpTableEntries;
+	}
+
+	/**
+	 * Set the maximum number of entries the decompiler will recover from a single jumptable.
+	 * If the number exceeds this, the table is not recovered and control flow from the
+	 * corresponding indirect jump is not followed.
+	 * @param num is the number of entries
+	 */
+	public void setMaxJumpTableEntries(int num) {
+		maxJumpTableEntries = num;
+	}
+
+	/**
+	 * @return the style in which comments are printed in decompiler output
+	 */
 	public CommentStyleEnum getCommentStyle() {
 		return commentStyle;
 	}
 
+	/**
+	 * Set the style in which comments are printed as part of decompiler output
+	 * @param commentStyle is the new style to set
+	 */
 	public void setCommentStyle(CommentStyleEnum commentStyle) {
 		this.commentStyle = commentStyle;
 	}
 
+	/**
+	 * Return the maximum number of decompiled function results that should be cached
+	 * by the controller of the decompiler process.
+	 * @return the number of functions to cache
+	 */
 	public int getCacheSize() {
 		return cachedResultsSize;
 	}
+
 }
