@@ -70,6 +70,7 @@ public abstract class ThemeManager {
 	protected LafType activeLafType = activeTheme.getLookAndFeelType();
 	protected boolean useDarkDefaults = activeTheme.useDarkDefaults();
 
+	// this use our normalized ids (e.g., 'laf.')
 	protected GThemeValueMap javaDefaults = new GThemeValueMap();
 	protected GThemeValueMap currentValues = new GThemeValueMap();
 
@@ -89,10 +90,11 @@ public abstract class ThemeManager {
 			// default behavior is only install to INSTANCE if first time
 			INSTANCE = this;
 		}
-		applicationDefaults = getApplicationDefaults();
+
+		applicationDefaults = loadApplicationDefaults();
 	}
 
-	protected ApplicationThemeDefaults getApplicationDefaults() {
+	protected ApplicationThemeDefaults loadApplicationDefaults() {
 		return new PropertyFileThemeDefaults();
 	}
 
@@ -100,9 +102,35 @@ public abstract class ThemeManager {
 		Gui.setThemeManager(this);
 	}
 
+	/**
+	 * This method is called to create the internal set of theme value used by the application. To
+	 * do this, we use a layered approach to install values, with the last values added overwriting
+	 * any pre-existing values with the same key.  The values are added in the following order:
+	 * <pre>
+	 * java defaults -> light values -> dark values -> look and feel values -> property file values -> theme values
+	 * </pre>
+	 * <p>
+	 * At the point this method is called, this is the state of these various values:
+	 * <ul>
+	 *     <li>The 'javaValues' are normalized in the form of 'laf.font.TextArea'
+	 *     </li>
+	 *     <li>The 'applicationDefaults' contains values loaded from the {@code theme.properties}
+	 *     files:
+	 *     <pre>
+	 *     font.listing.base
+	 *     font.monospaced
+	 *     [color]Viewport.background = color.bg
+	 *     [laf.font]TextArea.font = font.monospaced
+	 *     [laf.boolean]Button.rollover = true
+	 *     </pre>
+	 *     </li>
+	 *     <li>The 'activeTheme' values are those loaded by the current theme, which has any changes
+	 *     made to the default values
+	 *     </li>
+	 * </ul>
+	 */
 	protected void buildCurrentValues() {
 		GThemeValueMap map = new GThemeValueMap();
-
 		map.load(javaDefaults);
 		map.load(applicationDefaults.getLightValues());
 		if (useDarkDefaults) {
@@ -322,7 +350,7 @@ public abstract class ThemeManager {
 		FontValue font = currentValues.getFont(id);
 
 		if (font == null) {
-			error("No color value registered for: '" + id + "'");
+			error("No font value registered for: '" + id + "'");
 			return DEFAULT_FONT;
 		}
 		return font.get(currentValues);
@@ -443,20 +471,6 @@ public abstract class ThemeManager {
 		return map;
 	}
 
-	/**
-	 * Returns application defaults values (does not include java default values)
-	 * @return application defaults values (does not include java default values)
-	 */
-	public GThemeValueMap getApplicationOverrides() {
-		GThemeValueMap currentDefaults = new GThemeValueMap();
-		currentDefaults.load(applicationDefaults.getLightValues());
-		if (useDarkDefaults) {
-			currentDefaults.load(applicationDefaults.getDarkValues());
-		}
-		currentDefaults.load(applicationDefaults.getLookAndFeelValues(getLookAndFeelType()));
-		return currentDefaults;
-	}
-
 	/**
 	 * Returns a {@link GThemeValueMap} containing all default values for the current theme. It
 	 * is a combination of application defined defaults and java {@link LookAndFeel} defaults.
@@ -514,6 +528,16 @@ public abstract class ThemeManager {
 		return false;
 	}
 
+	/**
+	 * Returns true if any theme values have changed.  This does not take into account the current
+	 * Look and Feel.   Use {@link #hasThemeChanges()} to also account for changes to the Look and
+	 * Feel.
+	 * @return true if any theme values have changed
+	 */
+	public boolean hasThemeValueChanges() {
+		return false;
+	}
+
 	/**
 	 * Returns true if an color for the given Id has been defined
 	 * @param id the id to check for an existing color.
@@ -584,7 +608,7 @@ public abstract class ThemeManager {
 	}
 
 	protected void error(String message) {
-		Throwable t = ReflectionUtilities.createThrowableWithStackOlderThan();
+		Throwable t = ReflectionUtilities.createThrowableWithStackOlderThan(ThemeManager.class);
 		StackTraceElement[] trace = t.getStackTrace();
 		StackTraceElement[] filtered = ReflectionUtilities.filterStackTrace(trace, "java.",
 			"theme.Gui", "theme.ThemeManager", "theme.GColor");
