@@ -18,6 +18,7 @@ package ghidra.framework.project.tool;
 import java.io.*;
 import java.net.URL;
 import java.util.*;
+import java.util.function.Function;
 
 import org.jdom.Document;
 import org.jdom.output.XMLOutputter;
@@ -26,8 +27,9 @@ import docking.widgets.OptionDialog;
 import docking.widgets.filechooser.GhidraFileChooser;
 import ghidra.framework.ToolUtils;
 import ghidra.framework.data.*;
+import ghidra.framework.main.AppInfo;
+import ghidra.framework.main.FrontEndTool;
 import ghidra.framework.model.*;
-import ghidra.framework.plugintool.PluginEvent;
 import ghidra.framework.plugintool.PluginTool;
 import ghidra.framework.preferences.Preferences;
 import ghidra.framework.protocol.ghidra.GetUrlContentTypeTask;
@@ -38,6 +40,7 @@ import ghidra.util.filechooser.GhidraFileChooserModel;
 import ghidra.util.filechooser.GhidraFileFilter;
 import ghidra.util.task.TaskLauncher;
 import ghidra.util.xml.GenericXMLOutputter;
+import util.CollectionUtils;
 
 /**
  * Implementation of service used to manipulate tools.
@@ -49,7 +52,6 @@ class ToolServicesImpl implements ToolServices {
 
 	private ToolChest toolChest;
 	private ToolManagerImpl toolManager;
-	private List<DefaultToolChangeListener> listeners = new ArrayList<>();
 	private ToolChestChangeListener toolChestChangeListener;
 	private Set<ContentHandler<?>> contentHandlers;
 
@@ -166,59 +168,75 @@ class ToolServicesImpl implements ToolServices {
 		return toolChest;
 	}
 
-	@Override
-	public void displaySimilarTool(PluginTool tool, DomainFile domainFile, PluginEvent event) {
-
-		PluginTool[] similarTools = getSameNamedRunningTools(tool);
-		PluginTool matchingTool = findToolUsingFile(similarTools, domainFile);
-		if (matchingTool != null) {
-			// Bring the matching tool forward.
-			matchingTool.toFront();
+	private static DefaultLaunchMode getDefaultLaunchMode() {
+		DefaultLaunchMode defaultLaunchMode = DefaultLaunchMode.DEFAULT;
+		FrontEndTool frontEndTool = AppInfo.getFrontEndTool();
+		if (frontEndTool != null) {
+			defaultLaunchMode = frontEndTool.getDefaultLaunchMode();
 		}
-		else {
-			// Create a new tool and pop it up.
-			Workspace workspace = toolManager.getActiveWorkspace();
-			matchingTool = workspace.runTool(tool.getToolTemplate(true));
-			matchingTool.setVisible(true);
-			matchingTool.acceptDomainFiles(new DomainFile[] { domainFile });
-		}
-
-		// Fire the indicated event in the tool.
-		matchingTool.firePluginEvent(event);
+		return defaultLaunchMode;
 	}
 
-	@Override
-	public PluginTool launchDefaultTool(DomainFile domainFile) {
-		ToolTemplate template = getDefaultToolTemplate(domainFile);
-		if (template == null) {
-			return null;
+	private PluginTool defaultLaunch(ToolTemplate template,
+			Function<PluginTool, Boolean> openFunction) {
+
+		DefaultLaunchMode defaultLaunchMode = getDefaultLaunchMode();
+		if (defaultLaunchMode == DefaultLaunchMode.REUSE_TOOL) {
+			if (template != null) {
+				// attempt to reuse running tool with default name
+				String defaultToolName = template.getName();
+				for (PluginTool tool : getRunningTools()) {
+					if (tool.getName().equals(defaultToolName) && openFunction.apply(tool)) {
+						return tool;
+					}
+				}
+			}
+
+			// attempt to reuse any running tool
+			for (PluginTool tool : getRunningTools()) {
+				if (openFunction.apply(tool)) {
+					return tool;
+				}
+			}
 		}
+
+		if (template == null) {
+			return null; // unable to launch new tool
+		}
+
 		Workspace workspace = toolManager.getActiveWorkspace();
 		PluginTool tool = workspace.runTool(template);
 		if (tool == null) {
-			return null;
+			return null; // tool launch failed
 		}
 		tool.setVisible(true);
-		tool.acceptDomainFiles(new DomainFile[] { domainFile });
+		openFunction.apply(tool);
 		return tool;
 	}
 
 	@Override
-	public PluginTool launchTool(String toolName, DomainFile domainFile) {
+	public PluginTool launchDefaultTool(Collection<DomainFile> domainFiles) {
+		if (CollectionUtils.isBlank(domainFiles)) {
+			throw new IllegalArgumentException("Domain files cannot be empty");
+		}
+		ToolTemplate template = getDefaultToolTemplate(CollectionUtils.any(domainFiles));
+		return defaultLaunch(template, t -> {
+			return t.acceptDomainFiles(domainFiles.toArray(DomainFile[]::new));
+		});
+	}
+
+	@Override
+	public PluginTool launchTool(String toolName, Collection<DomainFile> domainFiles) {
 		ToolTemplate template = findToolChestToolTemplate(toolName);
 		if (template == null) {
 			return null;
 		}
-		Workspace workspace = toolManager.getActiveWorkspace();
-		PluginTool tool = workspace.runTool(template);
-		if (tool == null) {
-			return null;
-		}
-		tool.setVisible(true);
-		if (domainFile != null) {
-			tool.acceptDomainFiles(new DomainFile[] { domainFile });
-		}
-		return tool;
+		return defaultLaunch(template, t -> {
+			if (CollectionUtils.isBlank(domainFiles)) {
+				return true;
+			}
+			return t.acceptDomainFiles(domainFiles.toArray(DomainFile[]::new));
+		});
 	}
 
 	@Override
@@ -228,17 +246,9 @@ class ToolServicesImpl implements ToolServices {
 			return null;
 		}
 		ToolTemplate template = getDefaultToolTemplate(contentType);
-		if (template == null) {
-			return null;
-		}
-		Workspace workspace = toolManager.getActiveWorkspace();
-		PluginTool tool = workspace.runTool(template);
-		if (tool == null) {
-			return null;
-		}
-		tool.setVisible(true);
-		tool.accept(ghidraUrl);
-		return tool;
+		return defaultLaunch(template, t -> {
+			return t.accept(ghidraUrl);
+		});
 	}
 
 	@Override
@@ -475,16 +485,6 @@ class ToolServicesImpl implements ToolServices {
 		return contentHandlers;
 	}
 
-	@Override
-	public void addDefaultToolChangeListener(DefaultToolChangeListener listener) {
-		listeners.add(listener);
-	}
-
-	@Override
-	public void removeDefaultToolChangeListener(DefaultToolChangeListener listener) {
-		listeners.remove(listener);
-	}
-
 	private GhidraToolTemplate findToolChestToolTemplate(String toolName) {
 		if (toolName != null) {
 			return (GhidraToolTemplate) toolChest.getToolTemplate(toolName);
@@ -508,9 +508,9 @@ class ToolServicesImpl implements ToolServices {
 
 	/**
 	 * Get all running tools that have the same tool chest tool name as this one.
-	 * 
+	 *
 	 * @param tool the tool for comparison.
-	 * 
+	 *
 	 * @return array of tools that are running and named the same as this one.
 	 */
 	private PluginTool[] getSameNamedRunningTools(PluginTool tool) {
@@ -532,10 +532,10 @@ class ToolServicesImpl implements ToolServices {
 
 	/**
 	 * Search the array of tools for one using the given domainFile.
-	 * 
+	 *
 	 * @param tools array of tools to search
 	 * @param domainFile domain file to find user of
-	 * 
+	 *
 	 * @return first tool found to be using the domainFile
 	 */
 	private PluginTool findToolUsingFile(PluginTool[] tools, DomainFile domainFile) {
