@@ -209,7 +209,7 @@ public class FunctionDB extends DatabaseObject implements Function {
 	@Override
 	public ExternalLocation getExternalLocation() {
 		if (isExternal()) {
-			ExternalManagerDB extMgr = (ExternalManagerDB) program.getExternalManager();
+			ExternalManagerDB extMgr = program.getExternalManager();
 			return extMgr.getExternalLocation(getSymbol());
 		}
 		return null;
@@ -229,11 +229,6 @@ public class FunctionDB extends DatabaseObject implements Function {
 		return super.hashCode();
 	}
 
-	/*
-	 * (non-Javadoc)
-	 *
-	 * @see java.lang.Object#toString()
-	 */
 	@Override
 	public String toString() {
 		return getName(true);
@@ -397,7 +392,10 @@ public class FunctionDB extends DatabaseObject implements Function {
 				return;
 			}
 			type = type.clone(program.getDataTypeManager());
-			if (storage.isValid() && (storage.size() != type.getLength())) {
+			if (VoidDataType.isVoidDataType(type)) {
+				storage = VariableStorage.VOID_STORAGE;
+			}
+			else if (storage.isValid() && (storage.size() != type.getLength())) {
 				try {
 					storage = VariableUtilities.resizeStorage(storage, type, true, this);
 				}
@@ -816,17 +814,13 @@ public class FunctionDB extends DatabaseObject implements Function {
 		}
 
 		dataTypes[0] = returnParam.getFormalDataType();
-		DataType baseType = dataTypes[0];
-		if (baseType instanceof TypeDef) {
-			baseType = ((TypeDef) baseType).getBaseDataType();
-		}
-		returnParam
-				.setDynamicStorage((baseType instanceof VoidDataType) ? VariableStorage.VOID_STORAGE
-						: VariableStorage.UNASSIGNED_STORAGE);
+		returnParam.setDynamicStorage(
+					VoidDataType.isVoidDataType(dataTypes[0]) ? VariableStorage.VOID_STORAGE
+							: VariableStorage.UNASSIGNED_STORAGE);
 
 		PrototypeModel callingConvention = getCallingConvention();
 		if (callingConvention == null) {
-			callingConvention = getDefaultCallingConvention();
+			callingConvention = manager.getDefaultCallingConvention();
 		}
 		if (callingConvention == null) {
 			return;
@@ -918,12 +912,8 @@ public class FunctionDB extends DatabaseObject implements Function {
 			ReturnParameterDB rtnParam = getReturn();
 			if (rtnParam.getVariableStorage().isBadStorage()) {
 				DataType dt = rtnParam.getDataType();
-				DataType baseType = dt;
-				if (baseType instanceof TypeDef) {
-					baseType = ((TypeDef) baseType).getBaseDataType();
-				}
 				VariableStorage storage =
-					(baseType instanceof VoidDataType) ? VariableStorage.VOID_STORAGE
+					VoidDataType.isVoidDataType(dt) ? VariableStorage.VOID_STORAGE
 							: VariableStorage.UNASSIGNED_STORAGE;
 				rtnParam.setStorageAndDataType(storage, dt);
 			}
@@ -993,7 +983,7 @@ public class FunctionDB extends DatabaseObject implements Function {
 					v.setStorageAndDataType(storage, var.getDataType());
 				}
 				else {
-					SymbolManager symbolMgr = (SymbolManager) program.getSymbolTable();
+					SymbolManager symbolMgr = program.getSymbolTable();
 					VariableSymbolDB s = symbolMgr.createVariableSymbol(name, this,
 						SymbolType.LOCAL_VAR, firstUseOffset, storage, source);
 					s.setStorageAndDataType(storage, var.getDataType());
@@ -1310,6 +1300,7 @@ public class FunctionDB extends DatabaseObject implements Function {
 			source);
 	}
 
+
 	/**
 	 * Increment updateInProgressCount indicating that an update operation is in progress and 
 	 * that any attempted refresh should be deferred.  The updateRefreshReqd flag will be set
@@ -1460,7 +1451,7 @@ public class FunctionDB extends DatabaseObject implements Function {
 			}
 
 			// Append new parameters if needed
-			SymbolManager symbolMgr = (SymbolManager) program.getSymbolTable();
+			SymbolManager symbolMgr = program.getSymbolTable();
 			for (int i = newParamIndex; i < newParams.size(); i++) {
 				Variable newParam = newParams.get(i);
 				DataType dt = (newParam instanceof Parameter && !useCustomStorage)
@@ -1683,7 +1674,7 @@ public class FunctionDB extends DatabaseObject implements Function {
 							}
 						}
 					}
-					SymbolManager symbolMgr = (SymbolManager) program.getSymbolTable();
+					SymbolManager symbolMgr = program.getSymbolTable();
 					VariableSymbolDB s = symbolMgr.createVariableSymbol(name, this,
 						SymbolType.PARAMETER, ordinal, storage, paramSource);
 					s.setStorageAndDataType(storage, var.getDataType());
@@ -2517,11 +2508,6 @@ public class FunctionDB extends DatabaseObject implements Function {
 		}
 	}
 
-	/*
-	 * (non-Javadoc)
-	 *
-	 * @see ghidra.program.model.listing.Function#getCallingConvention()
-	 */
 	@Override
 	public PrototypeModel getCallingConvention() {
 		String name = getCallingConventionName();
@@ -2535,11 +2521,6 @@ public class FunctionDB extends DatabaseObject implements Function {
 		return functionMgr.getCallingConvention(name);
 	}
 
-	/*
-	 * (non-Javadoc)
-	 *
-	 * @see ghidra.program.model.listing.Function#getCallingConventionName()
-	 */
 	@Override
 	public String getCallingConventionName() {
 		manager.lock.acquire();
@@ -2551,14 +2532,13 @@ public class FunctionDB extends DatabaseObject implements Function {
 				return thunkedFunction.getCallingConventionName();
 			}
 			byte callingConventionID = rec.getByteValue(FunctionAdapter.CALLING_CONVENTION_ID_COL);
-			if (callingConventionID == CallingConventionDBAdapter.UNKNOWN_CALLING_CONVENTION_ID) {
+			if (callingConventionID == DataTypeManagerDB.UNKNOWN_CALLING_CONVENTION_ID) {
 				return Function.UNKNOWN_CALLING_CONVENTION_STRING;
 			}
-			if (callingConventionID == CallingConventionDBAdapter.DEFAULT_CALLING_CONVENTION_ID) {
+			if (callingConventionID == DataTypeManagerDB.DEFAULT_CALLING_CONVENTION_ID) {
 				return Function.DEFAULT_CALLING_CONVENTION_STRING;
 			}
-			String name = manager.getCallingConventionName(callingConventionID);
-			return name != null ? name : UNKNOWN_CALLING_CONVENTION_STRING;
+			return program.getDataTypeManager().getCallingConventionName(callingConventionID);
 		}
 		finally {
 			manager.lock.release();
@@ -2569,36 +2549,16 @@ public class FunctionDB extends DatabaseObject implements Function {
 		if (thunkedFunction != null) {
 			return thunkedFunction.getRealCallingConventionName();
 		}
-		String name = null;
 		byte callingConventionID = rec.getByteValue(FunctionAdapter.CALLING_CONVENTION_ID_COL);
-		if (callingConventionID != CallingConventionDBAdapter.UNKNOWN_CALLING_CONVENTION_ID &&
-			callingConventionID != CallingConventionDBAdapter.DEFAULT_CALLING_CONVENTION_ID) {
-			name = manager.getCallingConventionName(callingConventionID);
+		String name = program.getDataTypeManager().getCallingConventionName(callingConventionID);
+		if (UNKNOWN_CALLING_CONVENTION_STRING.equals(name) ||
+			DEFAULT_CALLING_CONVENTION_STRING.equals(name)) {
+			name = null;
 		}
 		// null returned for unknown or default calling convention
 		return name;
 	}
 
-	private PrototypeModel getDefaultCallingConvention() {
-		CompilerSpec compilerSpec = getProgram().getCompilerSpec();
-		if (compilerSpec != null) {
-			return compilerSpec.getDefaultCallingConvention();
-		}
-		return null;
-	}
-
-	@Override
-	public String getDefaultCallingConventionName() {
-		PrototypeModel defaultPrototype = getDefaultCallingConvention();
-		if (defaultPrototype != null) {
-			String defaultPrototypeName = defaultPrototype.getName();
-			if (defaultPrototypeName != null) {
-				return defaultPrototypeName;
-			}
-		}
-		return Function.DEFAULT_CALLING_CONVENTION_STRING;
-	}
-
 	@Override
 	public void setCallingConvention(String name) throws InvalidInputException {
 		manager.lock.acquire();
@@ -2610,36 +2570,38 @@ public class FunctionDB extends DatabaseObject implements Function {
 				return;
 			}
 
-			byte newCallingConventionID = manager.getCallingConventionID(name);
+			byte newCallingConventionID =
+				program.getDataTypeManager().getCallingConventionID(name, true);
 			byte oldCallingConventionID =
 				rec.getByteValue(FunctionAdapter.CALLING_CONVENTION_ID_COL);
 
-			if (oldCallingConventionID != newCallingConventionID) {
+			if (oldCallingConventionID == newCallingConventionID) {
+				return; // no change
+			}
 
+			loadVariables();
+
+			rec.setByteValue(FunctionAdapter.CALLING_CONVENTION_ID_COL, newCallingConventionID);
+			manager.getFunctionAdapter().updateFunctionRecord(rec);
+
+			boolean hasCustomStorage = hasCustomVariableStorage();
+			if (!hasCustomStorage) {
+				// remove 'this' param if switching to __thiscall with dynamic storage
+				removeExplicitThisParameter();
+			}
+
+			frame.setInvalid();
+
+			if (!hasCustomStorage) {
+				createClassStructIfNeeded(); // TODO: How should thunks within Class namespace be handled?
 				loadVariables();
-
-				rec.setByteValue(FunctionAdapter.CALLING_CONVENTION_ID_COL, newCallingConventionID);
-				manager.getFunctionAdapter().updateFunctionRecord(rec);
-
-				boolean hasCustomStorage = hasCustomVariableStorage();
-				if (!hasCustomStorage) {
-					// remove 'this' param if switching to __thiscall with dynamic storage
-					removeExplicitThisParameter();
-				}
-
-				frame.setInvalid();
-
-				if (!hasCustomStorage) {
-					createClassStructIfNeeded(); // TODO: How should thunks within Class namespace be handled?
-					loadVariables();
-					removeExplicitThisParameter();
-					updateParametersAndReturn(); // assign dynamic storage
-					manager.functionChanged(this, ChangeManager.FUNCTION_CHANGED_PARAMETERS);
-					manager.functionChanged(this, ChangeManager.FUNCTION_CHANGED_RETURN);
-				}
-				else {
-					manager.functionChanged(this, 0); // change did not affect parameters
-				}
+				removeExplicitThisParameter();
+				updateParametersAndReturn(); // assign dynamic storage
+				manager.functionChanged(this, ChangeManager.FUNCTION_CHANGED_PARAMETERS);
+				manager.functionChanged(this, ChangeManager.FUNCTION_CHANGED_RETURN);
+			}
+			else {
+				manager.functionChanged(this, 0); // change did not affect parameters
 			}
 		}
 		catch (IOException e) {
@@ -2654,7 +2616,7 @@ public class FunctionDB extends DatabaseObject implements Function {
 	void createClassStructIfNeeded() {
 		PrototypeModel callingConvention = getCallingConvention();
 		if (callingConvention == null ||
-			callingConvention.getGenericCallingConvention() != GenericCallingConvention.thiscall) {
+			!CompilerSpec.CALLING_CONVENTION_thiscall.equals(callingConvention.getName())) {
 			return;
 		}
 		Namespace parent = getParentNamespace();
@@ -2671,7 +2633,9 @@ public class FunctionDB extends DatabaseObject implements Function {
 			// relationship between a class namespace and its structure is needed
 			// so its name and category can track properly.
 			classStruct = VariableUtilities.findOrCreateClassStruct(this);
-			dataTypeManager.resolve(classStruct, null);
+			if (classStruct != null) {
+				dataTypeManager.resolve(classStruct, null);
+			}
 		}
 	}
 
