@@ -124,8 +124,62 @@ public class ParamEntry {
 		return spaceid;
 	}
 
-	public Varnode[] getJoinRecord() {
-		return joinrec;
+	/**
+	 * Collect pieces from the join list, in endian order, until the given size is covered.
+	 * The last piece is trimmed to match the size exactly.  If the size is too big to be
+	 * covered by this ParamEntry, null is returned.
+	 * @param sz is the given size
+	 * @return the collected array of Varnodes or null
+	 */
+	public Varnode[] getJoinPieces(int sz) {
+		int num = 0;
+		int first, replace;
+		Varnode vn = null;
+		Varnode[] res;
+		if (isBigEndian()) {
+			first = 0;
+			while (sz > 0) {
+				if (num >= joinrec.length) {
+					return null;
+				}
+				vn = joinrec[num];
+				if (vn.getSize() > sz) {
+					num += 1;
+					break;
+				}
+				sz -= vn.getSize();
+				num += 1;
+			}
+			replace = num - 1;
+		}
+		else {
+			while (sz > 0) {
+				if (num >= joinrec.length) {
+					return null;
+				}
+				vn = joinrec[joinrec.length - 1 - num];
+				if (vn.getSize() > sz) {
+					num += 1;
+					break;
+				}
+				sz -= vn.getSize();
+				num += 1;
+			}
+			first = joinrec.length - num;
+			replace = first;
+		}
+		if (sz == 0 && num == joinrec.length) {
+			return joinrec;
+		}
+		res = new Varnode[num];
+		for (int i = 0; i < num; ++i) {
+			res[i] = joinrec[first + i];
+		}
+		if (sz > 0) {
+			res[replace] = new Varnode(vn.getAddress(), sz);
+		}
+
+		return res;
 	}
 
 	/**
@@ -288,10 +342,11 @@ public class ParamEntry {
 	 * there are not enough slots left
 	 * @param slotnum	number of slots already assigned
 	 * @param sz        number of bytes to being assigned
+	 * @param typeAlign required byte alignment for the parameter
 	 * @param res       the final storage address
 	 * @return          slotnum plus the number of slots used
 	 */
-	public int getAddrBySlot(int slotnum, int sz, VarnodeData res) {
+	public int getAddrBySlot(int slotnum, int sz, int typeAlign, VarnodeData res) {
 		res.space = null;		// Start with an invalid result
 		int spaceused;
 		if (sz < minsize) {
@@ -312,6 +367,12 @@ public class ParamEntry {
 			}
 		}
 		else {
+			if (typeAlign > alignment) {
+				int tmp = (slotnum * alignment) % typeAlign;
+				if (tmp != 0) {
+					slotnum += (typeAlign - tmp) / alignment;	// Waste slots to achieve typeAlign
+				}
+			}
 			int slotsused = sz / alignment;	// How many slots does a -sz- byte object need
 			if ((sz % alignment) != 0) {
 				slotsused += 1;
