@@ -6,8 +6,10 @@
 
 #include <rz_util/rz_annotated_code.h>
 
+namespace ghidra {
 class Funcdata;
+};
 
-RZ_API RzAnnotatedCode *ParseCodeXML(Funcdata *func, const char *xml);
+RZ_API RzAnnotatedCode *ParseCodeXML(ghidra::Funcdata *func, const char *xml);
 
 #endif //RZ_GHIDRA_CODEXMLPARSE_H
